@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2004-2009.
+ * Copyright (c) Tony Bybell 2004-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -262,6 +262,7 @@ free_2(info_fname); info_fname = NULL;
 
 /* SPLASH */                            splash_create();
 
+sym_hash_initialize(GLOBALS);
 GLOBALS->ae2_num_sections=ae2_read_num_sections(GLOBALS->ae2);
 GLOBALS->numfacs=ae2_read_num_symbols(GLOBALS->ae2);
 GLOBALS->ae2_process_mask = calloc_2(1, GLOBALS->numfacs/8+1);
@@ -492,16 +493,17 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		prevsymroot = prevsym = NULL;
 		}
 		
-        if(!GLOBALS->firstnode)
-                {
-                GLOBALS->firstnode=GLOBALS->curnode=s;   
-                }
-                else
-                {
-                GLOBALS->curnode->nextinaet=s;
-                GLOBALS->curnode=s;   
-                }
-
+	if(!GLOBALS->firstnode)
+	        {
+	        GLOBALS->firstnode=
+	        GLOBALS->curnode=calloc_2(1, sizeof(struct symchain));
+	        }   
+	        else                                     
+	        {
+	        GLOBALS->curnode->next=calloc_2(1, sizeof(struct symchain));
+	        GLOBALS->curnode=GLOBALS->curnode->next;
+	        }
+	GLOBALS->curnode->symbol=s;
 
         mx_row = (GLOBALS->ae2_fr[match_idx].row < 1) ? 1 : GLOBALS->ae2_fr[match_idx].row;
 	mx_row_adjusted = (mx_row < 2) ? 0 : mx_row;
@@ -518,10 +520,9 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 		if(GLOBALS->ae2_fr[match_idx].length>1)
 			{
-			ExtNode *ext = (ExtNode *)calloc_2(1,sizeof(struct ExtNode));
-			ext->msi = 0;
-			ext->lsi = GLOBALS->ae2_fr[match_idx].length-1;
-			n[row_iter].ext = ext;
+			n[row_iter].msi = 0;
+			n[row_iter].lsi = GLOBALS->ae2_fr[match_idx].length-1;
+			n[row_iter].extvals = 1;
 			}
                  
 	        n[row_iter].head.time=-1;        /* mark 1st node as negative time */
@@ -548,10 +549,14 @@ if(GLOBALS->fast_tree_sort)
 	for(i=0;i<GLOBALS->numfacs;i++)
 		{
 		int len;
-		GLOBALS->facs[i]=GLOBALS->curnode;
-	        if((len=strlen(GLOBALS->curnode->name))>GLOBALS->longestname) GLOBALS->longestname=len;
-		GLOBALS->curnode=GLOBALS->curnode->nextinaet;
+		struct symchain *sc;
+		GLOBALS->facs[i]=GLOBALS->curnode->symbol;
+	        if((len=strlen(GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
+		sc = GLOBALS->curnode;
+		GLOBALS->curnode=GLOBALS->curnode->next;
+		free_2(sc);
 		}
+	GLOBALS->firstnode=GLOBALS->curnode=NULL;
 
 /* SPLASH */                            splash_sync(3, 5);
 	fprintf(stderr, AET2_RDLOAD"Building facility hierarchy tree.\n");
@@ -576,23 +581,33 @@ if(GLOBALS->fast_tree_sort)
 	GLOBALS->curnode=GLOBALS->firstnode;
 	for(i=0;i<GLOBALS->numfacs;i++)
 		{
-		char *subst, ch;	
+		char *subst;
+#ifdef WAVE_HIERFIX
+		char ch;	
+#endif
 		int len;
+		struct symchain *sc;
 
-		GLOBALS->facs[i]=GLOBALS->curnode;
-	        if((len=strlen(subst=GLOBALS->curnode->name))>GLOBALS->longestname) GLOBALS->longestname=len;
-		GLOBALS->curnode=GLOBALS->curnode->nextinaet;
+		GLOBALS->facs[i]=GLOBALS->curnode->symbol;
+	        if((len=strlen(subst=GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
+		sc = GLOBALS->curnode;
+		GLOBALS->curnode=GLOBALS->curnode->next;
+		free_2(sc);
+#ifdef WAVE_HIERFIX
 		while((ch=(*subst)))
 			{	
 			if(ch==GLOBALS->hier_delimeter) { *subst=VCDNAM_HIERSORT; }	/* forces sort at hier boundaries */
 			subst++;
 			}
+#endif
 		}
+	GLOBALS->firstnode=GLOBALS->curnode=NULL;
 	
 /* SPLASH */                            splash_sync(3, 5);
 	fprintf(stderr, AET2_RDLOAD"Sorting facilities at hierarchy boundaries.\n");
 	wave_heapsort(GLOBALS->facs,GLOBALS->numfacs);
 	
+#ifdef WAVE_HIERFIX
 	for(i=0;i<GLOBALS->numfacs;i++)
 		{
 		char *subst, ch;
@@ -604,7 +619,8 @@ if(GLOBALS->fast_tree_sort)
 			subst++;
 			}
 		}
-	
+#endif	
+
 	GLOBALS->facs_are_sorted=1;
 
 /* SPLASH */                            splash_sync(4, 5);
@@ -1264,8 +1280,23 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 /* ...of AET2_IS_PRESENT */
 
 /*
- * $Id: ae2.c,v 1.10 2009/07/01 07:39:12 gtkwave Exp $
+ * $Id: ae2.c,v 1.15 2010/03/19 17:07:22 gtkwave Exp $
  * $Log: ae2.c,v $
+ * Revision 1.15  2010/03/19 17:07:22  gtkwave
+ * added missing ->symbol after structure type changed
+ *
+ * Revision 1.14  2010/03/15 15:57:28  gtkwave
+ * only allocate hash when necessary
+ *
+ * Revision 1.13  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.12  2010/03/13 19:48:53  gtkwave
+ * remove nextinaet field and replace with temp symchain
+ *
+ * Revision 1.11  2010/01/23 03:21:11  gtkwave
+ * hierarchy fixes when characters < "." are in the signal names
+ *
  * Revision 1.10  2009/07/01 07:39:12  gtkwave
  * decorating hierarchy tree with module type info
  *
