@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2009.
+ * Copyright (c) Tony Bybell 1999-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -248,7 +248,7 @@ if(GLOBALS->default_flags & TR_PTRANSLATED)
 if(GLOBALS->shift_timebase_default_for_add)
 	t->shift=GLOBALS->shift_timebase_default_for_add;
 
-if(!GLOBALS->shadow_active)
+if(!GLOBALS->strace_ctx->shadow_active)
 	{
 	if( GLOBALS->traces.first == NULL )
 		{
@@ -268,14 +268,14 @@ if(!GLOBALS->shadow_active)
 	else	/* hide offscreen */
 	{
 	struct strace *st = calloc_2(1, sizeof(struct strace));
-	st->next = GLOBALS->shadow_straces;
-	st->value = GLOBALS->shadow_type;
+	st->next = GLOBALS->strace_ctx->shadow_straces;
+	st->value = GLOBALS->strace_ctx->shadow_type;
 	st->trace = t;
 
-	st->string = GLOBALS->shadow_string;	/* copy string over */
-	GLOBALS->shadow_string = NULL;
+	st->string = GLOBALS->strace_ctx->shadow_string; /* copy string over */
+	GLOBALS->strace_ctx->shadow_string = NULL;
 
-	GLOBALS->shadow_straces = st;
+	GLOBALS->strace_ctx->shadow_straces = st;
 	}
 }
 
@@ -482,11 +482,11 @@ int AddNodeTraceReturn(nptr nd, char *aliasname, Trptr *tret)
 	}
     }
 
-  if(nd->ext)	/* expansion vectors */
+  if(nd->extvals) /* expansion vectors */
     {	
       int n;
 
-      n = nd->ext->msi - nd->ext->lsi;
+      n = nd->msi - nd->lsi;
       if(n<0)n=-n;
       n++;
 
@@ -584,13 +584,13 @@ if(GLOBALS->starting_unshifted_trace == t)
 	GLOBALS->starting_unshifted_trace = NULL; /* for new "standard" clicking routines */
 	}
 
-if(GLOBALS->straces)
+if(GLOBALS->strace_ctx->straces)
 	{
 	struct strace_defer_free *sd = calloc_2(1, sizeof(struct strace_defer_free));
-	sd->next = GLOBALS->strace_defer_free_head;
+	sd->next = GLOBALS->strace_ctx->strace_defer_free_head;
 	sd->defer = t;
 
-	GLOBALS->strace_defer_free_head = sd;
+	GLOBALS->strace_ctx->strace_defer_free_head = sd;
 	return;
 	}
 
@@ -753,6 +753,7 @@ Trptr PasteBuffer(void)
 {
   Trptr t, tinsert=NULL, tinsertnext;
   int count;
+  Trptr prev;
 
   if(!GLOBALS->traces.buffer) return(NULL);
 
@@ -761,8 +762,10 @@ Trptr PasteBuffer(void)
   if(!(t=GLOBALS->traces.first))
     {
       t=GLOBALS->traces.last=GLOBALS->traces.first=GLOBALS->traces.buffer;
+      prev = NULL;
       while(t)
 	{
+          t->t_prev = prev; /* defensive re-link move */
 	  GLOBALS->traces.last=t;
 	  GLOBALS->traces.total++;
 	  t=t->t_next;
@@ -837,6 +840,16 @@ Trptr PasteBuffer(void)
   GLOBALS->traces.buffer=GLOBALS->traces.bufferlast=NULL;
   GLOBALS->traces.buffercount=0;
 
+  /* defensive re-link */
+  t=GLOBALS->traces.first;
+  prev = NULL;
+  while(t)
+	{
+        t->t_prev = prev;
+	prev = t;
+	t=t->t_next;
+	}	
+
   return(GLOBALS->traces.first);
 }
 
@@ -858,6 +871,7 @@ t=GLOBALS->traces.buffer;
 
 while(t)
 	{
+	t->t_prev = prev; /* defensive re-link move */
 	prev=t;
 	t->flags&=(~TR_HIGHLIGHT);
 	GLOBALS->traces.total++;
@@ -902,10 +916,20 @@ if(GLOBALS->traces.first)
       }
    }
 
- /* clean out the buffer */
+/* clean out the buffer */
 GLOBALS->traces.buffer=GLOBALS->traces.bufferlast=NULL;
 GLOBALS->traces.buffercount=0;
 
+/* defensive re-link */
+t=GLOBALS->traces.first;
+prev = NULL;
+while(t)
+	{
+        t->t_prev = prev;
+	prev = t;
+	t=t->t_next;
+	}	
+
 return(GLOBALS->traces.first);
 }
 
@@ -1035,7 +1059,9 @@ int TracesReorder(int mode)
 {
 Trptr t, prev = NULL;
 Trptr *tsort, *tsort_pnt;
+#ifdef WAVE_HIERFIX
 char *subst, ch;
+#endif
 int i;
 int (*cptr)(const void*, const void*);
    
@@ -1052,12 +1078,14 @@ for(i=0;i<GLOBALS->traces.total;i++)
                 }
         *(tsort_pnt++)=t;
 
+#ifdef WAVE_HIERFIX
 	if((subst=t->name))
 	        while((ch=(*subst)))
         	        {
         	        if(ch==GLOBALS->hier_delimeter) { *subst=VCDNAM_HIERSORT; } /* forces sort at hier boundaries */
         	        subst++;
         	        }
+#endif
 
         t=t->t_next;
         }
@@ -1171,12 +1199,14 @@ for(i=0;i<GLOBALS->traces.total;i++)
 
 	prev=t;
 
+#ifdef WAVE_HIERFIX
 	if((subst=t->name))
 	        while((ch=(*subst)))
         	        {
         	        if(ch==VCDNAM_HIERSORT) { *subst=GLOBALS->hier_delimeter; } /* restore hier */
         	        subst++;
         	        }
+#endif
         }
 
 GLOBALS->traces.last=prev;
@@ -1379,8 +1409,23 @@ if((underflow_sticky) || (oc_cnt > 0))
 }
 
 /*
- * $Id: analyzer.c,v 1.13 2009/12/24 20:55:27 gtkwave Exp $
+ * $Id: analyzer.c,v 1.18 2010/03/14 07:09:49 gtkwave Exp $
  * $Log: analyzer.c,v $
+ * Revision 1.18  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.17  2010/02/28 21:59:50  gtkwave
+ * defensive relinking of t_prev in cut and paste buffers
+ *
+ * Revision 1.16  2010/02/26 18:19:00  gtkwave
+ * defensive re-link of t_prev
+ *
+ * Revision 1.15  2010/01/23 03:21:11  gtkwave
+ * hierarchy fixes when characters < "." are in the signal names
+ *
+ * Revision 1.14  2010/01/22 02:10:49  gtkwave
+ * added second pattern search capability
+ *
  * Revision 1.13  2009/12/24 20:55:27  gtkwave
  * warnings cleanups
  *
