@@ -132,17 +132,10 @@ int    actual;			/* bit number to be used in [] */
 int    refcnt;
 } ExpandReferences;
 
-typedef struct ExtNode
-  {
-  int msi, lsi;
-  } ExtNode;
-
-
 struct Node
   {
     exptr    expansion; /* indicates which nptr this node was expanded from (if it was expanded at all) and (when implemented) refcnts */
     char     *nname;	/* ascii name of node */
-    ExtNode  *ext;	/* extension to node for vectors */    
     HistEnt  head;	/* first entry in transition history */
     hptr     curr;      /* ptr. to current history entry */
 
@@ -155,10 +148,14 @@ struct Node
       char *value;	/* for use when unrolling ae2 values */
     } mv; 		/* anon union is a gcc extension so use mv instead.  using this union avoids crazy casting warnings */
 
+    int msi, lsi;	/* for 64-bit, more efficient than having as an external struct ExtNode*/
+
     int      numhist;	/* number of elements in the harray */
     unsigned int array_height, this_row;
     unsigned char vartype; /* see nodeVarType, this is an internal value */
     unsigned char vardir; /* see nodeVarDir, this is an internal value */
+
+    unsigned extvals : 1; /* was formerly a pointer to ExtNode "ext", now simply a flag */
   };
 
 
@@ -184,6 +181,7 @@ static const char *vartype_strings[] = { \
     "wire", \
     "wor", \
     "array", \
+    "realtime", \
     "port" \
 };
 
@@ -210,9 +208,10 @@ enum nodeVarType {
     ND_VCD_WIRE            = 17,
     ND_VCD_WOR             = 18,
     ND_VCD_ARRAY           = 19,    /* used to define the rownum (index) port on the array */
+    ND_VCD_REALTIME        = 20,
 
-    ND_VCD_PORT		   = 20,
-    ND_VARTYPE_MAX	   = 20,
+    ND_VCD_PORT		   = 21,
+    ND_VARTYPE_MAX	   = 21,
                 
     ND_GEN_STRING          = 254,   /* generic string type */
     ND_GEN_MEMBLOCK        = 255    /* generic memblock type */
@@ -437,8 +436,14 @@ void ClearGroupTraces(Trptr t);
 #endif
 
 /*
- * $Id: analyzer.h,v 1.22 2009/12/24 20:55:27 gtkwave Exp $
+ * $Id: analyzer.h,v 1.24 2010/03/14 07:09:49 gtkwave Exp $
  * $Log: analyzer.h,v $
+ * Revision 1.24  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.23  2010/02/22 21:13:36  gtkwave
+ * added "realtime" VCD variable
+ *
  * Revision 1.22  2009/12/24 20:55:27  gtkwave
  * warnings cleanups
  *
