@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2009.
+ * Copyright (c) Tony Bybell 1999-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -749,7 +749,7 @@ struct Bits *b=NULL;
 if(!direction)
 for(i=GLOBALS->numfacs-1;i>=0;i--)	/* to keep vectors in hi..lo order */
 	{
-	if(GLOBALS->facs[i]->selected)
+	if(get_s_selected(GLOBALS->facs[i]))
 		{
 		n[nodepnt++]=GLOBALS->facs[i]->n;
 		if((nodepnt==512)||(numrows==nodepnt)) break;
@@ -758,7 +758,7 @@ for(i=GLOBALS->numfacs-1;i>=0;i--)	/* to keep vectors in hi..lo order */
 else
 for(i=0;i<GLOBALS->numfacs;i++)		/* to keep vectors in lo..hi order */
 	{
-	if(GLOBALS->facs[i]->selected)
+	if(get_s_selected(GLOBALS->facs[i]))
 		{
 		n[nodepnt++]=GLOBALS->facs[i]->n;
 		if((nodepnt==512)||(numrows==nodepnt)) break;
@@ -1631,14 +1631,14 @@ exptr exp1;
 if(n->mv.mvlfac) import_trace(n);
 
 DEBUG(fprintf(stderr, "expanding '%s'\n", n->nname));
-if(!n->ext)
+if(!n->extvals)
 	{
 	DEBUG(fprintf(stderr, "Nothing to expand\n"));
 	}
 	else
 	{
-	msb = n->ext->msi;
-	lsb = n->ext->lsi;
+	msb = n->msi;
+	lsb = n->lsi;
 	if(msb>lsb)
 		{
 		width = msb - lsb + 1;
@@ -1821,22 +1821,22 @@ exptr exp1;
 if(n->mv.mvlfac) import_trace(n);
 
 DEBUG(fprintf(stderr, "expanding '%s'\n", n->nname));
-if(!n->ext)
+if(!n->extvals)
 	{
 	DEBUG(fprintf(stderr, "Nothing to expand\n"));
 	return(NULL);
 	}
 	else
 	{
-	if(n->ext->lsi > n->ext->msi)
+	if(n->lsi > n->msi)
 		{
-		rgh = n->ext->lsi; lft = n->ext->msi;
-		actual = n->ext->msi + bit;
+		rgh = n->lsi; lft = n->msi;
+		actual = n->msi + bit;
 		}
 		else
 		{
-		rgh = n->ext->msi; lft = n->ext->lsi;
-		actual = n->ext->msi - bit;
+		rgh = n->msi; lft = n->lsi;
+		actual = n->msi - bit;
 		}
 
 	if((actual>rgh)||(actual<lft))
@@ -1895,7 +1895,7 @@ if(!n->ext)
 		h=h->next;
 		}
 
-	DEBUG(fprintf(stderr, "Extracting: (%d to %d) for offset #%d over %d entries.\n", n->ext->msi, n->ext->lsi, bit, n->numhist));
+	DEBUG(fprintf(stderr, "Extracting: (%d to %d) for offset #%d over %d entries.\n", n->msi, n->lsi, bit, n->numhist));
 
 	np = (nptr)calloc_2(1, sizeof(struct Node));
 	sprintf(nam+offset, "[%d]", actual);
@@ -2389,25 +2389,25 @@ if(*w2=='!')
 			{
 			if(ch=='!')
 				{
-				GLOBALS->shadow_active = 0;
+				GLOBALS->strace_ctx->shadow_active = 0;
 				return(~0);
 				}
 
-			if((!i)&&(GLOBALS->shadow_straces))
+			if((!i)&&(GLOBALS->strace_ctx->shadow_straces))
 				{
 				delete_strace_context();
 				}
 
-			GLOBALS->shadow_logical_mutex[i] = (ch & 1);
+			GLOBALS->strace_ctx->shadow_logical_mutex[i] = (ch & 1);
 			}
 			else	/* in case of short read */
 			{
-			GLOBALS->shadow_logical_mutex[i] = 0;
+			GLOBALS->strace_ctx->shadow_logical_mutex[i] = 0;
 			}
 		}
 
-	GLOBALS->shadow_mark_idx_start = 0;
-	GLOBALS->shadow_mark_idx_end = 0;
+	GLOBALS->strace_ctx->shadow_mark_idx_start = 0;
+	GLOBALS->strace_ctx->shadow_mark_idx_end = 0;
 
 	if(i==6)
 		{
@@ -2415,18 +2415,18 @@ if(*w2=='!')
 		if(ch != 0)
 			{
 			if (isupper(ch) || ch=='@')
-				GLOBALS->shadow_mark_idx_start = ch - '@';
+				GLOBALS->strace_ctx->shadow_mark_idx_start = ch - '@';
 		
 			ch = *(w2+8);
 			if(ch != 0)
 				{
 				if (isupper(ch) || ch=='@')
-					GLOBALS->shadow_mark_idx_end = ch - '@';
+					GLOBALS->strace_ctx->shadow_mark_idx_end = ch - '@';
 				}
 			}
 		}
 
-	GLOBALS->shadow_active = 1;
+	GLOBALS->strace_ctx->shadow_active = 1;
 	return(~0);
 	}
 	else
@@ -2436,22 +2436,22 @@ if(*w2=='?')
 	if(*(w2+1)=='\"')
 		{
 		int lens = strlen(w2+2);
-		if(GLOBALS->shadow_string) free_2(GLOBALS->shadow_string);
-		GLOBALS->shadow_string=NULL;
+		if(GLOBALS->strace_ctx->shadow_string) free_2(GLOBALS->strace_ctx->shadow_string);
+		GLOBALS->strace_ctx->shadow_string=NULL;
 
 		if(lens)
 			{
-			GLOBALS->shadow_string = malloc_2(lens+1);		
-			strcpy(GLOBALS->shadow_string, w2+2);
+			GLOBALS->strace_ctx->shadow_string = malloc_2(lens+1);		
+			strcpy(GLOBALS->strace_ctx->shadow_string, w2+2);
 			}
 
-		GLOBALS->shadow_type = ST_STRING;
+		GLOBALS->strace_ctx->shadow_type = ST_STRING;
 		}
 		else
 		{
-		int hex;
+		unsigned int hex;
 		sscanf(w2+1, "%x", &hex);	
-		GLOBALS->shadow_type = hex;
+		GLOBALS->strace_ctx->shadow_type = hex;
 		}
 
 	return(~0);
@@ -2525,6 +2525,15 @@ else if (*w2 == '[')
 	if(!GLOBALS->block_xy_update) set_window_xypos (x, y);
 	}
       }
+    else if (strcmp (w2, "pattern_trace") == 0)
+      {
+      int which_ctx = 0;
+      sscanf (w, "%d", &which_ctx);
+      if((which_ctx>=0)&&(which_ctx<WAVE_NUM_STRACE_WINDOWS))
+		{
+		GLOBALS->strace_ctx = &GLOBALS->strace_windows[GLOBALS->strace_current_window = which_ctx];
+		}
+      }
     else if (strcmp (w2, "timestart") == 0)
       {
       sscanf(w, TTFormat, &GLOBALS->timestart_from_savefile);
@@ -3046,8 +3055,20 @@ return(made);
 /****************/
 
 /*
- * $Id: bitvec.c,v 1.18 2009/12/24 20:55:27 gtkwave Exp $
+ * $Id: bitvec.c,v 1.22 2010/03/18 17:12:37 gtkwave Exp $
  * $Log: bitvec.c,v $
+ * Revision 1.22  2010/03/18 17:12:37  gtkwave
+ * pedantic warning cleanups
+ *
+ * Revision 1.21  2010/03/16 21:01:07  gtkwave
+ * remove selected member of struct symbol
+ *
+ * Revision 1.20  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.19  2010/01/22 02:10:49  gtkwave
+ * added second pattern search capability
+ *
  * Revision 1.18  2009/12/24 20:55:27  gtkwave
  * warnings cleanups
  *
