@@ -20,7 +20,7 @@
 #include "regex_wave.h"
 #include "translate.h"
 
-#define WAVE_VERSION_INFO "GTKWave Analyzer v3.3.2 (w)1999-2010 BSI"
+#define WAVE_VERSION_INFO "GTKWave Analyzer v3.3.5 (w)1999-2010 BSI"
 
 #define WAVE_INF_SCALING (0.5)
 #define WAVE_SI_UNITS " munpfaz"
@@ -124,7 +124,7 @@ void refresh_hier_tree(struct tree *t);
 
 void markerbox(char *title, GtkSignalFunc func);
 
-void tracesearchbox(char *title, GtkSignalFunc func);
+void tracesearchbox(const char *title, GtkSignalFunc func, gpointer data);
 
 int searchbox_is_active(void);	
 int treebox_is_active(void);
@@ -174,8 +174,29 @@ void do_popup_menu (GtkWidget *my_widget, GdkEventButton *event);
 #endif
 
 /*
- * $Id: currenttime.h,v 1.65 2010/01/05 06:18:33 gtkwave Exp $
+ * $Id: currenttime.h,v 1.72 2010/03/19 16:36:47 gtkwave Exp $
  * $Log: currenttime.h,v $
+ * Revision 1.72  2010/03/19 16:36:47  gtkwave
+ * version bump
+ *
+ * Revision 1.71  2010/03/09 21:32:01  gtkwave
+ * bumping to next revision
+ *
+ * Revision 1.70  2010/03/07 17:53:58  gtkwave
+ * version bump to 3.3.4
+ *
+ * Revision 1.69  2010/02/18 18:27:33  gtkwave
+ * modified clipping slope equation to use doubles for intermediate steps
+ *
+ * Revision 1.68  2010/02/18 17:27:07  gtkwave
+ * extern "C" headers / version bump
+ *
+ * Revision 1.67  2010/01/22 02:10:49  gtkwave
+ * added second pattern search capability
+ *
+ * Revision 1.66  2010/01/18 16:23:27  gtkwave
+ * clock count fix (>= rather than > in endcap check for loop break)
+ *
  * Revision 1.65  2010/01/05 06:18:33  gtkwave
  * emergency fix on missing comment causing bad code
  *
