@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999.
+ * Copyright (c) Tony Bybell 1999-2010
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,9 +16,49 @@
 #include <config.h>
 #include "globals.h"
 #include "debug.h"
+#ifdef _WAVE_HAVE_JUDY
+#include <Judy.h>
+#endif
 
 #undef free_2
 
+#ifdef _WAVE_HAVE_JUDY
+void free_outstanding(void)
+{
+Pvoid_t  PJArray = (Pvoid_t)GLOBALS->alloc2_chain;
+int rcValue;
+Word_t Index;
+JError_t JError;
+int ctr = 0;
+
+#ifdef DEBUG_PRINTF
+printf("\n*** cleanup ***\n");
+printf("Freeing %d chunks\n", GLOBALS->outstanding);
+system("date");
+#endif
+
+if(GLOBALS->s_selected)
+	{
+	destroy_s_selected();
+	}
+
+Index = 0;
+for (rcValue = Judy1First(PJArray, &Index, &JError); rcValue != 0; rcValue = Judy1Next(PJArray, &Index, &JError))
+	{
+	free((void *)Index);
+	ctr++;
+	}
+Judy1FreeArray(&PJArray, &JError);
+
+GLOBALS->alloc2_chain = NULL;
+GLOBALS->outstanding = 0;
+
+#ifdef DEBUG_PRINTF
+printf("Freed %d chunks\n", ctr);
+system("date");
+#endif
+}
+#else
 void free_outstanding(void)
 {
 void **t = (void **)GLOBALS->alloc2_chain;
@@ -47,11 +87,34 @@ printf("Freed %d chunks\n", ctr);
 system("date");
 #endif
 }
-
+#endif
 
 /*
  * wrapped malloc family...
  */
+#ifdef _WAVE_HAVE_JUDY
+void *malloc_2(size_t size)
+{
+void *ret;
+
+ret=malloc(size);
+if(ret)  
+        {
+	JError_t JError;
+
+	Judy1Set ((Pvoid_t)&GLOBALS->alloc2_chain, (Word_t)ret, &JError);
+
+        GLOBALS->outstanding++;
+        
+        return(ret);
+        }   
+        else
+        {
+        fprintf(stderr, "FATAL ERROR : Out of memory, sorry.\n");
+        exit(1);
+        }
+}
+#else
 void *malloc_2(size_t size)
 {
 void *ret;
@@ -78,7 +141,31 @@ if(ret)
 	exit(1);
 	}
 }
+#endif
 
+#ifdef _WAVE_HAVE_JUDY
+void *realloc_2(void *ptr, size_t size)
+{
+void *ret=realloc(ptr, size);
+
+if(ret)
+        {
+	if(ptr != ret)
+		{
+		JError_t JError1, JError2;
+		Judy1Unset ((Pvoid_t)&GLOBALS->alloc2_chain, (Word_t)ptr, &JError1);
+		Judy1Set ((Pvoid_t)&GLOBALS->alloc2_chain, (Word_t)ret, &JError2);
+		}
+
+        return(ret);
+        }
+        else
+        {
+        fprintf(stderr, "FATAL ERROR : Out of memory, sorry.\n");
+        exit(1);
+        }
+}
+#else
 void *realloc_2(void *ptr, size_t size)
 {
 void *ret;
@@ -122,8 +209,30 @@ if(ret)
 	exit(1);
 	}
 }
+#endif
 
+#ifdef _WAVE_HAVE_JUDY
+void *calloc_2_into_context(struct Global *g, size_t nmemb, size_t size)
+{
+void *ret;
 
+ret=calloc(nmemb, size);
+if(ret)
+	{
+	JError_t JError;
+	Judy1Set ((Pvoid_t)&g->alloc2_chain, (Word_t)ret, &JError);
+
+	g->outstanding++;
+
+	return(ret);
+	}
+	else
+	{
+	fprintf(stderr, "FATAL ERROR: Out of memory, sorry.\n");
+	exit(1);
+	}
+}
+#else
 void *calloc_2_into_context(struct Global *g, size_t nmemb, size_t size)
 {
 void *ret;
@@ -150,7 +259,7 @@ if(ret)
 	exit(1);
 	}
 }
-
+#endif
 
 void *calloc_2(size_t nmemb, size_t size)
 {
@@ -158,7 +267,30 @@ return(calloc_2_into_context(GLOBALS, nmemb, size));
 }
 
 
+#ifdef _WAVE_HAVE_JUDY
+void free_2(void *ptr)
+{
+if(ptr)
+	{
+	JError_t JError;
+	int delstat = Judy1Unset ((Pvoid_t)&GLOBALS->alloc2_chain, (Word_t)ptr, &JError);
 
+	if(delstat)
+		{
+		GLOBALS->outstanding--;
+		free(ptr);
+		}
+		else
+		{
+		printf("JUDYMEM | free to non-malloc'd address %p blocked\n", ptr);
+		}
+	}
+	else
+	{
+	fprintf(stderr, "WARNING: Attempt to free NULL pointer caught.\n");
+	}
+}
+#else
 void free_2(void *ptr)
 {
 if(ptr)
@@ -190,7 +322,7 @@ if(ptr)
 	fprintf(stderr, "WARNING: Attempt to free NULL pointer caught.\n");
 	}
 }
-
+#endif
 
 char *strdup_2(const char *s)
 {
@@ -354,8 +486,20 @@ return(tmpspace);
 }
 
 /*
- * $Id: debug.c,v 1.9 2009/03/25 09:20:26 gtkwave Exp $
+ * $Id: debug.c,v 1.13 2010/03/16 21:01:08 gtkwave Exp $
  * $Log: debug.c,v $
+ * Revision 1.13  2010/03/16 21:01:08  gtkwave
+ * remove selected member of struct symbol
+ *
+ * Revision 1.12  2010/03/12 18:45:31  gtkwave
+ * updated realloc_2 by moving bit clear/set inside if() guard
+ *
+ * Revision 1.11  2010/03/09 23:23:31  gtkwave
+ * use Judy1 rather than JudyL functions for memory tracking
+ *
+ * Revision 1.10  2010/03/09 22:21:29  gtkwave
+ * added optional preliminary Judy array support
+ *
  * Revision 1.9  2009/03/25 09:20:26  gtkwave
  * fixing reloader crashes in vcd_build_symbols if times is zero
  *
