@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2009.
+ * Copyright (c) Tony Bybell 2009-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -174,7 +174,7 @@ struct Node *n;
 struct symbol *s, *prevsymroot=NULL, *prevsym=NULL;
 struct symbol *sym_block = NULL;
 struct Node *node_block = NULL;
-JRB ptr, lst;
+char **namecache = NULL;
 
 if(!(GLOBALS->extload=fopen(fname, "rb")))
 	{
@@ -281,6 +281,7 @@ GLOBALS->max_time *= GLOBALS->time_scale;
 
 GLOBALS->mvlfacs_vzt_c_3=(struct fac *)calloc_2(GLOBALS->numfacs,sizeof(struct fac));
 GLOBALS->vzt_table_vzt_c_1=(struct lx2_entry *)calloc_2(GLOBALS->numfacs, sizeof(struct lx2_entry));
+namecache=(char **)calloc_2(GLOBALS->numfacs, sizeof(char *));
 sym_block = (struct symbol *)calloc_2(GLOBALS->numfacs, sizeof(struct symbol));
 node_block=(struct Node *)calloc_2(GLOBALS->numfacs,sizeof(struct Node));
 GLOBALS->extload_idcodes=(unsigned int *)calloc_2(GLOBALS->numfacs, sizeof(unsigned int));
@@ -451,13 +452,13 @@ if(GLOBALS->numfacs)
 
 	if(was_packed)
 		{
-		GLOBALS->mvlfacs_vzt_c_3[0].name = pnt;
+		namecache[0] = pnt;
 		}
 		else
 		{
 		int flen = strlen(fnam);
-		GLOBALS->mvlfacs_vzt_c_3[0].name=malloc_2(flen+1);
-		strcpy(GLOBALS->mvlfacs_vzt_c_3[0].name, fnam);
+		namecache[0]=malloc_2(flen+1);
+		strcpy(namecache[0], fnam);
 		}
 	}
 
@@ -480,27 +481,27 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 		if(was_packed)
 			{
-			GLOBALS->mvlfacs_vzt_c_3[i+1].name = pnt;
+			namecache[i+1] = pnt;
 			}
 			else
 			{
 			int flen = strlen(fnam);
-			GLOBALS->mvlfacs_vzt_c_3[i+1].name=malloc_2(flen+1);
-			strcpy(GLOBALS->mvlfacs_vzt_c_3[i+1].name, fnam);
+			namecache[i+1]=malloc_2(flen+1);
+			strcpy(namecache[i+1], fnam);
 			}
 		}
 
 	if(i>1)
 		{
-		free_2(GLOBALS->mvlfacs_vzt_c_3[i-2].name);
-		GLOBALS->mvlfacs_vzt_c_3[i-2].name = NULL;
+		free_2(namecache[i-2]);
+		namecache[i-2] = NULL;
 		}
 
 	f=GLOBALS->mvlfacs_vzt_c_3+i;
 
 	if((f->len>1)&& (!(f->flags&(VZT_RD_SYM_F_INTEGER|VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING))) )
 		{
-		int len=sprintf(buf, "%s[%d:%d]", GLOBALS->mvlfacs_vzt_c_3[i].name,GLOBALS->mvlfacs_vzt_c_3[i].msb, GLOBALS->mvlfacs_vzt_c_3[i].lsb);
+		int len=sprintf(buf, "%s[%d:%d]", namecache[i],GLOBALS->mvlfacs_vzt_c_3[i].msb, GLOBALS->mvlfacs_vzt_c_3[i].lsb);
 		str=malloc_2(len+1);
 
 		if(!GLOBALS->alt_hier_delimeter)
@@ -517,13 +518,13 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		}
 	else if ( 
 			((f->len==1)&&(!(f->flags&(VZT_RD_SYM_F_INTEGER|VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))&&
-			((i!=GLOBALS->numfacs-1)&&(!strcmp(GLOBALS->mvlfacs_vzt_c_3[i].name, GLOBALS->mvlfacs_vzt_c_3[i+1].name))))
+			((i!=GLOBALS->numfacs-1)&&(!strcmp(namecache[i], namecache[i+1]))))
 			||
-			(((i!=0)&&(!strcmp(GLOBALS->mvlfacs_vzt_c_3[i].name, GLOBALS->mvlfacs_vzt_c_3[i-1].name))) &&
+			(((i!=0)&&(!strcmp(namecache[i], namecache[i-1]))) &&
 			(GLOBALS->mvlfacs_vzt_c_3[i].msb!=-1)&&(GLOBALS->mvlfacs_vzt_c_3[i].lsb!=-1))
 		)
 		{
-		int len = sprintf(buf, "%s[%d]", GLOBALS->mvlfacs_vzt_c_3[i].name,GLOBALS->mvlfacs_vzt_c_3[i].msb);
+		int len = sprintf(buf, "%s[%d]", namecache[i],GLOBALS->mvlfacs_vzt_c_3[i].msb);
 		str=malloc_2(len+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
@@ -535,7 +536,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			}
 		s=&sym_block[i];
 	        symadd_name_exists_sym_exists(s,str,0);
-		if((prevsym)&&(i>0)&&(!strcmp(GLOBALS->mvlfacs_vzt_c_3[i].name, GLOBALS->mvlfacs_vzt_c_3[i-1].name)))	/* allow chaining for search functions.. */
+		if((prevsym)&&(i>0)&&(!strcmp(namecache[i], namecache[i-1])))	/* allow chaining for search functions.. */
 			{
 			prevsym->vec_root = prevsymroot;
 			prevsym->vec_chain = s;
@@ -549,14 +550,14 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		}
 		else
 		{
-		str=malloc_2(strlen(GLOBALS->mvlfacs_vzt_c_3[i].name)+1);
+		str=malloc_2(strlen(namecache[i])+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
-			strcpy(str, GLOBALS->mvlfacs_vzt_c_3[i].name);
+			strcpy(str, namecache[i]);
 			}
 			else
 			{
-			strcpy_vcdalt(str, GLOBALS->mvlfacs_vzt_c_3[i].name, GLOBALS->alt_hier_delimeter);
+			strcpy_vcdalt(str, namecache[i], GLOBALS->alt_hier_delimeter);
 			}
 		s=&sym_block[i];
 	        symadd_name_exists_sym_exists(s,str,0);
@@ -570,27 +571,16 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			}
 		}
 		
-        if(!GLOBALS->firstnode)
-                {
-                GLOBALS->firstnode=GLOBALS->curnode=s;   
-                }
-                else
-                {
-                GLOBALS->curnode->nextinaet=s;
-                GLOBALS->curnode=s;   
-                }
-
         n=&node_block[i];
         n->nname=s->name;
         n->mv.mvlfac = GLOBALS->mvlfacs_vzt_c_3+i;
 	GLOBALS->mvlfacs_vzt_c_3[i].working_node = n;
 
-	if((f->len>1)||(f->flags&&(VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))
+	if((f->len>1)||(f->flags&(VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))
 		{
-		ExtNode *ext = (ExtNode *)calloc_2(1,sizeof(struct ExtNode));
-		ext->msi = GLOBALS->mvlfacs_vzt_c_3[i].msb;
-		ext->lsi = GLOBALS->mvlfacs_vzt_c_3[i].lsb;
-		n->ext = ext;
+		n->extvals = 1;
+		n->msi = GLOBALS->mvlfacs_vzt_c_3[i].msb;
+		n->lsi = GLOBALS->mvlfacs_vzt_c_3[i].lsb;
 		}
                  
         n->head.time=-1;        /* mark 1st node as negative time */
@@ -600,37 +590,27 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 for(i=0;((i<2)&&(i<GLOBALS->numfacs));i++)
 	{
-	if(GLOBALS->mvlfacs_vzt_c_3[i].name)
+	if(namecache[i])
 		{
-		free_2(GLOBALS->mvlfacs_vzt_c_3[i].name);
-		GLOBALS->mvlfacs_vzt_c_3[i].name = NULL;
+		free_2(namecache[i]);
+		namecache[i] = NULL;
 		}
 	}
+free_2(namecache); namecache = NULL;
 pclose(GLOBALS->extload);
 
 /* SPLASH */                            splash_sync(2, 5);  
 GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
 
-GLOBALS->pfx_hier_array = calloc_2(GLOBALS->hier_pfx_cnt ? GLOBALS->hier_pfx_cnt : 1, sizeof(char *));
-         
-lst = GLOBALS->hier_pfx;
-if(lst)  
-        {
-        jrb_traverse(ptr, lst)
-                {
-                GLOBALS->pfx_hier_array[ptr->val.ui] = ptr->key.s;
-                }
-        }
+create_hier_array();
 
 if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
         {
-        GLOBALS->curnode=GLOBALS->firstnode;
         for(i=0;i<GLOBALS->numfacs;i++)
                 {
                 int len;
-                GLOBALS->facs[i]=GLOBALS->curnode; 
-                if((len=strlen(GLOBALS->curnode->name))>GLOBALS->longestname) GLOBALS->longestname=len;
-                GLOBALS->curnode=GLOBALS->curnode->nextinaet;
+                GLOBALS->facs[i]=&sym_block[i]; 
+                if((len=strlen(GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
                 }
                                 
 /* SPLASH */                            splash_sync(3, 5);  
@@ -653,26 +633,30 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
         }
         else
 	{
-	GLOBALS->curnode=GLOBALS->firstnode;
 	for(i=0;i<GLOBALS->numfacs;i++)
 		{
-		char *subst, ch;
+		char *subst;
+#ifdef WAVE_HIERFIX
+		char ch;
+#endif
 		int len;
 
-		GLOBALS->facs[i]=GLOBALS->curnode;
-	        if((len=strlen(subst=GLOBALS->curnode->name))>GLOBALS->longestname) GLOBALS->longestname=len;
-		GLOBALS->curnode=GLOBALS->curnode->nextinaet;
+		GLOBALS->facs[i]=&sym_block[i];
+	        if((len=strlen(subst=GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
+#ifdef WAVE_HIERFIX
 		while((ch=(*subst)))
 			{	
 			if(ch==GLOBALS->hier_delimeter) { *subst=VCDNAM_HIERSORT; }	/* forces sort at hier boundaries */
 			subst++;
 			}
+#endif
 		}
 
 /* SPLASH */                            splash_sync(3, 5);  
 	fprintf(stderr, EXTLOAD"Sorting facilities at hierarchy boundaries.\n");
 	wave_heapsort(GLOBALS->facs,GLOBALS->numfacs);
 	
+#ifdef WAVE_HIERFIX
 	for(i=0;i<GLOBALS->numfacs;i++)
 		{
 		char *subst, ch;
@@ -684,7 +668,8 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
 			subst++;
 			}
 		}
-	
+#endif	
+
 	GLOBALS->facs_are_sorted=1;
 
 /* SPLASH */                            splash_sync(4, 5);  
@@ -821,7 +806,9 @@ l2e->numtrans++;
  */
 static void ext_resolver(nptr np, nptr resolve)
 { 
-np->ext = resolve->ext;
+np->extvals = resolve->extvals;
+np->msi = resolve->msi;
+np->lsi = resolve->lsi;
 memcpy(&np->head, &resolve->head, sizeof(struct HistEnt));
 np->curr = resolve->curr;
 np->harray = resolve->harray;
@@ -1018,8 +1005,23 @@ if(nold!=np)
 #endif
 
 /*
- * $Id: extload.c,v 1.5 2009/07/01 07:39:12 gtkwave Exp $
+ * $Id: extload.c,v 1.10 2010/03/19 17:50:57 gtkwave Exp $
  * $Log: extload.c,v $
+ * Revision 1.10  2010/03/19 17:50:57  gtkwave
+ * compatibility fixes from fac struct changes
+ *
+ * Revision 1.9  2010/03/13 21:38:16  gtkwave
+ * fixed && used in logical operations for allocating ExtNode
+ *
+ * Revision 1.8  2010/03/13 19:16:00  gtkwave
+ * removal of useless symbol->nextinaet code
+ *
+ * Revision 1.7  2010/03/01 05:16:26  gtkwave
+ * move compressed hier tree traversal to hierpack
+ *
+ * Revision 1.6  2010/01/23 03:21:11  gtkwave
+ * hierarchy fixes when characters < "." are in the signal names
+ *
  * Revision 1.5  2009/07/01 07:39:12  gtkwave
  * decorating hierarchy tree with module type info
  *
