@@ -38,7 +38,7 @@ if((alloclen=strlen(allocbuf)))
 DEBUG(printf("Filesel OK %s\n",allocbuf));
 gtk_grab_remove(GLOBALS->fs_file_c_1);
 gtk_widget_destroy(GLOBALS->fs_file_c_1);
-gtkwave_gtk_main_iteration();
+gtkwave_main_iteration();
 GLOBALS->cleanup_file_c_2();
 }
 
@@ -47,14 +47,14 @@ static void cancel_callback(GtkWidget *widget, GtkWidget *nothing)
 DEBUG(printf("Filesel Entry Cancel\n"));
 gtk_grab_remove(GLOBALS->fs_file_c_1);
 gtk_widget_destroy(GLOBALS->fs_file_c_1);
-gtkwave_gtk_main_iteration();
+gtkwave_main_iteration();
 if(GLOBALS->bad_cleanup_file_c_1) GLOBALS->bad_cleanup_file_c_1();
 }
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
 DEBUG(printf("Filesel Destroy\n"));
-gtkwave_gtk_main_iteration();
+gtkwave_main_iteration();
 if(GLOBALS->bad_cleanup_file_c_1) GLOBALS->bad_cleanup_file_c_1();
 }
 
@@ -300,7 +300,7 @@ fix_suffix:                     s2 = malloc_2(strlen(s) + strlen(suffix) + 1);
 	gtk_grab_remove(pFileChoose);
 	gtk_widget_destroy(pFileChoose);
 
-	gtkwave_gtk_main_iteration();
+	gtkwave_main_iteration();
 	ok_func();
 	}
 	else
@@ -309,15 +309,18 @@ fix_suffix:                     s2 = malloc_2(strlen(s) + strlen(suffix) + 1);
 	gtk_grab_remove(pFileChoose);
 	gtk_widget_destroy(pFileChoose);
 
-	gtkwave_gtk_main_iteration();
+	gtkwave_main_iteration();
 	if(GLOBALS->bad_cleanup_file_c_1) notok_func();
 	}
 #endif
 }
 
 /*
- * $Id: file.c,v 1.14 2009/12/15 23:40:59 gtkwave Exp $
+ * $Id: file.c,v 1.15 2010/02/18 23:06:04 gtkwave Exp $
  * $Log: file.c,v $
+ * Revision 1.15  2010/02/18 23:06:04  gtkwave
+ * change name of main iteration loop calls
+ *
  * Revision 1.14  2009/12/15 23:40:59  gtkwave
  * removed old style scripts; also removed tempfiles for Tcl args
  *
