@@ -196,12 +196,12 @@ unsigned int numalias = 0;
 unsigned int numvars = 0;
 struct symbol *sym_block = NULL;
 struct Node *node_block = NULL;
-JRB ptr, lst;
 struct fstHier *h = NULL;
 int msb, lsb;
 char *nnam = NULL, *pnam = NULL, *pnam2 = NULL;
 uint32_t activity_idx, num_activity_changes;
 struct tree *npar = NULL, *ppar = NULL;
+char **f_name = NULL;
 
 GLOBALS->fst_fst_c_1 = fstReaderOpen(fname);
 if(!GLOBALS->fst_fst_c_1)
@@ -215,6 +215,7 @@ exponent_to_time_scale(scale);
 
 GLOBALS->numfacs=fstReaderGetVarCount(GLOBALS->fst_fst_c_1);
 GLOBALS->mvlfacs_fst_c_3=(struct fac *)calloc_2(GLOBALS->numfacs,sizeof(struct fac));
+f_name = calloc_2(GLOBALS->numfacs,sizeof(char *));
 GLOBALS->fst_table_fst_c_1=(struct lx2_entry *)calloc_2(GLOBALS->numfacs, sizeof(struct lx2_entry));
 sym_block = (struct symbol *)calloc_2(GLOBALS->numfacs, sizeof(struct symbol));
 node_block=(struct Node *)calloc_2(GLOBALS->numfacs,sizeof(struct Node));
@@ -322,13 +323,13 @@ if(GLOBALS->numfacs)
 
 	if(was_packed)
 		{
-		GLOBALS->mvlfacs_fst_c_3[0].name = pnt;
+		f_name[0] = pnt;
 		}
 		else
 		{
 		int flen = strlen(fnam);
-		GLOBALS->mvlfacs_fst_c_3[0].name=malloc_2(flen+1);
-		strcpy(GLOBALS->mvlfacs_fst_c_3[0].name, fnam);
+		f_name[0]=malloc_2(flen+1);
+		strcpy(f_name[0], fnam);
 		}
 	}
 
@@ -361,6 +362,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
                 case FST_VT_VCD_PARAMETER: 	nvt = ND_VCD_PARAMETER; break;
                 case FST_VT_VCD_REAL: 		nvt = ND_VCD_REAL; break;
                 case FST_VT_VCD_REAL_PARAMETER: nvt = ND_VCD_REAL_PARAMETER; break;
+                case FST_VT_VCD_REALTIME:       nvt = ND_VCD_REALTIME; break;
                 case FST_VT_VCD_REG: 		nvt = ND_VCD_REG; break;
                 case FST_VT_VCD_SUPPLY0: 	nvt = ND_VCD_SUPPLY0; break;
                 case FST_VT_VCD_SUPPLY1: 	nvt = ND_VCD_SUPPLY1; break;
@@ -387,6 +389,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 		case FST_VT_VCD_REAL:
 		case FST_VT_VCD_REAL_PARAMETER:
+		case FST_VT_VCD_REALTIME:
 			GLOBALS->mvlfacs_fst_c_3[i].flags = VZT_RD_SYM_F_DOUBLE;
 			break;
 
@@ -451,27 +454,27 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 		if(was_packed)
 			{
-			GLOBALS->mvlfacs_fst_c_3[i+1].name = pnt;
+			f_name[i+1] = pnt;
 			}
 			else
 			{
 			int flen = strlen(fnam);
-			GLOBALS->mvlfacs_fst_c_3[i+1].name=malloc_2(flen+1);
-			strcpy(GLOBALS->mvlfacs_fst_c_3[i+1].name, fnam);
+			f_name[i+1]=malloc_2(flen+1);
+			strcpy(f_name[i+1], fnam);
 			}
 		}
 
 	if(i>1)
 		{
-		free_2(GLOBALS->mvlfacs_fst_c_3[i-2].name);
-		GLOBALS->mvlfacs_fst_c_3[i-2].name = NULL;
+		free_2(f_name[i-2]);
+		f_name[i-2] = NULL;
 		}
 
 	f=GLOBALS->mvlfacs_fst_c_3+i;
 
 	if((f->len>1)&& (!(f->flags&(VZT_RD_SYM_F_INTEGER|VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING))) )
 		{
-		int len=sprintf(buf, "%s[%d:%d]", GLOBALS->mvlfacs_fst_c_3[i].name,GLOBALS->mvlfacs_fst_c_3[i].msb, GLOBALS->mvlfacs_fst_c_3[i].lsb);
+		int len=sprintf(buf, "%s[%d:%d]", f_name[i],GLOBALS->mvlfacs_fst_c_3[i].msb, GLOBALS->mvlfacs_fst_c_3[i].lsb);
 		str=malloc_2(len+1);
 
 		if(!GLOBALS->alt_hier_delimeter)
@@ -491,13 +494,13 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		}
 	else if ( 
 			((f->len==1)&&(!(f->flags&(VZT_RD_SYM_F_INTEGER|VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))&&
-			((i!=GLOBALS->numfacs-1)&&(!strcmp(GLOBALS->mvlfacs_fst_c_3[i].name, GLOBALS->mvlfacs_fst_c_3[i+1].name))))
+			((i!=GLOBALS->numfacs-1)&&(!strcmp(f_name[i], f_name[i+1]))))
 			||
-			(((i!=0)&&(!strcmp(GLOBALS->mvlfacs_fst_c_3[i].name, GLOBALS->mvlfacs_fst_c_3[i-1].name))) &&
+			(((i!=0)&&(!strcmp(f_name[i], f_name[i-1]))) &&
 			(GLOBALS->mvlfacs_fst_c_3[i].msb!=-1)&&(GLOBALS->mvlfacs_fst_c_3[i].lsb!=-1))
 		)
 		{
-		int len = sprintf(buf, "%s[%d]", GLOBALS->mvlfacs_fst_c_3[i].name,GLOBALS->mvlfacs_fst_c_3[i].msb);
+		int len = sprintf(buf, "%s[%d]", f_name[i],GLOBALS->mvlfacs_fst_c_3[i].msb);
 		str=malloc_2(len+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
@@ -509,7 +512,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			}
 		s=&sym_block[i];
 	        symadd_name_exists_sym_exists(s,str,0);
-		if((prevsym)&&(i>0)&&(!strcmp(GLOBALS->mvlfacs_fst_c_3[i].name, GLOBALS->mvlfacs_fst_c_3[i-1].name)))	/* allow chaining for search functions.. */
+		if((prevsym)&&(i>0)&&(!strcmp(f_name[i], f_name[i-1])))	/* allow chaining for search functions.. */
 			{
 			prevsym->vec_root = prevsymroot;
 			prevsym->vec_chain = s;
@@ -526,14 +529,14 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		}
 		else
 		{
-		str=malloc_2(strlen(GLOBALS->mvlfacs_fst_c_3[i].name)+1);
+		str=malloc_2(strlen(f_name[i])+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
-			strcpy(str, GLOBALS->mvlfacs_fst_c_3[i].name);
+			strcpy(str, f_name[i]);
 			}
 			else
 			{
-			strcpy_vcdalt(str, GLOBALS->mvlfacs_fst_c_3[i].name, GLOBALS->alt_hier_delimeter);
+			strcpy_vcdalt(str, f_name[i], GLOBALS->alt_hier_delimeter);
 			}
 		s=&sym_block[i];
 	        symadd_name_exists_sym_exists(s,str,0);
@@ -549,28 +552,17 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		fst_append_graft_chain(strlen(pnam), pnam, i, ppar);
 		}
 		
-        if(!GLOBALS->firstnode)
-                {
-       	        GLOBALS->firstnode=GLOBALS->curnode=s;   
-                }
-                else
-                {
-                GLOBALS->curnode->nextinaet=s;
-                GLOBALS->curnode=s;   
-                }
-
         n=&node_block[i];
         n->nname=s->name;
         n->mv.mvlfac = GLOBALS->mvlfacs_fst_c_3+i;
 	GLOBALS->mvlfacs_fst_c_3[i].working_node = n;
 	n->vartype = nvt;
 
-	if((f->len>1)||(f->flags&&(VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))
+	if((f->len>1)||(f->flags&(VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))
 		{
-		ExtNode *ext = (ExtNode *)calloc_2(1,sizeof(struct ExtNode));
-		ext->msi = GLOBALS->mvlfacs_fst_c_3[i].msb;
-		ext->lsi = GLOBALS->mvlfacs_fst_c_3[i].lsb;
-		n->ext = ext;
+		n->msi = GLOBALS->mvlfacs_fst_c_3[i].msb;
+		n->lsi = GLOBALS->mvlfacs_fst_c_3[i].lsb;
+		n->extvals = 1;
 		}
                  
         n->head.time=-1;        /* mark 1st node as negative time */
@@ -583,12 +575,13 @@ if(pnam) { free_2(pnam); pnam = NULL; }
 
 for(i=0;((i<2)&&(i<GLOBALS->numfacs));i++)
 	{
-	if(GLOBALS->mvlfacs_fst_c_3[i].name)
+	if(f_name[i])
 		{
-		free_2(GLOBALS->mvlfacs_fst_c_3[i].name);
-		GLOBALS->mvlfacs_fst_c_3[i].name = NULL;
+		free_2(f_name[i]);
+		f_name[i] = NULL;
 		}
 	}
+free_2(f_name); f_name = NULL;
 
 fprintf(stderr, FST_RDLOAD"Built %d signal%s and %d alias%s.\n", 
 	numvars, (numvars == 1) ? "" : "s", 
@@ -599,26 +592,15 @@ GLOBALS->fst_maxhandle = numvars;
 /* SPLASH */                            splash_sync(2, 5);  
 GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
 
-GLOBALS->pfx_hier_array = calloc_2(GLOBALS->hier_pfx_cnt ? GLOBALS->hier_pfx_cnt : 1, sizeof(char *));
-         
-lst = GLOBALS->hier_pfx;
-if(lst)  
-        {
-        jrb_traverse(ptr, lst)
-                {
-                GLOBALS->pfx_hier_array[ptr->val.ui] = ptr->key.s;
-                }
-        }
+create_hier_array();
 
-if(1)
+if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
         {
-        GLOBALS->curnode=GLOBALS->firstnode;
         for(i=0;i<GLOBALS->numfacs;i++)
                 {
                 int len;
-                GLOBALS->facs[i]=GLOBALS->curnode; 
-                if((len=strlen(GLOBALS->curnode->name))>GLOBALS->longestname) GLOBALS->longestname=len;
-                GLOBALS->curnode=GLOBALS->curnode->nextinaet;
+                GLOBALS->facs[i]=&sym_block[i]; 
+                if((len=strlen(GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
                 }
                                 
 /* SPLASH */                            splash_sync(3, 5);  
@@ -635,6 +617,89 @@ if(1)
         order_facs_from_treesort(GLOBALS->treeroot, &GLOBALS->facs);
         GLOBALS->facs_are_sorted=1;
         }
+        else
+	{
+	for(i=0;i<GLOBALS->numfacs;i++)
+		{
+		char *subst, ch;
+		int len;
+		int esc = 0;
+
+		GLOBALS->facs[i]=&sym_block[i];
+	        if((len=strlen(subst=GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
+		while((ch=(*subst)))
+			{	
+#ifdef WAVE_HIERFIX
+	                if(ch==GLOBALS->hier_delimeter) { *subst=(!esc) ? VCDNAM_HIERSORT : VCDNAM_ESCAPE; }    /* forces sort at hier boundaries */
+#else
+	                if((ch==GLOBALS->hier_delimeter)&&(esc)) { *subst = VCDNAM_ESCAPE; }    /* forces sort at hier boundaries */
+#endif
+	                else if(ch=='\\') { esc = 1; GLOBALS->escaped_names_found_vcd_c_1 = 1; }
+	                subst++;
+			}
+		}
+
+/* SPLASH */                            splash_sync(3, 5);
+	fprintf(stderr, FST_RDLOAD"Sorting facilities at hierarchy boundaries.\n");
+	wave_heapsort(GLOBALS->facs,GLOBALS->numfacs);
+
+#ifdef WAVE_HIERFIX	
+	for(i=0;i<GLOBALS->numfacs;i++)
+		{
+		char *subst, ch;
+	
+		subst=GLOBALS->facs[i]->name;
+		while((ch=(*subst)))
+			{	
+			if(ch==VCDNAM_HIERSORT) { *subst=GLOBALS->hier_delimeter; }	/* restore back to normal */
+			subst++;
+			}
+		}
+#endif
+
+	GLOBALS->facs_are_sorted=1;
+
+/* SPLASH */                            splash_sync(4, 5);
+	fprintf(stderr, FST_RDLOAD"Building facility hierarchy tree.\n");
+
+	init_tree();		
+	for(i=0;i<GLOBALS->numfacs;i++)	
+		{
+		char *nf = GLOBALS->facs[i]->name;
+		int was_packed;
+		char *recon = hier_decompress_flagged(nf, &was_packed);
+                
+		if(was_packed)   
+		        {
+		        build_tree_from_name(recon, i);
+		        free_2(recon);
+		        }
+		        else
+		        {
+		        build_tree_from_name(nf, i);
+		        }
+		}
+/* SPLASH */                            splash_sync(5, 5);
+	if(GLOBALS->escaped_names_found_vcd_c_1)
+	        {
+		for(i=0;i<GLOBALS->numfacs;i++)
+			{
+		        char *subst, ch;
+		        subst=GLOBALS->facs[i]->name;
+		        while((ch=(*subst)))
+		                {
+		                if(ch==VCDNAM_ESCAPE) { *subst=GLOBALS->hier_delimeter; } /* restore back to normal */
+		                subst++;
+		                }
+			}
+	        }
+	treegraft(&GLOBALS->treeroot);
+	treesort(GLOBALS->treeroot, NULL);
+	if(GLOBALS->escaped_names_found_vcd_c_1)  
+	        {
+	        treenamefix(GLOBALS->treeroot);   
+	        }
+	}
 
 if(GLOBALS->prev_hier_uncompressed_name) 
 	{
@@ -884,7 +949,9 @@ l2e->numtrans++;
  */
 static void fst_resolver(nptr np, nptr resolve)
 { 
-np->ext = resolve->ext;
+np->extvals = resolve->extvals;
+np->msi = resolve->msi;
+np->lsi = resolve->lsi;
 memcpy(&np->head, &resolve->head, sizeof(struct HistEnt));
 np->curr = resolve->curr;
 np->harray = resolve->harray;
@@ -1192,8 +1259,29 @@ for(txidxi=0;txidxi<GLOBALS->fst_maxhandle;txidxi++)
 }
 
 /*
- * $Id: fst.c,v 1.19 2009/08/06 20:03:31 gtkwave Exp $
+ * $Id: fst.c,v 1.26 2010/03/14 07:09:49 gtkwave Exp $
  * $Log: fst.c,v $
+ * Revision 1.26  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.25  2010/03/13 21:38:16  gtkwave
+ * fixed && used in logical operations for allocating ExtNode
+ *
+ * Revision 1.24  2010/03/13 19:16:00  gtkwave
+ * removal of useless symbol->nextinaet code
+ *
+ * Revision 1.23  2010/03/12 16:11:49  gtkwave
+ * added missing hierarchy boundary sort
+ *
+ * Revision 1.22  2010/03/11 23:31:52  gtkwave
+ * remove name field from struct fac
+ *
+ * Revision 1.21  2010/03/01 05:16:26  gtkwave
+ * move compressed hier tree traversal to hierpack
+ *
+ * Revision 1.20  2010/02/22 21:13:36  gtkwave
+ * added "realtime" VCD variable
+ *
  * Revision 1.19  2009/08/06 20:03:31  gtkwave
  * warnings fixes
  *
