@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007-2009.
+ * Copyright (c) Kermin Elliott Fleming 2007-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -44,6 +44,7 @@
 #include "lxt2_read.h"
 #include "vzt_read.h"
 #include "fst.h"
+#include "hierpack.h"
 
 #ifdef __MINGW32__
 #define sleep(x) Sleep(x)
@@ -93,6 +94,7 @@ TR_RJUSTIFY, /* default_flags 5 */
 {0, 0, 0, 0, 0, 0, 0}, /* tims 6 */
 {0, 0, NULL, NULL, NULL, NULL, 0, NULL, NULL}, /* traces 9 */
 0, /* hier_max_level 8 */
+0, /* hier_max_level_shadow */
 0, /* timestart_from_savefile */
 0, /* timestart_from_savefile_valid */
 0, /* group_depth */
@@ -135,6 +137,7 @@ NULL, /* busycursor_busy_c_1 23 */
 -1, /* color_back 25 */
 -1, /* color_baseline 26 */
 -1, /* color_grid 27 */
+-1, /* color_grid2 27 */
 -1, /* color_high 28 */
 -1, /* color_low 29 */
 -1, /* color_mark 30 */
@@ -281,8 +284,6 @@ NULL, /* double_fini_fst */
  * ghw.c
  */
 0, /* nxp_ghw_c_1 93 */
-NULL, /* sym_head_ghw_c_1 94 */
-NULL,
 0, /* sym_which_ghw_c_1 95 */
 NULL, /* gwt_ghw_c_1 96 */
 NULL, /* gwt_corr_ghw_c_1 97 */
@@ -292,7 +293,6 @@ NULL, /* asbuf */
 0, /* nbr_sig_ref_ghw_c_1 101 */
 0, /* num_glitches_ghw_c_1 102 */
 0, /*  num_glitch_regions_ghw_c_1 */
-{0, 0 }, /* dummy_en_ghw_c_1 103 */
 0, /* fac_name_ghw_c_1 104 */
 0, /* fac_name_len_ghw_c_1 105 */
 0, /* fac_name_max_ghw_c_1 106 */
@@ -425,6 +425,8 @@ NULL, /* lt_buf_lxt_c_1 183 */
 0, /* double_is_native_lxt_c_1 187 */
 0, /* max_compare_time_tc_lxt_c_2 189 */
 0, /* max_compare_pos_tc_lxt_c_2 */
+NULL, /* resolve_lxt_alias_to */
+NULL, /* lastchange */
 
 
 /* 
@@ -797,33 +799,37 @@ NULL, /* bold_tag_status_c_3 401 */
 /*
  * strace.c
  */
-NULL, /* timearray 402 */
-0, /* timearray_size 403 */
-NULL, /* ptr_mark_count_label_strace_c_1 404 */
-NULL, /* straces 405 */
-NULL, /* shadow_straces 406 */
-NULL, /* strace_defer_free_head 407 */
-NULL, /* window_strace_c_10 408 */
-NULL, /* cleanup_strace_c_7 409 */
-{0,0,0,0,0,0}, /* logical_mutex 412 */
-{0,0,0,0,0,0}, /* shadow_logical_mutex 413 */
-0, /* shadow_active 414 */
-0, /* shadow_type 415 */
-NULL, /* shadow_string 416 */
-0, /* mark_idx_start 417 */
-0, /* mark_idx_end 418 */
-0, /* shadow_mark_idx_start 419 */
-0, /* shadow_mark_idx_end 420 */
-NULL, /* mprintf_buff_head 423 */
-NULL, /* mprintf_buff_current */
+NULL, /* strace_ctx (defined in strace.h for multiple strace sessions) */
+
+{
+{NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0,{0,0,0,0,0,0},{0,0,0,0,0,0},0,0,0,0,0,0,0},  /* strace_windows[0] */
+#ifdef WAVE_USE_GTK2
+ {NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0,{0,0,0,0,0,0},{0,0,0,0,0,0},0,0,0,0,0,0,0}
+#endif
+}, /* strace_windows[1] */
+#if WAVE_NUM_STRACE_WINDOWS != 2
+#ifdef WAVE_USE_GTK2
+#error the number of strace windows as defined in strace.h does not match globals.c!
+#else
+#if WAVE_NUM_STRACE_WINDOWS != 1
+#error gtk1 only supports 1 strace window, sorry!
+#endif
+#endif
+#endif
+0, /* strace_current_window */
 
 
 /*
  * symbol.c
  */
-NULL, /* sym 424 */
+#ifdef _WAVE_HAVE_JUDY
+NULL, /* sym_judy */
+NULL, /* s_selected */
+#endif
+NULL, /* sym_hash 424 */
 NULL, /* facs 425 */
 0, /* facs_are_sorted 426 */
+0, /* facs_have_symbols_state_machine */
 0, /* numfacs 427 */
 0, /* regions 428 */
 0, /* longestname 429 */
@@ -1145,10 +1151,12 @@ NULL, /* wavepixmap_wavewindow_c_1 621 */
 NULL, /* wave_vslider 622 */
 NULL, /* wave_hslider */
 {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, /* named_markers 623 */
+-1, /* named_marker_lock_idx */
 0, /* made_gc_contexts_wavewindow_c_1 624 */
 NULL, /* gc_back_wavewindow_c_1 625 */
 NULL, /* gc_baseline_wavewindow_c_1 626 */
 NULL, /* gc_grid_wavewindow_c_1 627 */
+NULL, /* gc_grid2_wavewindow_c_1 627 */
 NULL, /* gc_time_wavewindow_c_1 628 */
 NULL, /* gc_timeb_wavewindow_c_1 629 */
 NULL, /* gc_value_wavewindow_c_1 630 */
@@ -1194,6 +1202,7 @@ NULL, /* gccache_gmstrd */
 NULL, /* gccache_back_wavewindow_c_1 */
 NULL, /* gccache_baseline_wavewindow_c_1 */
 NULL, /* gccache_grid_wavewindow_c_1 */
+NULL, /* gccache_grid2_wavewindow_c_1 */
 NULL, /* gccache_time_wavewindow_c_1 */
 NULL, /* gccache_timeb_wavewindow_c_1 */
 NULL, /* gccache_value_wavewindow_c_1 */
@@ -1215,7 +1224,7 @@ NULL, /* gccache_wfill_wavewindow_c_1 */
 NULL, /* gccache_w_wavewindow_c_1 */
 NULL, /* gccache_dashfill_wavewindow_c_1 */
 NULL, /* gccache_dash_wavewindow_c_1 */
-
+20, /* analog_redraw_skip_count */
 /*
  * zoombuttons.c
  */
@@ -1247,6 +1256,8 @@ g->regexp_string_menu_c_1 = calloc_2_into_context(g, 1, 129);
 g->regex_ok_regex_c_1 = calloc_2_into_context(g, WAVE_REGEX_TOTAL, sizeof(int));
 g->preg_regex_c_1 = calloc_2_into_context(g, WAVE_REGEX_TOTAL, sizeof(regex_t));
 
+g->strace_ctx = &g->strace_windows[0];			/* arbitrarily point to first one */
+
 return(g);						/* what to do with ctx is at discretion of caller */
 }
 
@@ -1306,6 +1317,7 @@ void reload_into_new_context(void)
  char *save_tmpfilename = NULL;
  char *reload_tmpfilename = NULL;
  int fd_dummy = -1;
+ int s_ctx_iter;
 
  /* save these in case we decide to write out the rc file later as a user option */
  char cached_ignore_savefile_pos = GLOBALS->ignore_savefile_pos;
@@ -1324,7 +1336,7 @@ void reload_into_new_context(void)
  if(GLOBALS->text_status_c_2)
 	{
 	gtk_grab_add(GLOBALS->text_status_c_2);			/* grab focus to a known widget with no real side effects */
-	gtkwave_gtk_main_iteration();				/* spin on GTK event loop */
+	gtkwave_main_iteration();				/* spin on GTK event loop */
 	gtk_grab_remove(GLOBALS->text_status_c_2);		/* ungrab focus */
 	}
 
@@ -1390,6 +1402,7 @@ void reload_into_new_context(void)
  
  /* Marker positions */
  memcpy(new_globals->named_markers, GLOBALS->named_markers, sizeof(GLOBALS->named_markers));
+ new_globals->named_marker_lock_idx = GLOBALS->named_marker_lock_idx;
 
  /* notebook page flipping */
  new_globals->num_notebook_pages = GLOBALS->num_notebook_pages;
@@ -1436,6 +1449,7 @@ void reload_into_new_context(void)
  new_globals->gc_back_wavewindow_c_1 = GLOBALS->gc_back_wavewindow_c_1;
  new_globals->gc_baseline_wavewindow_c_1 = GLOBALS->gc_baseline_wavewindow_c_1;
  new_globals->gc_grid_wavewindow_c_1 = GLOBALS->gc_grid_wavewindow_c_1;
+ new_globals->gc_grid2_wavewindow_c_1 = GLOBALS->gc_grid2_wavewindow_c_1;
  new_globals->gc_time_wavewindow_c_1 = GLOBALS->gc_time_wavewindow_c_1;
  new_globals->gc_timeb_wavewindow_c_1 = GLOBALS->gc_timeb_wavewindow_c_1;
  new_globals->gc_value_wavewindow_c_1 = GLOBALS->gc_value_wavewindow_c_1;
@@ -1469,7 +1483,7 @@ void reload_into_new_context(void)
  new_globals->gccache_gmstrd = GLOBALS->gccache_gmstrd;
  new_globals->gccache_back_wavewindow_c_1 = GLOBALS->gccache_back_wavewindow_c_1;
  new_globals->gccache_baseline_wavewindow_c_1 = GLOBALS->gccache_baseline_wavewindow_c_1;
- new_globals->gccache_grid_wavewindow_c_1 = GLOBALS->gccache_grid_wavewindow_c_1;
+ new_globals->gccache_grid2_wavewindow_c_1 = GLOBALS->gccache_grid2_wavewindow_c_1;
  new_globals->gccache_time_wavewindow_c_1 = GLOBALS->gccache_time_wavewindow_c_1;
  new_globals->gccache_timeb_wavewindow_c_1 = GLOBALS->gccache_timeb_wavewindow_c_1;
  new_globals->gccache_value_wavewindow_c_1 = GLOBALS->gccache_value_wavewindow_c_1;
@@ -1568,6 +1582,7 @@ void reload_into_new_context(void)
  new_globals->color_back = GLOBALS->color_back;
  new_globals->color_baseline = GLOBALS->color_baseline;
  new_globals->color_grid = GLOBALS->color_grid;
+ new_globals->color_grid2 = GLOBALS->color_grid2;
  new_globals->color_high = GLOBALS->color_high;
  new_globals->color_low = GLOBALS->color_low;
  new_globals->color_1 = GLOBALS->color_1;
@@ -1621,6 +1636,7 @@ void reload_into_new_context(void)
  new_globals->sst_expanded = GLOBALS->sst_expanded;
  new_globals->hier_grouping = GLOBALS->hier_grouping;
  new_globals->hier_max_level = GLOBALS->hier_max_level;
+ new_globals->hier_max_level_shadow = GLOBALS->hier_max_level_shadow;
  new_globals->paned_pack_semantics = GLOBALS->paned_pack_semantics;
  new_globals->left_justify_sigs = GLOBALS->left_justify_sigs;
  new_globals->lxt_clock_compress_to_z = GLOBALS->lxt_clock_compress_to_z;
@@ -1667,8 +1683,7 @@ void reload_into_new_context(void)
  new_globals->repscript_period = GLOBALS->repscript_period;
 
  /* hierarchy handling from vcd.c */
- if(GLOBALS->hier_pfx) { jrb_free_tree(GLOBALS->hier_pfx); GLOBALS->hier_pfx = NULL; }
-
+ free_hier_tree();
 
  /* vlist.c */
  if(GLOBALS->vlist_handle)
@@ -1798,7 +1813,11 @@ void reload_into_new_context(void)
 
  /* remaining windows which are completely destroyed and haven't migrated over */
  widget_only_destroy(&GLOBALS->window_ptranslate_c_5);		/* ptranslate.c */
- widget_only_destroy(&GLOBALS->window_strace_c_10);		/* strace.c */
+ WAVE_STRACE_ITERATOR(s_ctx_iter)
+	{
+	GLOBALS->strace_ctx = &GLOBALS->strace_windows[GLOBALS->strace_current_window = s_ctx_iter];
+	widget_only_destroy(&GLOBALS->strace_ctx->window_strace_c_10);	/* strace.c */
+	}
  widget_only_destroy(&GLOBALS->window_translate_c_11);		/* translate.c */
  widget_only_destroy(&GLOBALS->window_treesearch_gtk1_c);	/* treesearch_gtk1.c */
  widget_only_destroy(&GLOBALS->window_help_c_2); 		/* help.c : reload is gated off during help so this should never execute */
@@ -1894,7 +1913,7 @@ void reload_into_new_context(void)
  dead_context_sweep();
 
  /* let any destructors finalize on GLOBALS dereferences... */
- gtkwave_gtk_main_iteration();
+ gtkwave_main_iteration();
 
  /* Free the old context */
  free_outstanding();
@@ -1907,10 +1926,6 @@ void reload_into_new_context(void)
  set_GLOBALS(new_globals);
  *(GLOBALS->gtk_context_bridge_ptr) = GLOBALS;
 
-
- /* Initialize new variables */
- GLOBALS->sym=(struct symbol **)calloc_2(SYMPRIME,sizeof(struct symbol *));
-
  init_filetrans_data();
  init_proctrans_data();
  /* load_all_fonts(); */
@@ -1974,8 +1989,6 @@ void reload_into_new_context(void)
 
 			if(!setjmp(*(GLOBALS->vcd_jmp_buf)))			/* loader exception handling */
 				{
-				void **t, **t2;
-
 				switch(GLOBALS->loaded_file_type)		/* on fail, longjmp called in these loaders */
 					{			
 			   		case LXT_FILE: lxt_main(GLOBALS->loaded_file_name); break;
@@ -1984,6 +1997,27 @@ void reload_into_new_context(void)
 					default: break;
 					}
 				
+#ifdef _WAVE_HAVE_JUDY
+				{
+				Pvoid_t  PJArray = (Pvoid_t)setjmp_globals->alloc2_chain;
+				int rcValue;
+				Word_t Index;
+				JError_t JError;
+
+				Index = 0;
+				for (rcValue = Judy1First(PJArray, &Index, &JError); rcValue != 0; rcValue = Judy1Next(PJArray, &Index, &JError))
+					{
+				        JError_t JError;
+				        Judy1Set ((Pvoid_t)&GLOBALS->alloc2_chain, Index, &JError);
+					}
+
+				GLOBALS->outstanding += setjmp_globals->outstanding;
+				Judy1FreeArray(&PJArray, &JError);
+				}
+#else
+				{
+				void **t, **t2;
+
 				t = (void **)setjmp_globals->alloc2_chain;
 				while(t)
 					{
@@ -2005,6 +2039,8 @@ void reload_into_new_context(void)
 						break;					
 						}
 					}
+				}
+#endif
 				free(GLOBALS->vcd_jmp_buf); GLOBALS->vcd_jmp_buf = NULL;
 				free(setjmp_globals); setjmp_globals = NULL;
 
@@ -2082,6 +2118,9 @@ void reload_into_new_context(void)
 		}
 	}
 
+ /* deallocate the symbol hash table */
+ sym_hash_destroy(GLOBALS);
+
  /* Setup timings we probably need to redraw here */
  GLOBALS->tims.last=GLOBALS->max_time;
  GLOBALS->tims.first=GLOBALS->min_time;
@@ -2306,6 +2345,8 @@ void reload_into_new_context(void)
  */
 void free_and_destroy_page_context(void)
 {
+ int s_ctx_iter;
+
  /* deallocate any loader-related stuff */
  switch(GLOBALS->loaded_file_type) {
    case LXT_FILE:
@@ -2338,7 +2379,12 @@ void free_and_destroy_page_context(void)
  /* window destruction (of windows that aren't the parent window) */
 
  widget_only_destroy(&GLOBALS->window_ptranslate_c_5);		/* ptranslate.c */
- widget_only_destroy(&GLOBALS->window_strace_c_10);		/* strace.c */
+
+ WAVE_STRACE_ITERATOR(s_ctx_iter)                                
+        {
+        GLOBALS->strace_ctx = &GLOBALS->strace_windows[GLOBALS->strace_current_window = s_ctx_iter];
+	widget_only_destroy(&GLOBALS->strace_ctx->window_strace_c_10);	/* strace.c */
+	}
  widget_only_destroy(&GLOBALS->window_translate_c_11);		/* translate.c */
  widget_only_destroy(&GLOBALS->window_treesearch_gtk1_c);	/* treesearch_gtk1.c */
  widget_only_destroy(&GLOBALS->window_treesearch_gtk2_c_12);	/* treesearch_gtk2.c */
@@ -2369,7 +2415,7 @@ void free_and_destroy_page_context(void)
  (*GLOBALS->dead_context)[0] = GLOBALS;
 
  /* let any destructors finalize on GLOBALS dereferences... */
- gtkwave_gtk_main_iteration();
+ gtkwave_main_iteration();
 }
 
 
