@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007-2009.
+ * Copyright (c) Kermin Elliott Fleming 2007-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -57,6 +57,10 @@
 #include "jrb.h"
 #include "extload.h"
 
+#ifdef _WAVE_HAVE_JUDY
+#include <Judy.h>
+#endif
+
 
 struct Global{ 
 
@@ -91,6 +95,7 @@ unsigned int default_flags; /* from analyzer.c 5 */
 Times tims; /* from analyzer.c 6 */
 Traces traces; /* from analyzer.c 7 */
 int hier_max_level; /* from analyzer.c 8 */
+int hier_max_level_shadow; /* from analyzer.c */
 TimeType timestart_from_savefile;
 char timestart_from_savefile_valid;
 int group_depth;
@@ -132,6 +137,7 @@ int busy_busy_c_1; /* from busy.c 24 */
 int color_back; /* from color.c 25  */
 int color_baseline; /* from color.c 26 */
 int color_grid; /* from color.c 27 */
+int color_grid2; /* from color.c */
 int color_high; /* from color.c 28 */
 int color_low; /* from color.c 29 */
 int color_mark; /* from color.c 30 */
@@ -277,8 +283,6 @@ double *double_fini_fst;
  * ghw.c
  */
 struct Node **nxp_ghw_c_1; /* from ghw.c 95 */
-struct symbol *sym_head_ghw_c_1; /* from ghw.c 96 */
-struct symbol *sym_curr_ghw_c_1; /* from ghw.c 97 */
 int sym_which_ghw_c_1; /* from ghw.c 98 */
 struct ghw_tree_node *gwt_ghw_c_1; /* from ghw.c 99 */
 struct ghw_tree_node *gwt_corr_ghw_c_1; /* from ghw.c 100 */
@@ -288,7 +292,6 @@ char *asbuf; /* from ghw.c 103 */
 int nbr_sig_ref_ghw_c_1; /* from ghw.c 104 */
 int num_glitches_ghw_c_1; /* from ghw.c 105 */
 int num_glitch_regions_ghw_c_1; /* from ghw.c 106 */
-struct ExtNode dummy_en_ghw_c_1; /* from ghw.c 107 */
 char *fac_name_ghw_c_1; /* from ghw.c 108 */
 int fac_name_len_ghw_c_1; /* from ghw.c 109 */
 int fac_name_max_ghw_c_1; /* from ghw.c 110 */
@@ -422,6 +425,8 @@ unsigned char double_mask_lxt_c_1[8]; /* from lxt.c 196 */
 char double_is_native_lxt_c_1; /* from lxt.c 197 */
 int max_compare_time_tc_lxt_c_2; /* from lxt.c 199 */
 int max_compare_pos_tc_lxt_c_2; /* from lxt.c 200 */
+struct Node **resolve_lxt_alias_to;
+unsigned int *lastchange;
 
 
 /*
@@ -460,7 +465,7 @@ char *aet_name; /* from main.c 205 */
 struct gtkwave_annotate_ipc_t *anno_ctx; /* from main.c 206 */
 struct gtkwave_dual_ipc_t *dual_ctx; /* from main.c 207 */
 int dual_id; /* from main.c 208 */
-int dual_attach_id_main_c_1; /* from main.c 209 */
+unsigned int dual_attach_id_main_c_1; /* from main.c 209 */
 int dual_race_lock; /* from main.c 210 */
 GtkWidget *mainwindow; /* from main.c 211 */
 GtkWidget *signalwindow; /* from main.c 212 */
@@ -792,38 +797,27 @@ GtkTextTag *bold_tag_status_c_3; /* from status.c 429 */
 /*
  * strace.c
  */
-TimeType *timearray; /* from strace.c 430 */
-int timearray_size; /* from strace.c 431 */
-GtkWidget *ptr_mark_count_label_strace_c_1; /* from strace.c 432 */
-struct strace *straces; /* from strace.c 433 */
-struct strace *shadow_straces; /* from strace.c 434 */
-struct strace_defer_free *strace_defer_free_head; /* from strace.c 435 */
-GtkWidget *window_strace_c_10; /* from strace.c 436 */
-void (*cleanup_strace_c_7)(); /* from strace.c 437 */
-char logical_mutex[6]; /* from strace.c 440 */
-char shadow_logical_mutex[6]; /* from strace.c 441 */
-char shadow_active; /* from strace.c 442 */
-char shadow_type; /* from strace.c 443 */
-char *shadow_string; /* from strace.c 444 */
-signed char mark_idx_start; /* from strace.c 445 */
-signed char mark_idx_end; /* from strace.c 446 */
-signed char shadow_mark_idx_start; /* from strace.c 447 */
-signed char shadow_mark_idx_end; /* from strace.c 448 */
-struct mprintf_buff_t *mprintf_buff_head; /* from strace.c 451 */
-struct mprintf_buff_t *mprintf_buff_current; /* from strace.c 452 */
+struct strace_ctx_t *strace_ctx; /* moved to strace.h */
+struct strace_ctx_t strace_windows[WAVE_NUM_STRACE_WINDOWS];
+int strace_current_window;
 
 
 /*
  * symbol.c
  */
-struct symbol **sym; /* from symbol.c 453 */
+#ifdef _WAVE_HAVE_JUDY
+Pvoid_t sym_judy; /* from symbol.c */
+Pvoid_t s_selected; /* from symbol.c */
+#endif
+struct symbol **sym_hash; /* from symbol.c 453 */
 struct symbol **facs; /* from symbol.c 454 */
 char facs_are_sorted; /* from symbol.c 455 */
+char facs_have_symbols_state_machine; /* from symbol.c */
 int numfacs; /* from symbol.c 456 */
 int regions; /* from symbol.c 457 */
 int longestname; /* from symbol.c 458 */
-struct symbol *firstnode; /* from symbol.c 459 */
-struct symbol *curnode; /* from symbol.c 460 */
+struct symchain *firstnode; /* from symbol.c 459 */
+struct symchain *curnode; /* from symbol.c 460 */
 int hashcache; /* from symbol.c 461 */
 
 
@@ -1140,10 +1134,12 @@ GdkDrawable *wavepixmap_wavewindow_c_1; /* from wavewindow.c 680 */
 GtkObject *wave_vslider; /* from wavewindow.c 681 */
 GtkObject *wave_hslider; /* from wavewindow.c 682 */
 TimeType named_markers[26]; /* from wavewindow.c 683 */
+int named_marker_lock_idx; /* from menu.c */
 char made_gc_contexts_wavewindow_c_1; /* from wavewindow.c 684 */
 GdkGC *gc_back_wavewindow_c_1; /* from wavewindow.c 685 */
 GdkGC *gc_baseline_wavewindow_c_1; /* from wavewindow.c 686 */
 GdkGC *gc_grid_wavewindow_c_1; /* from wavewindow.c 687 */
+GdkGC *gc_grid2_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gc_time_wavewindow_c_1; /* from wavewindow.c 688 */
 GdkGC *gc_timeb_wavewindow_c_1; /* from wavewindow.c 689 */
 GdkGC *gc_value_wavewindow_c_1; /* from wavewindow.c 690 */
@@ -1189,6 +1185,7 @@ GdkGC *gccache_gmstrd; /* from wavewindow.c */
 GdkGC *gccache_back_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gccache_baseline_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gccache_grid_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_grid2_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gccache_time_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gccache_timeb_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gccache_value_wavewindow_c_1; /* from wavewindow.c */
@@ -1210,6 +1207,7 @@ GdkGC *gccache_wfill_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gccache_w_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gccache_dashfill_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gccache_dash_wavewindow_c_1; /* from wavewindow.c */
+int analog_redraw_skip_count; /* from wavewindow.c */
 
 /*
  * zoombuttons.c
