@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Tony Bybell.
+ * Copyright (c) 2009-2010 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -23,6 +23,10 @@
 #ifndef FST_API_H
 #define FST_API_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -84,7 +88,8 @@ enum fstVarType {
     FST_VT_VCD_WOR             = 17,
     FST_VT_VCD_PORT            = 18,
     FST_VT_VCD_ARRAY           = 19,	/* used to define the rownum (index) port on the array */
-    FST_VT_VCD_MAX             = 19,	/* end of VCD datatypes */
+    FST_VT_VCD_REALTIME        = 20,
+    FST_VT_VCD_MAX             = 20,	/* end of VCD datatypes */
 
     FST_VT_GEN_STRING	       = 254,	/* generic string type   (max len is defined as the len in fstWriterCreateVar() */
     FST_VT_GEN_MEMBLOCK	       = 255	/* generic memblock type (max len is defined as the len in fstWriterCreateVar() */
@@ -205,4 +210,8 @@ int fstReaderIterBlocks(void *ctx,
 
 char *fstReaderGetValueFromHandleAtTime(void *ctx, uint64_t tim, fstHandle facidx, char *buf);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
