@@ -316,7 +316,7 @@ for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBA
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=GLOBALS->autocoalesce;
+		set_s_selected(s->vec_root, GLOBALS->autocoalesce);
 		}
         }
 
@@ -332,7 +332,7 @@ if(GLOBALS->is_lx2)
 		t=s->vec_root;
 		if((t)&&(GLOBALS->autocoalesce))
 			{
-			if(t->selected)
+			if(get_s_selected(t))
 				{
 				while(t)
 					{
@@ -370,9 +370,9 @@ for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBA
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
 		{
-		if(t->selected)
+		if(get_s_selected(t))
 			{
-			t->selected=0;
+			set_s_selected(t, 0);
 			len=0;
 			while(t)
 				{
@@ -416,7 +416,7 @@ for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBA
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=GLOBALS->autocoalesce;
+		set_s_selected(s->vec_root, GLOBALS->autocoalesce);
 		}
         }
 
@@ -432,7 +432,7 @@ if(GLOBALS->is_lx2)
 		t=s->vec_root;
 		if((t)&&(GLOBALS->autocoalesce))
 			{
-			if(t->selected)
+			if(get_s_selected(t))
 				{
 				while(t)
 					{
@@ -470,9 +470,9 @@ for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBA
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
 		{
-		if(t->selected)
+		if(get_s_selected(t))
 			{
-			t->selected=0;
+			set_s_selected(t, 0);
 			len=0;
 			while(t)
 				{
@@ -529,7 +529,7 @@ for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBA
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=GLOBALS->autocoalesce;
+		set_s_selected(s->vec_root, GLOBALS->autocoalesce);
 		}
         }
 
@@ -545,7 +545,7 @@ if(GLOBALS->is_lx2)
 		t=s->vec_root;
 		if((t)&&(GLOBALS->autocoalesce))
 			{
-			if(t->selected)
+			if(get_s_selected(t))
 				{
 				while(t)
 					{
@@ -583,9 +583,9 @@ for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBA
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
 		{
-		if(t->selected)
+		if(get_s_selected(t))
 			{
-			t->selected=0;
+			set_s_selected(t, 0);
 			len=0;
 			while(t)
 				{
@@ -979,8 +979,11 @@ void hier_searchbox(char *title, GtkSignalFunc func)
 }
 
 /*
- * $Id: hiersearch.c,v 1.7 2008/12/18 01:31:30 gtkwave Exp $
+ * $Id: hiersearch.c,v 1.8 2010/03/16 21:01:09 gtkwave Exp $
  * $Log: hiersearch.c,v $
+ * Revision 1.8  2010/03/16 21:01:09  gtkwave
+ * remove selected member of struct symbol
+ *
  * Revision 1.7  2008/12/18 01:31:30  gtkwave
  * integrated experimental autoscroll code on signal adds
  *
