@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2003-2009.
+ * Copyright (c) Tony Bybell 2003-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,7 +41,7 @@ signed char scale;
 unsigned int numalias = 0;
 struct symbol *sym_block = NULL;
 struct Node *node_block = NULL;
-JRB ptr, lst;
+char **f_name = NULL;
 
 GLOBALS->lx2_lx2_c_1 = lxt2_rd_init(fname);
 if(!GLOBALS->lx2_lx2_c_1)
@@ -58,6 +58,7 @@ exponent_to_time_scale(scale);
 
 GLOBALS->numfacs=lxt2_rd_get_num_facs(GLOBALS->lx2_lx2_c_1);
 GLOBALS->mvlfacs_lx2_c_1=(struct fac *)calloc_2(GLOBALS->numfacs,sizeof(struct fac));
+f_name = calloc_2(GLOBALS->numfacs,sizeof(char *));
 GLOBALS->lx2_table_lx2_c_1=(struct lx2_entry *)calloc_2(GLOBALS->numfacs, sizeof(struct lx2_entry));
 sym_block = (struct symbol *)calloc_2(GLOBALS->numfacs, sizeof(struct symbol));
 node_block=(struct Node *)calloc_2(GLOBALS->numfacs,sizeof(struct Node));
@@ -98,13 +99,13 @@ if(GLOBALS->numfacs)
 
         if(was_packed)
                 {
-                GLOBALS->mvlfacs_lx2_c_1[0].name = pnt;
+                f_name[0] = pnt;
                 }
                 else
                 {
 		int flen = strlen(fnam);
-		GLOBALS->mvlfacs_lx2_c_1[0].name=malloc_2(flen+1);
-		strcpy(GLOBALS->mvlfacs_lx2_c_1[0].name, fnam);
+		f_name[0]=malloc_2(flen+1);
+		strcpy(f_name[0], fnam);
                 }
 	}
 
@@ -127,20 +128,20 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 	        if(was_packed)
 	                {
-			GLOBALS->mvlfacs_lx2_c_1[i+1].name = pnt;
+			f_name[i+1] = pnt;
 			}
 			else
 			{
 			int flen = strlen(fnam);
-			GLOBALS->mvlfacs_lx2_c_1[i+1].name=malloc_2(flen+1);
-			strcpy(GLOBALS->mvlfacs_lx2_c_1[i+1].name, fnam);
+			f_name[i+1]=malloc_2(flen+1);
+			strcpy(f_name[i+1], fnam);
 			}
 		}
 
 	if(i>1)
 		{
-		free_2(GLOBALS->mvlfacs_lx2_c_1[i-2].name);
-		GLOBALS->mvlfacs_lx2_c_1[i-2].name = NULL;
+		free_2(f_name[i-2]);
+		f_name[i-2] = NULL;
 		}
 
 	if(GLOBALS->mvlfacs_lx2_c_1[i].flags&LXT2_RD_SYM_F_ALIAS)
@@ -162,7 +163,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 	if((f->len>1)&& (!(f->flags&(LXT2_RD_SYM_F_INTEGER|LXT2_RD_SYM_F_DOUBLE|LXT2_RD_SYM_F_STRING))) )
 		{
-		int len = sprintf(buf, "%s[%d:%d]", GLOBALS->mvlfacs_lx2_c_1[i].name,GLOBALS->mvlfacs_lx2_c_1[i].msb, GLOBALS->mvlfacs_lx2_c_1[i].lsb);
+		int len = sprintf(buf, "%s[%d:%d]", f_name[i],GLOBALS->mvlfacs_lx2_c_1[i].msb, GLOBALS->mvlfacs_lx2_c_1[i].lsb);
 		str=malloc_2(len+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
@@ -178,13 +179,13 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		}
 	else if ( 
 			((f->len==1)&&(!(f->flags&(LXT2_RD_SYM_F_INTEGER|LXT2_RD_SYM_F_DOUBLE|LXT2_RD_SYM_F_STRING)))&&
-			((i!=GLOBALS->numfacs-1)&&(!strcmp(GLOBALS->mvlfacs_lx2_c_1[i].name, GLOBALS->mvlfacs_lx2_c_1[i+1].name))))
+			((i!=GLOBALS->numfacs-1)&&(!strcmp(f_name[i], f_name[i+1]))))
 			||
-			(((i!=0)&&(!strcmp(GLOBALS->mvlfacs_lx2_c_1[i].name, GLOBALS->mvlfacs_lx2_c_1[i-1].name))) &&
+			(((i!=0)&&(!strcmp(f_name[i], f_name[i-1]))) &&
 			(GLOBALS->mvlfacs_lx2_c_1[i].msb!=-1)&&(GLOBALS->mvlfacs_lx2_c_1[i].lsb!=-1))
 		)
 		{
-		int len = sprintf(buf, "%s[%d]", GLOBALS->mvlfacs_lx2_c_1[i].name,GLOBALS->mvlfacs_lx2_c_1[i].msb);
+		int len = sprintf(buf, "%s[%d]", f_name[i],GLOBALS->mvlfacs_lx2_c_1[i].msb);
 		str=malloc_2(len+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
@@ -196,7 +197,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			}
                 s=&sym_block[i];
                 symadd_name_exists_sym_exists(s,str,0);
-		if((prevsym)&&(i>0)&&(!strcmp(GLOBALS->mvlfacs_lx2_c_1[i].name, GLOBALS->mvlfacs_lx2_c_1[i-1].name)))	/* allow chaining for search functions.. */
+		if((prevsym)&&(i>0)&&(!strcmp(f_name[i], f_name[i-1])))	/* allow chaining for search functions.. */
 			{
 			prevsym->vec_root = prevsymroot;
 			prevsym->vec_chain = s;
@@ -210,14 +211,14 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		}
 		else
 		{
-		str=malloc_2(strlen(GLOBALS->mvlfacs_lx2_c_1[i].name)+1);
+		str=malloc_2(strlen(f_name[i])+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
-			strcpy(str, GLOBALS->mvlfacs_lx2_c_1[i].name);
+			strcpy(str, f_name[i]);
 			}
 			else
 			{
-			strcpy_vcdalt(str, GLOBALS->mvlfacs_lx2_c_1[i].name, GLOBALS->alt_hier_delimeter);
+			strcpy_vcdalt(str, f_name[i], GLOBALS->alt_hier_delimeter);
 			}
                 s=&sym_block[i];
                 symadd_name_exists_sym_exists(s,str,0);
@@ -231,27 +232,16 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			}
 		}
 		
-        if(!GLOBALS->firstnode)
-                {
-                GLOBALS->firstnode=GLOBALS->curnode=s;   
-                }
-                else
-                {
-                GLOBALS->curnode->nextinaet=s;
-                GLOBALS->curnode=s;   
-                }
-
 	n=&node_block[i];
         n->nname=s->name;
         n->mv.mvlfac = GLOBALS->mvlfacs_lx2_c_1+i;
 	GLOBALS->mvlfacs_lx2_c_1[i].working_node = n;
 
-	if((f->len>1)||(f->flags&&(LXT2_RD_SYM_F_DOUBLE|LXT2_RD_SYM_F_STRING)))
+	if((f->len>1)||(f->flags&(LXT2_RD_SYM_F_DOUBLE|LXT2_RD_SYM_F_STRING)))
 		{
-		ExtNode *ext = (ExtNode *)calloc_2(1,sizeof(struct ExtNode));
-		ext->msi = GLOBALS->mvlfacs_lx2_c_1[i].msb;
-		ext->lsi = GLOBALS->mvlfacs_lx2_c_1[i].lsb;
-		n->ext = ext;
+		n->msi = GLOBALS->mvlfacs_lx2_c_1[i].msb;
+		n->lsi = GLOBALS->mvlfacs_lx2_c_1[i].lsb;
+		n->extvals = 1;
 		}
                  
         n->head.time=-1;        /* mark 1st node as negative time */
@@ -261,36 +251,26 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 for(i=0;((i<2)&&(i<GLOBALS->numfacs));i++)
 	{
-	if(GLOBALS->mvlfacs_lx2_c_1[i].name)
+	if(f_name[i])
 		{
-		free_2(GLOBALS->mvlfacs_lx2_c_1[i].name);
-		GLOBALS->mvlfacs_lx2_c_1[i].name = NULL;
+		free_2(f_name[i]);
+		f_name[i] = NULL;
 		}
 	}
+free_2(f_name); f_name = NULL;
 
-GLOBALS->pfx_hier_array = calloc_2(GLOBALS->hier_pfx_cnt ? GLOBALS->hier_pfx_cnt : 1, sizeof(char *));
-
-lst = GLOBALS->hier_pfx;
-if(lst)
-        {
-        jrb_traverse(ptr, lst)
-                {
-                GLOBALS->pfx_hier_array[ptr->val.ui] = ptr->key.s;
-                }
-        }
+create_hier_array();
 
 /* SPLASH */                            splash_sync(2, 5);
 GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
 
 if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
         {
-        GLOBALS->curnode=GLOBALS->firstnode;
         for(i=0;i<GLOBALS->numfacs;i++)
                 {
                 int len;
-                GLOBALS->facs[i]=GLOBALS->curnode;
-                if((len=strlen(GLOBALS->curnode->name))>GLOBALS->longestname) GLOBALS->longestname=len;
-                GLOBALS->curnode=GLOBALS->curnode->nextinaet;
+                GLOBALS->facs[i]=&sym_block[i];
+                if((len=strlen(GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
                 }
 
 	if(numalias)
@@ -382,19 +362,21 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
         }
         else
 	{
-	GLOBALS->curnode=GLOBALS->firstnode;
 	for(i=0;i<GLOBALS->numfacs;i++)
 		{
 		char *subst, ch;
 		int len;
 		int esc = 0;
 
-		GLOBALS->facs[i]=GLOBALS->curnode;
-	        if((len=strlen(subst=GLOBALS->curnode->name))>GLOBALS->longestname) GLOBALS->longestname=len;
-		GLOBALS->curnode=GLOBALS->curnode->nextinaet;
+		GLOBALS->facs[i]=&sym_block[i];
+	        if((len=strlen(subst=GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
 		while((ch=(*subst)))
 			{	
+#ifdef WAVE_HIERFIX
 	                if(ch==GLOBALS->hier_delimeter) { *subst=(!esc) ? VCDNAM_HIERSORT : VCDNAM_ESCAPE; }    /* forces sort at hier boundaries */
+#else
+	                if((ch==GLOBALS->hier_delimeter)&&(esc)) { *subst = VCDNAM_ESCAPE; }    /* forces sort at hier boundaries */
+#endif
 	                else if(ch=='\\') { esc = 1; GLOBALS->escaped_names_found_vcd_c_1 = 1; }
 	                subst++;
 			}
@@ -403,7 +385,8 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
 /* SPLASH */                            splash_sync(3, 5);
 	fprintf(stderr, LXT2_RDLOAD"Sorting facilities at hierarchy boundaries.\n");
 	wave_heapsort(GLOBALS->facs,GLOBALS->numfacs);
-	
+
+#ifdef WAVE_HIERFIX	
 	for(i=0;i<GLOBALS->numfacs;i++)
 		{
 		char *subst, ch;
@@ -415,6 +398,7 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
 			subst++;
 			}
 		}
+#endif
 
 	GLOBALS->facs_are_sorted=1;
 
@@ -580,7 +564,9 @@ l2e->numtrans++;
  */
 static void lx2_resolver(nptr np, nptr resolve)
 { 
-np->ext = resolve->ext;
+np->extvals = resolve->extvals;
+np->msi = resolve->msi;
+np->lsi = resolve->lsi;
 memcpy(&np->head, &resolve->head, sizeof(struct HistEnt));
 np->curr = resolve->curr;
 np->harray = resolve->harray;
@@ -883,8 +869,26 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 }
 
 /*
- * $Id: lx2.c,v 1.10 2009/08/06 20:03:31 gtkwave Exp $
+ * $Id: lx2.c,v 1.16 2010/03/14 07:09:49 gtkwave Exp $
  * $Log: lx2.c,v $
+ * Revision 1.16  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.15  2010/03/13 21:38:16  gtkwave
+ * fixed && used in logical operations for allocating ExtNode
+ *
+ * Revision 1.14  2010/03/13 19:16:00  gtkwave
+ * removal of useless symbol->nextinaet code
+ *
+ * Revision 1.13  2010/03/11 23:31:52  gtkwave
+ * remove name field from struct fac
+ *
+ * Revision 1.12  2010/03/01 05:16:26  gtkwave
+ * move compressed hier tree traversal to hierpack
+ *
+ * Revision 1.11  2010/01/23 03:21:11  gtkwave
+ * hierarchy fixes when characters < "." are in the signal names
+ *
  * Revision 1.10  2009/08/06 20:03:31  gtkwave
  * warnings fixes
  *
