@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2001-2009.
+ * Copyright (c) Tony Bybell 2001-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -425,7 +425,7 @@ fprintf(stderr, LXTHDR"...expanded %d entries from %08x into %08x bytes.\n", GLO
 /*
  * decompress facility names and build up fac geometry
  */
-static void build_facs(char *fname)
+static void build_facs(char *fname, char **f_name)
 {
 char *buf, *bufprev = NULL, *bufcurr;
 off_t offs=GLOBALS->facname_offset_lxt_c_1+8;
@@ -434,8 +434,6 @@ char *pnt = NULL;
 int total_mem = get_32(GLOBALS->facname_offset_lxt_c_1+4);
 gzFile zhandle = NULL;
 char *decmem=NULL;
-JRB ptr, lst;
-
 
 #if defined __MINGW32__ || defined _MSC_VER
 FILE *tmp;
@@ -488,11 +486,11 @@ if(GLOBALS->do_hier_compress)
 		string_ret =  hier_compress(workspace, HIERPACK_ADD, &was_packed);
 		if(was_packed)
 			{
-			GLOBALS->mvlfacs_lxt_c_2[i].name=string_ret;
+			f_name[i]=string_ret;
 			}
 			else
 			{
-		        GLOBALS->mvlfacs_lxt_c_2[i].name=strdup_2(workspace);
+		        f_name[i]=strdup_2(workspace);
 			}
 	        }
 	}
@@ -508,21 +506,13 @@ if(GLOBALS->do_hier_compress)
 			*(pnt++) = *(bufprev++);
 			}
 	        while((*(pnt++)=get_byte(offs++)));
-	        GLOBALS->mvlfacs_lxt_c_2[i].name=bufcurr;
+	        f_name[i]=bufcurr;
 		DEBUG(printf(LXTHDR"Encountered facility %d: '%s'\n", i, bufcurr));
 		bufprev=bufcurr;
 	        }
 	}
 
-GLOBALS->pfx_hier_array = calloc_2(GLOBALS->hier_pfx_cnt ? GLOBALS->hier_pfx_cnt : 1, sizeof(char *));
-lst = GLOBALS->hier_pfx;
-if(lst)
-        {
-        jrb_traverse(ptr, lst)
-                {
-                GLOBALS->pfx_hier_array[ptr->val.ui] = ptr->key.s;
-                }
-        }
+create_hier_array();
 
 if(GLOBALS->prev_hier_uncompressed_name) { free_2(GLOBALS->prev_hier_uncompressed_name); GLOBALS->prev_hier_uncompressed_name = NULL; }
 
@@ -578,7 +568,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	GLOBALS->mvlfacs_lxt_c_2[i].len=(GLOBALS->mvlfacs_lxt_c_2[i].lsb>GLOBALS->mvlfacs_lxt_c_2[i].msb)?(GLOBALS->mvlfacs_lxt_c_2[i].lsb-GLOBALS->mvlfacs_lxt_c_2[i].msb+1):(GLOBALS->mvlfacs_lxt_c_2[i].msb-GLOBALS->mvlfacs_lxt_c_2[i].lsb+1);
 
 	if(GLOBALS->mvlfacs_lxt_c_2[i].len>GLOBALS->lt_len_lxt_c_1) GLOBALS->lt_len_lxt_c_1 = GLOBALS->mvlfacs_lxt_c_2[i].len;
-	DEBUG(printf(LXTHDR"%s[%d:%d]\n", mvlfacs[i].name, mvlfacs[i].msb, mvlfacs[i].lsb));
+	DEBUG(printf(LXTHDR"%s[%d:%d]\n", mvlfacs[i].f_name, mvlfacs[i].msb, mvlfacs[i].lsb));
 
 	offs+=0x10;
 	}
@@ -806,8 +796,8 @@ if(GLOBALS->sync_table_offset_lxt_c_1)
 		{
 		chg=get_32(offs);  offs+=4;
 		if(chg>maxchg) {maxchg=chg; maxindx=i; }
-		GLOBALS->mvlfacs_lxt_c_2[i].lastchange=chg;
-		DEBUG(printf(LXTHDR"Changes: %d '%s' %08x\n", i, mvlfacs[i].name, chg));
+		GLOBALS->lastchange[i]=chg;
+		DEBUG(printf(LXTHDR"Changes: %d '%s' %08x\n", i, mvlfacs[i].f_name, chg));
 		}
 
 	if(GLOBALS->zsync_table_size_lxt_c_1)
@@ -820,7 +810,7 @@ if(GLOBALS->sync_table_offset_lxt_c_1)
 #endif
 		}
 
-	DEBUG(printf(LXTHDR"Maxchange at: %08x for symbol '%s' of len %d\n", maxchg, mvlfacs[maxindx].name,  mvlfacs[maxindx].len));
+	DEBUG(printf(LXTHDR"Maxchange at: %08x for symbol '%s' of len %d\n", maxchg, mvlfacs[maxindx].f_name,  mvlfacs[maxindx].len));
 
 	GLOBALS->maxchange_lxt_c_1=maxchg;
 	GLOBALS->maxindex_lxt_c_1=maxindx;
@@ -1129,7 +1119,7 @@ if(!GLOBALS->sync_table_offset_lxt_c_1)
 			}
 
 
-		/* printf("%08x : %04x %02x (%d) %s[%d:%d]\n", offscache, facidx, cmd, mvlfacs[facidx].len, mvlfacs[facidx].name, mvlfacs[facidx].msb, mvlfacs[facidx].lsb); */
+		/* printf("%08x : %04x %02x (%d) %s[%d:%d]\n", offscache, facidx, cmd, mvlfacs[facidx].len, mvlfacs[facidx].f_name, mvlfacs[facidx].msb, mvlfacs[facidx].lsb); */
 
 		if(!cmdkill)
 		switch(cmd)
@@ -1205,8 +1195,8 @@ if(!GLOBALS->sync_table_offset_lxt_c_1)
 				}
 			}
 
-		last_change_delta = GLOBALS->fpos_lxt_c_1 - GLOBALS->mvlfacs_lxt_c_2[facidx].lastchange - 2;
-		GLOBALS->mvlfacs_lxt_c_2[facidx].lastchange = GLOBALS->fpos_lxt_c_1;
+		last_change_delta = GLOBALS->fpos_lxt_c_1 - GLOBALS->lastchange[facidx] - 2;
+		GLOBALS->lastchange[facidx] = GLOBALS->fpos_lxt_c_1;
 
 		GLOBALS->maxchange_lxt_c_1=GLOBALS->fpos_lxt_c_1;
 		GLOBALS->maxindex_lxt_c_1=facidx;
@@ -1448,6 +1438,7 @@ off_t tagpnt;
 int tag;
 struct symbol *sym_block = NULL;
 struct Node *node_block = NULL;
+char **f_name = NULL;
 
 GLOBALS->fd_lxt_c_1=open(fname, O_RDONLY);
 if(GLOBALS->fd_lxt_c_1<0)
@@ -1572,6 +1563,9 @@ if(!GLOBALS->facname_offset_lxt_c_1)
 GLOBALS->numfacs=get_32(GLOBALS->facname_offset_lxt_c_1);
 DEBUG(printf(LXTHDR"Number of facs: %d\n", numfacs));
 GLOBALS->mvlfacs_lxt_c_2=(struct fac *)calloc_2(GLOBALS->numfacs,sizeof(struct fac));
+GLOBALS->resolve_lxt_alias_to=(struct Node **)calloc_2(GLOBALS->numfacs,sizeof(struct Node *));
+GLOBALS->lastchange=(unsigned int *)calloc_2(GLOBALS->numfacs,sizeof(unsigned int));
+f_name = calloc_2(GLOBALS->numfacs,sizeof(char *));
 
 if(GLOBALS->initial_value_offset_lxt_c_1)
 	{
@@ -1604,7 +1598,7 @@ if(GLOBALS->zdictionary_offset_lxt_c_1)
 		}
 	}
 
-build_facs(fname);
+build_facs(fname, f_name);
 /* SPLASH */                            splash_sync(1, 5);
 build_facs2(fname);
 /* SPLASH */                            splash_sync(2, 5);
@@ -1642,7 +1636,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 	if((f->len>1)&& (!(f->flags&(LT_SYM_F_INTEGER|LT_SYM_F_DOUBLE|LT_SYM_F_STRING))) )
 		{
-		int len = sprintf(buf, "%s[%d:%d]", GLOBALS->mvlfacs_lxt_c_2[i].name,GLOBALS->mvlfacs_lxt_c_2[i].msb, GLOBALS->mvlfacs_lxt_c_2[i].lsb);
+		int len = sprintf(buf, "%s[%d:%d]", f_name[i],GLOBALS->mvlfacs_lxt_c_2[i].msb, GLOBALS->mvlfacs_lxt_c_2[i].lsb);
 		str=malloc_2(len+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
@@ -1658,13 +1652,13 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		}
 	else if ( 
 			((f->len==1)&&(!(f->flags&(LT_SYM_F_INTEGER|LT_SYM_F_DOUBLE|LT_SYM_F_STRING)))&&
-			((i!=GLOBALS->numfacs-1)&&(!strcmp(GLOBALS->mvlfacs_lxt_c_2[i].name, GLOBALS->mvlfacs_lxt_c_2[i+1].name))))
+			((i!=GLOBALS->numfacs-1)&&(!strcmp(f_name[i], f_name[i+1]))))
 			||
-			(((i!=0)&&(!strcmp(GLOBALS->mvlfacs_lxt_c_2[i].name, GLOBALS->mvlfacs_lxt_c_2[i-1].name))) &&
+			(((i!=0)&&(!strcmp(f_name[i], f_name[i-1]))) &&
 			(GLOBALS->mvlfacs_lxt_c_2[i].msb!=-1)&&(GLOBALS->mvlfacs_lxt_c_2[i].lsb!=-1))
 		)
 		{
-		int len = sprintf(buf, "%s[%d]", GLOBALS->mvlfacs_lxt_c_2[i].name,GLOBALS->mvlfacs_lxt_c_2[i].msb);
+		int len = sprintf(buf, "%s[%d]", f_name[i],GLOBALS->mvlfacs_lxt_c_2[i].msb);
 		str=malloc_2(len+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
@@ -1676,7 +1670,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			}
                 s=&sym_block[i];
                 symadd_name_exists_sym_exists(s,str,0);
-		if((prevsym)&&(i>0)&&(!strcmp(GLOBALS->mvlfacs_lxt_c_2[i].name, GLOBALS->mvlfacs_lxt_c_2[i-1].name)))	/* allow chaining for search functions.. */
+		if((prevsym)&&(i>0)&&(!strcmp(f_name[i], f_name[i-1])))	/* allow chaining for search functions.. */
 			{
 			prevsym->vec_root = prevsymroot;
 			prevsym->vec_chain = s;
@@ -1690,14 +1684,14 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		}
 		else
 		{
-		str=malloc_2(strlen(GLOBALS->mvlfacs_lxt_c_2[i].name)+1);
+		str=malloc_2(strlen(f_name[i])+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
-			strcpy(str, GLOBALS->mvlfacs_lxt_c_2[i].name);
+			strcpy(str, f_name[i]);
 			}
 			else
 			{
-			strcpy_vcdalt(str, GLOBALS->mvlfacs_lxt_c_2[i].name, GLOBALS->alt_hier_delimeter);
+			strcpy_vcdalt(str, f_name[i], GLOBALS->alt_hier_delimeter);
 			}
                 s=&sym_block[i];
                 symadd_name_exists_sym_exists(s,str,0);
@@ -1711,26 +1705,15 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			}
 		}
 		
-        if(!GLOBALS->firstnode)
-                {
-                GLOBALS->firstnode=GLOBALS->curnode=s;   
-                }
-                else
-                {
-                GLOBALS->curnode->nextinaet=s;
-                GLOBALS->curnode=s;   
-                }
-
 	n=&node_block[i];
         n->nname=s->name;
         n->mv.mvlfac = GLOBALS->mvlfacs_lxt_c_2+i;
 
-	if((f->len>1)||(f->flags&&(LT_SYM_F_DOUBLE|LT_SYM_F_STRING)))
+	if((f->len>1)||(f->flags&(LT_SYM_F_DOUBLE|LT_SYM_F_STRING)))
 		{
-		ExtNode *ext = (ExtNode *)calloc_2(1,sizeof(struct ExtNode));
-		ext->msi = GLOBALS->mvlfacs_lxt_c_2[i].msb;
-		ext->lsi = GLOBALS->mvlfacs_lxt_c_2[i].lsb;
-		n->ext = ext;
+		n->msi = GLOBALS->mvlfacs_lxt_c_2[i].msb;
+		n->lsi = GLOBALS->mvlfacs_lxt_c_2[i].lsb;
+		n->extvals = 1;
 		}
 
         n->head.time=-1;        /* mark 1st node as negative time */
@@ -1738,27 +1721,30 @@ for(i=0;i<GLOBALS->numfacs;i++)
         s->n=n;
         }
 
-free_2(GLOBALS->mvlfacs_lxt_c_2[0].name);	/* the start of the big decompression buffer */
+free_2(f_name[0]);	/* the start of the big decompression buffer */
 for(i=0;i<GLOBALS->numfacs;i++)
 	{
-	GLOBALS->mvlfacs_lxt_c_2[i].name = NULL;
+	f_name[i] = NULL;
 	}
+free_2(f_name); f_name = NULL;
 
 /* SPLASH */                            splash_sync(3, 5);
 GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
-GLOBALS->curnode=GLOBALS->firstnode;
 for(i=0;i<GLOBALS->numfacs;i++)
 	{
 	char *subst, ch;
 	int len;
 	int esc = 0;
 
-	GLOBALS->facs[i]=GLOBALS->curnode;
-        if((len=strlen(subst=GLOBALS->curnode->name))>GLOBALS->longestname) GLOBALS->longestname=len;
-	GLOBALS->curnode=GLOBALS->curnode->nextinaet;
+	GLOBALS->facs[i]=&sym_block[i];
+        if((len=strlen(subst=GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
 	while((ch=(*subst)))
 		{	
+#ifdef WAVE_HIERFIX
 		if(ch==GLOBALS->hier_delimeter) { *subst=(!esc) ? VCDNAM_HIERSORT : VCDNAM_ESCAPE; }	/* forces sort at hier boundaries */
+#else
+                if((ch==GLOBALS->hier_delimeter)&&(esc)) { *subst = VCDNAM_ESCAPE; }    /* forces sort at hier boundaries */
+#endif
 		else if(ch=='\\') { esc = 1; GLOBALS->escaped_names_found_vcd_c_1 = 1; }
 		subst++;
 		}
@@ -1768,6 +1754,7 @@ fprintf(stderr, LXTHDR"Sorting facilities at hierarchy boundaries...");
 wave_heapsort(GLOBALS->facs,GLOBALS->numfacs);
 fprintf(stderr, "sorted.\n");
 	
+#ifdef WAVE_HIERFIX
 for(i=0;i<GLOBALS->numfacs;i++)
 	{
 	char *subst, ch;
@@ -1783,6 +1770,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	printf("%-4d %s\n",i,facs[i]->name);
 #endif
 	}
+#endif
 
 GLOBALS->facs_are_sorted=1;
 
@@ -1864,7 +1852,9 @@ return(GLOBALS->max_time);
  */
 static void lxt_resolver(nptr np, nptr resolve)
 {
-np->ext = resolve->ext;
+np->extvals = resolve->extvals;
+np->msi = resolve->msi;
+np->lsi = resolve->lsi;
 memcpy(&np->head, &resolve->head, sizeof(struct HistEnt));
 np->curr = resolve->curr;
 np->harray = resolve->harray;
@@ -1898,39 +1888,39 @@ if(np->mv.mvlfac->flags&LT_SYM_F_ALIAS)
 	int alias = np->mv.mvlfac->array_height;
 	f=GLOBALS->mvlfacs_lxt_c_2+alias;
 
-	if(f->resolve_lxt_alias_to)
+	if(GLOBALS->resolve_lxt_alias_to[alias])
 		{
-		if(!np->mv.mvlfac->resolve_lxt_alias_to) np->mv.mvlfac->resolve_lxt_alias_to = f->resolve_lxt_alias_to;
+		if(!GLOBALS->resolve_lxt_alias_to[np->mv.mvlfac - GLOBALS->mvlfacs_lxt_c_2]) GLOBALS->resolve_lxt_alias_to[np->mv.mvlfac - GLOBALS->mvlfacs_lxt_c_2] = GLOBALS->resolve_lxt_alias_to[alias];
 		}
 		else
 		{
-		f->resolve_lxt_alias_to = np;
+		GLOBALS->resolve_lxt_alias_to[alias] = np;
 		}
 
 	while(f->flags&LT_SYM_F_ALIAS)
 		{
 		f=GLOBALS->mvlfacs_lxt_c_2+f->array_height;
 
-		if(f->resolve_lxt_alias_to)
+		if(GLOBALS->resolve_lxt_alias_to[f->array_height])
 			{
-			if(!np->mv.mvlfac->resolve_lxt_alias_to) np->mv.mvlfac->resolve_lxt_alias_to = f->resolve_lxt_alias_to;
+			if(!GLOBALS->resolve_lxt_alias_to[np->mv.mvlfac - GLOBALS->mvlfacs_lxt_c_2]) GLOBALS->resolve_lxt_alias_to[np->mv.mvlfac - GLOBALS->mvlfacs_lxt_c_2] = GLOBALS->resolve_lxt_alias_to[f->array_height];
 			}
 			else
 			{
-			f->resolve_lxt_alias_to = np; 
+			GLOBALS->resolve_lxt_alias_to[f->array_height] = np; 
 			}
 		}
 	}
 
 /* f is the head minus any aliases, np->mv.mvlfac is us... */
-if(np->mv.mvlfac->resolve_lxt_alias_to)	/* in case we're an alias head for later.. */
+if(GLOBALS->resolve_lxt_alias_to[np->mv.mvlfac - GLOBALS->mvlfacs_lxt_c_2])	/* in case we're an alias head for later.. */
 	{
-	lxt_resolver(np, np->mv.mvlfac->resolve_lxt_alias_to);
+	lxt_resolver(np, GLOBALS->resolve_lxt_alias_to[np->mv.mvlfac - GLOBALS->mvlfacs_lxt_c_2]);
 	return;
 	}
 
-np->mv.mvlfac->resolve_lxt_alias_to = np;	/* in case we're an alias head for later.. */
-offs=f->lastchange;
+GLOBALS->resolve_lxt_alias_to[np->mv.mvlfac - GLOBALS->mvlfacs_lxt_c_2] = np;	/* in case we're an alias head for later.. */
+offs=GLOBALS->lastchange[f-GLOBALS->mvlfacs_lxt_c_2];
 
 tmval=LLDescriptor(-1);
 prevtmval = LLDescriptor(-1);
@@ -2416,8 +2406,32 @@ np->numhist++;
 }
 
 /*
- * $Id: lxt.c,v 1.11 2009/07/01 07:39:12 gtkwave Exp $
+ * $Id: lxt.c,v 1.19 2010/03/14 07:09:49 gtkwave Exp $
  * $Log: lxt.c,v $
+ * Revision 1.19  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.18  2010/03/13 21:38:16  gtkwave
+ * fixed && used in logical operations for allocating ExtNode
+ *
+ * Revision 1.17  2010/03/13 19:16:00  gtkwave
+ * removal of useless symbol->nextinaet code
+ *
+ * Revision 1.16  2010/03/12 21:12:39  gtkwave
+ * removed lastchange field
+ *
+ * Revision 1.15  2010/03/12 20:37:15  gtkwave
+ * removed resolve_lxt_alias_to field from struct fac
+ *
+ * Revision 1.14  2010/03/11 23:31:52  gtkwave
+ * remove name field from struct fac
+ *
+ * Revision 1.13  2010/03/01 05:16:26  gtkwave
+ * move compressed hier tree traversal to hierpack
+ *
+ * Revision 1.12  2010/01/23 03:21:11  gtkwave
+ * hierarchy fixes when characters < "." are in the signal names
+ *
  * Revision 1.11  2009/07/01 07:39:12  gtkwave
  * decorating hierarchy tree with module type info
  *
