@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 1999-2009.
+ * Copyright (c) Tony Bybell 1999-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -74,6 +74,14 @@
 #include <tk.h>
 #endif
 
+
+static int suffix_check(const char *s, const char *sfx)
+{
+int sfxlen = strlen(sfx);
+return((strlen(s)>=sfxlen)&&(!strcasecmp(s+strlen(s)-sfxlen,sfx)));
+}
+
+
 static void switch_page(GtkNotebook     *notebook,
 			GtkNotebookPage *page,
 			guint            page_num,
@@ -345,6 +353,7 @@ void addPidToExecutableName(int argc, char* argv[], char* argv_mod[])
   argv_mod[0] = buffer;
 }
 
+
 int main(int argc, char *argv[])
 {
 return(main_2(argc, argv));
@@ -463,6 +472,7 @@ if(!GLOBALS)
 	GLOBALS->color_back = old_g->color_back;
 	GLOBALS->color_baseline = old_g->color_baseline;
 	GLOBALS->color_grid = old_g->color_grid;
+	GLOBALS->color_grid2 = old_g->color_grid2;
 	GLOBALS->color_high = old_g->color_high;
 	GLOBALS->color_low = old_g->color_low;
 	GLOBALS->color_1 = old_g->color_1;
@@ -516,6 +526,7 @@ if(!GLOBALS)
 	GLOBALS->sst_expanded = old_g->sst_expanded;
 	GLOBALS->hier_grouping = old_g->hier_grouping;
 	GLOBALS->hier_max_level = old_g->hier_max_level;
+	GLOBALS->hier_max_level_shadow = old_g->hier_max_level_shadow;
 	GLOBALS->paned_pack_semantics = old_g->paned_pack_semantics;
 	GLOBALS->left_justify_sigs = old_g->left_justify_sigs;
 	GLOBALS->lxt_clock_compress_to_z = old_g->lxt_clock_compress_to_z;
@@ -1050,8 +1061,6 @@ if((!wname)&&(GLOBALS->make_vcd_save_file))
 	is_smartsave = (GLOBALS->vcd_save_handle != NULL); /* use smartsave if for some reason can't open auto savefile */
 	}
 
-GLOBALS->sym=(struct symbol **)calloc_2(SYMPRIME,sizeof(struct symbol *));
-
 if(!GLOBALS->loaded_file_name)
 	{
 	GLOBALS->loaded_file_name = strdup_2("[no file loaded]");	
@@ -1095,8 +1104,7 @@ if(is_missing_file)
 	}
 else
 #ifdef EXTLOAD_SUFFIX
-if( (strlen(GLOBALS->loaded_file_name)>strlen(EXTLOAD_SUFFIX))&&
-	((!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-strlen(EXTLOAD_SUFFIX),EXTLOAD_SUFFIX))) )
+if(suffix_check(GLOBALS->loaded_file_name, EXTLOAD_SUFFIX))
 	{
 	TimeType extload_max;
 
@@ -1110,7 +1118,7 @@ if( (strlen(GLOBALS->loaded_file_name)>strlen(EXTLOAD_SUFFIX))&&
 	}
 else
 #endif
-if((strlen(GLOBALS->loaded_file_name)>3)&&((!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".lxt"))||(!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".lx2"))))
+if(suffix_check(GLOBALS->loaded_file_name, ".lxt") || suffix_check(GLOBALS->loaded_file_name, ".lx2") || suffix_check(GLOBALS->loaded_file_name, ".lxt2"))
 	{
 	FILE *f = fopen(GLOBALS->loaded_file_name, "rb");
 	int typ = 0;
@@ -1151,7 +1159,7 @@ if((strlen(GLOBALS->loaded_file_name)>3)&&((!strcasecmp(GLOBALS->loaded_file_nam
 		}	
 	}
 else
-if((strlen(GLOBALS->loaded_file_name)>3)&&(!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".fst")))
+if(suffix_check(GLOBALS->loaded_file_name, ".fst"))
 	{
 #if !defined _MSC_VER
 	GLOBALS->stems_type = WAVE_ANNO_FST;
@@ -1167,7 +1175,7 @@ if((strlen(GLOBALS->loaded_file_name)>3)&&(!strcasecmp(GLOBALS->loaded_file_name
 		}
 	}
 else
-if((strlen(GLOBALS->loaded_file_name)>3)&&(!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".vzt")))
+if(suffix_check(GLOBALS->loaded_file_name, ".vzt"))
 	{
 #if !defined _MSC_VER
 	GLOBALS->stems_type = WAVE_ANNO_VZT;
@@ -1182,7 +1190,7 @@ if((strlen(GLOBALS->loaded_file_name)>3)&&(!strcasecmp(GLOBALS->loaded_file_name
 		vcd_exit(255);
 		}
 	}
-else if ((strlen(GLOBALS->loaded_file_name)>3)&&((!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".aet"))||(!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".ae2"))))
+else if(suffix_check(GLOBALS->loaded_file_name, ".aet") || suffix_check(GLOBALS->loaded_file_name, ".ae2"))
 	{
 #if !defined _MSC_VER
 	GLOBALS->stems_type = WAVE_ANNO_AE2;
@@ -1197,11 +1205,8 @@ else if ((strlen(GLOBALS->loaded_file_name)>3)&&((!strcasecmp(GLOBALS->loaded_fi
 		vcd_exit(255);
 		}
 	}
-else if (
-	((strlen(GLOBALS->loaded_file_name)>3)&&(!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".ghw"))) ||
-	((strlen(GLOBALS->loaded_file_name)>6)&&(!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-7,".ghw.gz"))) ||
-	((strlen(GLOBALS->loaded_file_name)>7)&&(!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-8,".ghw.bz2")))
-	)
+else if (suffix_check(GLOBALS->loaded_file_name, ".ghw") || suffix_check(GLOBALS->loaded_file_name, ".ghw.gz") ||
+		suffix_check(GLOBALS->loaded_file_name, ".ghw.bz2"))
 	{
           GLOBALS->loaded_file_type = GHW_FILE;
 	  if(!ghw_main(GLOBALS->loaded_file_name))
@@ -1281,6 +1286,10 @@ load_vcd:
 	}
 
 
+/* deallocate the symbol hash table */
+sym_hash_destroy(GLOBALS);
+
+/* reset/initialize various markers and time values */
 for(i=0;i<26;i++) GLOBALS->named_markers[i]=-1;	/* reset all named markers */
 
 GLOBALS->tims.last=GLOBALS->max_time;
@@ -1361,7 +1370,13 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 	        else
 	        {
 	        char *iline;
-		char any_shadow = 0;
+		int s_ctx_iter;
+
+                WAVE_STRACE_ITERATOR(s_ctx_iter)
+                        {
+                        GLOBALS->strace_ctx = &GLOBALS->strace_windows[GLOBALS->strace_current_window = s_ctx_iter];
+                        GLOBALS->strace_ctx->shadow_encountered_parsewavline = 0;
+			}
 
 		if(GLOBALS->is_lx2)
 			{
@@ -1401,10 +1416,11 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 
 		GLOBALS->default_flags=TR_RJUSTIFY;
 		GLOBALS->shift_timebase_default_for_add=LLDescriptor(0);
+		GLOBALS->strace_current_window = 0; /* in case there are shadow traces */
 	        while((iline=fgetmalloc(wave)))
 	                {
 	                parsewavline(iline, NULL, 0);
-			any_shadow |= GLOBALS->shadow_active;
+			GLOBALS->strace_ctx->shadow_encountered_parsewavline |= GLOBALS->strace_ctx->shadow_active;
 			free_2(iline);
 	                }
 		GLOBALS->default_flags=TR_RJUSTIFY;
@@ -1414,18 +1430,25 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 
 		EnsureGroupsMatch();
 
-                if(any_shadow)
-                        {
-                        if(GLOBALS->shadow_straces)
-                                {
-                                GLOBALS->shadow_active = 1;
+		WAVE_STRACE_ITERATOR(s_ctx_iter)
+			{
+			GLOBALS->strace_ctx = &GLOBALS->strace_windows[GLOBALS->strace_current_window = s_ctx_iter];
 
-                                swap_strace_contexts();
-                                strace_maketimetrace(1);
-                                swap_strace_contexts();
+	                if(GLOBALS->strace_ctx->shadow_encountered_parsewavline)
+	                        {
+				GLOBALS->strace_ctx->shadow_encountered_parsewavline = 0;
 
-				GLOBALS->shadow_active = 0;
-                                }
+	                        if(GLOBALS->strace_ctx->shadow_straces)
+	                                {
+	                                GLOBALS->strace_ctx->shadow_active = 1;
+	
+	                                swap_strace_contexts();
+	                                strace_maketimetrace(1);
+	                                swap_strace_contexts();
+	
+					GLOBALS->strace_ctx->shadow_active = 0;
+	                                }
+				}
                         }
 	        }
 	}
@@ -1942,10 +1965,10 @@ if(GLOBALS->treeopen_chain_head)
 			force_open_tree_node(t->str);
 			}
 
-		t2 = t;
+		t2 = t->next;
 		if(t->str) free_2(t->str);
 		free_2(t);
-		t = t2->next;
+		t = t2;
 		}
 
 	GLOBALS->treeopen_chain_head = GLOBALS->treeopen_chain_curr = NULL;
@@ -2628,8 +2651,29 @@ void optimize_vcd_file(void) {
 #endif
 
 /*
- * $Id: main.c,v 1.90 2009/12/24 20:55:27 gtkwave Exp $
+ * $Id: main.c,v 1.97 2010/03/15 15:57:28 gtkwave Exp $
  * $Log: main.c,v $
+ * Revision 1.97  2010/03/15 15:57:28  gtkwave
+ * only allocate hash when necessary
+ *
+ * Revision 1.96  2010/03/15 03:14:53  gtkwave
+ * deallocated symbol hash table after no longer needed
+ *
+ * Revision 1.95  2010/03/11 16:32:38  gtkwave
+ * fix to add .lxt2 suffix recognition
+ *
+ * Revision 1.94  2010/03/10 18:14:13  gtkwave
+ * Toggle Trace Hier fix (cache old value for more usability)
+ *
+ * Revision 1.93  2010/03/09 21:20:00  gtkwave
+ * crash fix for using ->next on a struct after free
+ *
+ * Revision 1.92  2010/01/22 16:51:21  gtkwave
+ * fixes to ensure WAVE_NUM_STRACE_WINDOWS is more maintainable
+ *
+ * Revision 1.91  2010/01/22 02:10:49  gtkwave
+ * added second pattern search capability
+ *
  * Revision 1.90  2009/12/24 20:55:27  gtkwave
  * warnings cleanups
  *
