@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,7 +16,108 @@
 #include "analyzer.h"
 #include "currenttime.h"
 
+static void str_change_callback(GtkWidget *entry, gpointer which)
+{
+G_CONST_RETURN gchar *entry_text;
+int i;
 
+i = ((int) (((long) which) & 31L)) % 26;
+GLOBALS->dirty_markerbox_c_1 = 1;
+ 
+entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
+if(strlen(entry_text))
+	{
+	if(GLOBALS->shadow_marker_names[i])
+		{
+		free_2(GLOBALS->shadow_marker_names[i]); 
+		}
+
+	GLOBALS->shadow_marker_names[i] = strdup_2(entry_text);
+	}
+	else
+	{
+	if(GLOBALS->shadow_marker_names[i])
+		{
+		free_2(GLOBALS->shadow_marker_names[i]); 
+		GLOBALS->shadow_marker_names[i] = NULL;
+		}
+	}
+}
+
+static void str_enter_callback(GtkWidget *entry, gpointer which)
+{
+G_CONST_RETURN gchar *entry_text;
+int i;
+
+i = ((int) (((long) which) & 31L)) % 26;
+GLOBALS->dirty_markerbox_c_1 = 1;
+ 
+entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
+if(strlen(entry_text))
+	{
+	if(GLOBALS->shadow_marker_names[i])
+		{
+		free_2(GLOBALS->shadow_marker_names[i]); 
+		}
+
+	GLOBALS->shadow_marker_names[i] = strdup_2(entry_text);
+	gtk_entry_select_region (GTK_ENTRY (entry),
+                             0, GTK_ENTRY(entry)->text_length);
+
+	}
+	else
+	{
+	if(GLOBALS->shadow_marker_names[i])
+		{
+		free_2(GLOBALS->shadow_marker_names[i]); 
+		GLOBALS->shadow_marker_names[i] = NULL;
+		}
+	}
+}
+
+
+
+
+static void change_callback(GtkWidget *widget, gpointer which)
+{
+GtkWidget *entry;
+TimeType temp;
+G_CONST_RETURN gchar *entry_text;
+char buf[49];
+int len, i;
+int ent_idx;
+
+ent_idx = ((int) (((long) which) & 31L)) % 26;
+ 
+entry=GLOBALS->entries_markerbox_c_1[ent_idx];
+
+entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
+if(!(len=strlen(entry_text))) goto failure;
+if(!isdigit(entry_text[0])) goto failure;
+
+temp=unformat_time(entry_text, GLOBALS->time_dimension);
+if((temp<GLOBALS->tims.start)||(temp>GLOBALS->tims.last)) goto failure;
+
+for(i=0;i<26;i++)
+        {
+        if(temp==GLOBALS->shadow_markers_markerbox_c_1[i]) 
+		{
+		if(i!=ent_idx)
+			{
+			GLOBALS->shadow_markers_markerbox_c_1[ent_idx] = -1;
+			}
+		goto failure;
+		}
+        }
+
+reformat_time_simple(buf, temp, GLOBALS->time_dimension);
+
+GLOBALS->shadow_markers_markerbox_c_1[ent_idx]=temp;
+GLOBALS->dirty_markerbox_c_1=1;
+
+failure:
+return;
+}
 
 static void enter_callback(GtkWidget *widget, gpointer which)
 {
@@ -39,11 +140,11 @@ temp=unformat_time(entry_text, GLOBALS->time_dimension);
 if((temp<GLOBALS->tims.start)||(temp>GLOBALS->tims.last)) goto failure;
 
 for(i=0;i<26;i++)
-	{
-	if(temp==GLOBALS->shadow_markers_markerbox_c_1[i]) goto failure;
-	}
+        {
+        if(temp==GLOBALS->shadow_markers_markerbox_c_1[i]) goto failure;
+        }
 
-reformat_time(buf, temp, GLOBALS->time_dimension);
+reformat_time_simple(buf, temp, GLOBALS->time_dimension);
 gtk_entry_set_text (GTK_ENTRY (entry), buf);
 
 GLOBALS->shadow_markers_markerbox_c_1[ent_idx]=temp;
@@ -60,7 +161,7 @@ if(GLOBALS->shadow_markers_markerbox_c_1[ent_idx]==-1)
 	}
 	else
 	{
-	reformat_time(buf, GLOBALS->shadow_markers_markerbox_c_1[ent_idx], GLOBALS->time_dimension);
+	reformat_time_simple(buf, GLOBALS->shadow_markers_markerbox_c_1[ent_idx], GLOBALS->time_dimension);
 	}
 gtk_entry_set_text (GTK_ENTRY (entry), buf);
 }
@@ -70,7 +171,13 @@ static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 if(GLOBALS->dirty_markerbox_c_1)
 	{
 	int i;
-	for(i=0;i<26;i++) GLOBALS->named_markers[i]=GLOBALS->shadow_markers_markerbox_c_1[i];
+	for(i=0;i<26;i++) 
+		{
+		GLOBALS->named_markers[i]=GLOBALS->shadow_markers_markerbox_c_1[i];
+		if(GLOBALS->marker_names[i]) free_2(GLOBALS->marker_names[i]);
+		GLOBALS->marker_names[i] = GLOBALS->shadow_marker_names[i];
+		GLOBALS->shadow_marker_names[i] = NULL;
+		}
         MaxSignalLength();
         signalarea_configure_event(GLOBALS->signalarea, NULL);
         wavearea_configure_event(GLOBALS->wavearea, NULL);
@@ -85,6 +192,14 @@ if(GLOBALS->dirty_markerbox_c_1)
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+int i;
+  for(i=0;i<26;i++)
+	{
+	if(GLOBALS->marker_names[i]) free_2(GLOBALS->marker_names[i]);
+  	GLOBALS->marker_names[i] = GLOBALS->shadow_marker_names[i];
+  	GLOBALS->shadow_marker_names[i] = NULL;
+	}
+
   gtk_grab_remove(GLOBALS->window_markerbox_c_4);
   gtk_widget_destroy(GLOBALS->window_markerbox_c_4);
   GLOBALS->window_markerbox_c_4 = NULL;
@@ -102,7 +217,11 @@ void markerbox(char *title, GtkSignalFunc func)
     GLOBALS->cleanup_markerbox_c_4=func;
     GLOBALS->dirty_markerbox_c_1=0;
 
-    for(i=0;i<26;i++) GLOBALS->shadow_markers_markerbox_c_1[i]=GLOBALS->named_markers[i];
+    for(i=0;i<26;i++) 
+	{
+	GLOBALS->shadow_markers_markerbox_c_1[i] = GLOBALS->named_markers[i];
+	GLOBALS->shadow_marker_names[i] = strdup_2(GLOBALS->marker_names[i]);
+	}
 
     /* create a new modal window */
     GLOBALS->window_markerbox_c_4 = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
@@ -130,7 +249,7 @@ void markerbox(char *title, GtkSignalFunc func)
     gtk_widget_show(frame);
 
     scrolled_win = gtk_scrolled_window_new (NULL, NULL);
-    gtk_widget_set_usize( GTK_WIDGET (scrolled_win), -1, 300);
+    gtk_widget_set_usize( GTK_WIDGET (scrolled_win), 400, 300);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
                                       GTK_POLICY_AUTOMATIC,
                                       GTK_POLICY_AUTOMATIC);
@@ -154,20 +273,36 @@ void markerbox(char *title, GtkSignalFunc func)
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (vbox_g), label, TRUE, TRUE, 0);
 
+    hbox = gtk_hbox_new(FALSE, 0);
+    gtk_widget_show (hbox);
+
     GLOBALS->entries_markerbox_c_1[i]=entry = gtk_entry_new_with_max_length (48);
     gtkwave_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(enter_callback), (void *)((long) i));
+    gtkwave_signal_connect(GTK_OBJECT(entry), "changed", GTK_SIGNAL_FUNC(change_callback), (void *)((long) i));
     if(GLOBALS->shadow_markers_markerbox_c_1[i]==-1)
 	{
 	sprintf(buf,"<None>");
 	}
 	else
 	{
-	reformat_time(buf, GLOBALS->shadow_markers_markerbox_c_1[i], GLOBALS->time_dimension);
+	reformat_time_simple(buf, GLOBALS->shadow_markers_markerbox_c_1[i], GLOBALS->time_dimension);
 	}
 
     gtk_entry_set_text (GTK_ENTRY (entry), buf);
-    gtk_box_pack_start (GTK_BOX (vbox_g), entry, TRUE, TRUE, 0);
     gtk_widget_show (entry);
+    gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
+
+    /* string part */
+    entry = gtk_entry_new_with_max_length (48);
+    if(GLOBALS->shadow_marker_names[i]) gtk_entry_set_text (GTK_ENTRY (entry), GLOBALS->shadow_marker_names[i]);
+    gtk_widget_show (entry);
+    gtkwave_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(str_enter_callback), (void *)((long) i));
+    gtkwave_signal_connect(GTK_OBJECT(entry), "changed", GTK_SIGNAL_FUNC(str_change_callback), (void *)((long) i));
+
+    gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
+
+
+    gtk_box_pack_start (GTK_BOX (vbox_g), hbox, TRUE, TRUE, 0);
     }
 
     gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_win), vbox_g);
@@ -200,8 +335,20 @@ void markerbox(char *title, GtkSignalFunc func)
 }
 
 /*
- * $Id: markerbox.c,v 1.4 2007/09/12 17:26:45 gtkwave Exp $
+ * $Id: markerbox.c,v 1.8 2008/12/28 03:03:33 gtkwave Exp $
  * $Log: markerbox.c,v $
+ * Revision 1.8  2008/12/28 03:03:33  gtkwave
+ * Added scale_to_time_dimension rc variable and menu options.
+ *
+ * Revision 1.7  2008/12/16 19:28:20  gtkwave
+ * more warnings cleanups
+ *
+ * Revision 1.6  2008/12/11 21:08:15  gtkwave
+ * allow support for marker names which are strings
+ *
+ * Revision 1.5  2008/12/11 19:55:03  gtkwave
+ * dynamic updates for string names in markerbox
+ *
  * Revision 1.4  2007/09/12 17:26:45  gtkwave
  * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
  *
