@@ -88,7 +88,6 @@ WV_MENU_SEP4,
 WV_MENU_EE,
 WV_MENU_ECD,
 WV_MENU_ECU,
-WV_MENU_ERSBV,
 WV_MENU_SEP5,
 WV_MENU_EDFH,
 WV_MENU_EDFD,
@@ -146,6 +145,9 @@ WV_MENU_ALPHA2,
 WV_MENU_LEX,
 WV_MENU_RVS,
 WV_MENU_SPS,
+#ifdef WAVE_USE_GTK2
+WV_MENU_SPS2,
+#endif
 WV_MENU_SEP7B,
 WV_MENU_SSR,
 WV_MENU_SSH,
@@ -181,6 +183,9 @@ WV_MENU_MCANM,
 WV_MENU_MDPM,
 WV_MENU_SEP8,
 WV_MENU_MWSON,
+WV_MENU_MLKLT, 
+WV_MENU_MLKRT, 
+WV_MENU_MLKOFF,
 WV_MENU_VSG,
 WV_MENU_SEP9,
 #if !defined _MSC_VER && !defined __MINGW32__
@@ -338,8 +343,20 @@ void SetTraceScrollbarRowValue(int row, unsigned center);
 #endif
 
 /*
- * $Id: menu.h,v 1.29 2009/11/25 09:49:28 gtkwave Exp $
+ * $Id: menu.h,v 1.33 2010/02/24 18:06:14 gtkwave Exp $
  * $Log: menu.h,v $
+ * Revision 1.33  2010/02/24 18:06:14  gtkwave
+ * removed reduce single bit vectors
+ *
+ * Revision 1.32  2010/02/24 17:35:35  gtkwave
+ * gtk1 compile fixes
+ *
+ * Revision 1.31  2010/01/22 02:10:49  gtkwave
+ * added second pattern search capability
+ *
+ * Revision 1.30  2010/01/18 20:47:02  gtkwave
+ * added named locker marking
+ *
  * Revision 1.29  2009/11/25 09:49:28  gtkwave
  * added gray code support
  *
