@@ -115,7 +115,7 @@ if(t->name)
 			hptr h_ptr;
 			if((h_ptr=bsearch_node(t->n.nd,tim)))
 				{
-				if(!t->n.nd->ext)
+				if(!t->n.nd->extvals)
 					{
 					unsigned char h_val = h_ptr->v.h_val;
 					if(t->n.nd->vartype == ND_VCD_EVENT)
@@ -396,8 +396,11 @@ if(flagged_name) { free_2(flagged_name); }
 }
 
 /*
- * $Id: mouseover.c,v 1.12 2009/11/25 09:49:28 gtkwave Exp $
+ * $Id: mouseover.c,v 1.13 2010/03/14 07:09:49 gtkwave Exp $
  * $Log: mouseover.c,v $
+ * Revision 1.13  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
  * Revision 1.12  2009/11/25 09:49:28  gtkwave
  * added gray code support
  *
