@@ -160,7 +160,7 @@ if(tname)
 			hptr h_ptr;
 			if((h_ptr=bsearch_node(t->n.nd,tim)))
 				{
-				if(!t->n.nd->ext)
+				if(!t->n.nd->extvals)
 					{
 					unsigned char h_val = h_ptr->v.h_val;
 					if(t->n.nd->vartype == ND_VCD_EVENT)
@@ -443,8 +443,11 @@ if(tname) { free_2(tname); }
 }
 
 /*
- * $Id: mouseover_sigs.c,v 1.6 2009/11/25 09:49:28 gtkwave Exp $
+ * $Id: mouseover_sigs.c,v 1.7 2010/03/14 07:09:49 gtkwave Exp $
  * $Log: mouseover_sigs.c,v $
+ * Revision 1.7  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
  * Revision 1.6  2009/11/25 09:49:28  gtkwave
  * added gray code support
  *
