@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 1999-2009. 
+ * Copyright (c) Tony Bybell 1999-2010. 
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free
@@ -685,7 +685,7 @@ ps_MaxSignalLength (void)
 
 		  if ((h_ptr = bsearch_node (t->n.nd, GLOBALS->tims.marker)))
 		    {
-		      if (!t->n.nd->ext)
+		      if (!t->n.nd->extvals)
 			{
 			  unsigned char h_val = h_ptr->v.h_val;
 			
@@ -801,13 +801,25 @@ pr_renderhash (pr_context * prc, int x, TimeType tim)
   int fhminus2;
   int rhs;
   int iter = 0;
+  int s_ctx_iter;
+  int timearray_encountered = 0;
 
   fhminus2 = GLOBALS->fontheight - 2;
 
+  WAVE_STRACE_ITERATOR(s_ctx_iter)
+        {
+        GLOBALS->strace_ctx = &GLOBALS->strace_windows[GLOBALS->strace_current_window = s_ctx_iter];
+        if(GLOBALS->strace_ctx->timearray)
+                {
+                timearray_encountered = 1;
+                break;
+                }
+        }       
+
   pr_setgray (prc, 0.75);
 
   pr_draw_line (prc, x, 0,
-		x, ((!GLOBALS->timearray) && (GLOBALS->display_grid)
+		x, ((!timearray_encountered) && (GLOBALS->display_grid)
 		    && (GLOBALS->enable_vert_grid)) ? GLOBALS->
 		liney_max : fhminus2);
 
@@ -900,6 +912,7 @@ pr_rendertimes (pr_context * prc)
   TimeType tim, rem;
   int x, len, lenhalf;
   char timebuff[32];
+  int s_ctx_iter;  
 
   pr_renderblackout (prc);
 
@@ -908,7 +921,11 @@ pr_rendertimes (pr_context * prc)
     GLOBALS->tims.start + (((gdouble) GLOBALS->wavewidth) * GLOBALS->nspx);
 
 	/**********/
-  if (GLOBALS->timearray)
+  WAVE_STRACE_ITERATOR_FWD(s_ctx_iter)
+  {
+  GLOBALS->strace_ctx = &GLOBALS->strace_windows[GLOBALS->strace_current_window = s_ctx_iter];
+
+  if (GLOBALS->strace_ctx->timearray)
     {
       int pos, pos2;
       TimeType *t, tm;
@@ -917,11 +934,11 @@ pr_rendertimes (pr_context * prc)
 
       pos = bsearch_timechain (GLOBALS->tims.start);
     top:
-      if ((pos >= 0) && (pos < GLOBALS->timearray_size))
+      if ((pos >= 0) && (pos < GLOBALS->strace_ctx->timearray_size))
 	{
-	  pr_setgray (prc, 0.90);
-	  t = GLOBALS->timearray + pos;
-	  for (; pos < GLOBALS->timearray_size; t++, pos++)
+	  pr_setgray (prc, (s_ctx_iter==0) ? 0.90 : 0.75);
+	  t = GLOBALS->strace_ctx->timearray + pos;
+	  for (; pos < GLOBALS->strace_ctx->timearray_size; t++, pos++)
 	    {
 	      tm = *t;
 	      if (tm >= GLOBALS->tims.start)
@@ -954,6 +971,8 @@ pr_rendertimes (pr_context * prc)
 	    }
 	}
     }
+  }
+  GLOBALS->strace_ctx = &GLOBALS->strace_windows[GLOBALS->strace_current_window = 0];
 	/**********/
 
   DEBUG (printf
@@ -1009,15 +1028,12 @@ pr_rendertimes (pr_context * prc)
 /*************************************************/
 
 static void
-pr_draw_named_markers (pr_context * prc)
+pr_render_individual_named_marker ( pr_context * prc, int i, gdouble gray, int blackout)
 {
   gdouble pixstep;
   gint xl, y;
-  int i;
   TimeType t;
 
-  for (i = 0; i < 26; i++)
-    {
       if ((t = GLOBALS->named_markers[i]) != -1)
 	{
 	  if ((t >= GLOBALS->tims.start) && (t <= GLOBALS->tims.last)
@@ -1034,11 +1050,10 @@ pr_draw_named_markers (pr_context * prc)
 	      if ((xl >= 0) && (xl < GLOBALS->wavewidth))
 		{
 		  char nbuff[2];
-		  int xsize;
 		  nbuff[0] = 'A' + i;
 		  nbuff[1] = 0x00;
 
-		  pr_setgray (prc, 0.40);
+		  pr_setgray (prc, gray);
 		  for (y = GLOBALS->fontheight - 1;
 		       y <= GLOBALS->liney_max - 5; y += 8)
 		    {
@@ -1047,7 +1062,7 @@ pr_draw_named_markers (pr_context * prc)
 
 		  if((!GLOBALS->marker_names[i])||(!GLOBALS->marker_names[i][0]))
 			{
-		  	xsize = font_engine_string_measure (GLOBALS->wavefont, nbuff);
+		  	int xsize = font_engine_string_measure (GLOBALS->wavefont, nbuff);
 		  	pr_setgray (prc, 0.00);
 		  	pr_draw_string (prc,
 				  xl - (xsize >> 1) + 1,
@@ -1059,20 +1074,47 @@ pr_draw_named_markers (pr_context * prc)
 			}
 			else
 			{
-		  	xsize = font_engine_string_measure (GLOBALS->wavefont, GLOBALS->marker_names[i]);
+			int boxheight = GLOBALS->wavefont-> ascent + GLOBALS->wavefont-> descent;
+		  	int xsize = font_engine_string_measure (GLOBALS->wavefont, GLOBALS->marker_names[i]);
+                        int ysize = (prc->gpd == &ps_print_device) ? GLOBALS->wavefont-> ascent / 2 : GLOBALS->wavefont->ascent;
+                        int boxysize = (prc->gpd == &ps_print_device) ? boxheight / 2 : boxheight;
+
+                        if(blackout) /* blackout background so text is legible if overlaid with other marker labels */
+                        	{
+			  	pr_setgray (prc, 1.00);
+                                pr_draw_box(prc,
+                                	xl-(xsize>>1) + 1, GLOBALS->fontheight-2-ysize,
+                                                (xl-(xsize>>1) + 1) + xsize, (GLOBALS->fontheight-2-ysize) + boxysize);
+				}
+
 		  	pr_setgray (prc, 0.00);
 		  	pr_draw_string (prc,
 				  xl - (xsize >> 1) + 1,
 				  GLOBALS->fontheight - 1, GLOBALS->marker_names[i],
-				  xsize,
-				  (prc->gpd ==
-				   &ps_print_device) ? GLOBALS->wavefont->
-				  ascent / 2 : GLOBALS->wavefont->ascent);
+				  xsize, ysize);
 			}
 		}
 	    }
 	}
-    }
+}
+
+static void
+pr_draw_named_markers (pr_context * prc)
+{
+int i;
+
+for(i=0;i<26;i++)
+        {
+        if(i != GLOBALS->named_marker_lock_idx)
+                {
+                pr_render_individual_named_marker(prc, i, 0.40, 0);
+                }
+        }
+
+if(GLOBALS->named_marker_lock_idx >= 0)
+        {
+        pr_render_individual_named_marker(prc, GLOBALS->named_marker_lock_idx, 0.65, 1);
+        }
 }
 
 
@@ -1396,6 +1438,7 @@ pr_draw_hptr_trace_vector_analog (pr_context * prc, Trptr t, hptr h,
   double tmin = mynan, tmax = mynan, tv, tv2;
   int is_nan = 0, is_nan2 = 0, is_inf = 0, is_inf2 = 0;
   int any_infs = 0, any_infp = 0, any_infm = 0;
+  int skipcnt = 0;
 
   liney = ((which + 2 + num_extension) * GLOBALS->fontheight) - 2;
   _y1 = ((which + 1) * GLOBALS->fontheight) + 2;
@@ -1665,8 +1708,17 @@ pr_draw_hptr_trace_vector_analog (pr_context * prc, Trptr t, hptr h,
 	  yt1 = _y0 + (tv2 - tmin) * tmax;
 	}
 
-      if (_x0 != _x1)
+      if ((_x0 != _x1) || (skipcnt < GLOBALS->analog_redraw_skip_count)) /* lower number = better performance */
 	{
+        if(_x0==_x1)
+                {
+                skipcnt++;
+                }
+                else
+                {
+                skipcnt = 0;
+                }
+
 	  if (h->next)
 	    {
 	      if (h->next->time > GLOBALS->max_time)
@@ -1678,6 +1730,37 @@ pr_draw_hptr_trace_vector_analog (pr_context * prc, Trptr t, hptr h,
 	  if ((is_nan2) && (h2tim > GLOBALS->max_time))
 	    is_nan2 = 0;
 
+/* clamp to top/bottom because of integer rounding errors */
+
+if(yt0 < _y1) yt0 = _y1;
+else if(yt0 > _y0) yt0 = _y0;
+                        
+if(yt1 < _y1) yt1 = _y1;
+else if(yt1 > _y0) yt1 = _y0;
+
+/* clipping... */
+{
+int coords[4];
+int rect[4];
+                        
+coords[0] = _x0; 
+coords[1] = yt0;
+coords[2] = _x1;
+coords[3] = yt1;
+                                
+rect[0] = -10;   
+rect[1] = _y1;
+rect[2] = GLOBALS->wavewidth + 10;
+rect[3] = _y0;          
+                                
+wave_lineclip(coords, rect);
+_x0 = coords[0];
+yt0 = coords[1];
+_x1 = coords[2];
+yt1 = coords[3];
+}
+/* ...clipping */
+
 	  if (is_nan || is_nan2)
 	    {
 	      if (is_nan)
@@ -1790,8 +1873,9 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
 
   if ((GLOBALS->display_grid) && (GLOBALS->enable_horiz_grid))
     {
-      if ((t->flags & TR_ANALOGMASK) && (t->t_next)
-	  && (t->t_next->flags & TR_ANALOG_BLANK_STRETCH))
+      Trptr tn = GiveNextTrace(t);
+      if ((t->flags & TR_ANALOGMASK) && (tn)
+	  && (tn->flags & TR_ANALOG_BLANK_STRETCH))
 	{
 	}
       else
@@ -1812,7 +1896,7 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
   if ((t->flags & TR_ANALOGMASK)
       && (!(h->flags & HIST_STRING) || !(h->flags & HIST_REAL)))
     {
-      Trptr te = t->t_next;
+      Trptr te = GiveNextTrace(t);
       int ext = 0;
       int num_traces_displayable =
 	GLOBALS->signalarea->allocation.height / GLOBALS->fontheight;
@@ -1822,7 +1906,7 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
 	  if (te->flags & TR_ANALOG_BLANK_STRETCH)
 	    {
 	      ext++;
-	      te = te->t_next;
+	      te = GiveNextTrace(te);
 	    }
 	  else
 	    {
@@ -2403,8 +2487,9 @@ pr_draw_vptr_trace (pr_context * prc, Trptr t, vptr v, int which)
 
   if ((GLOBALS->display_grid) && (GLOBALS->enable_horiz_grid))
     {
-      if ((t->flags & TR_ANALOGMASK) && (t->t_next)
-	  && (t->t_next->flags & TR_ANALOG_BLANK_STRETCH))
+      Trptr tn = GiveNextTrace(t);
+      if ((t->flags & TR_ANALOGMASK) && (tn)
+	  && (tn->flags & TR_ANALOG_BLANK_STRETCH))
 	{
 	}
       else
@@ -2424,7 +2509,7 @@ pr_draw_vptr_trace (pr_context * prc, Trptr t, vptr v, int which)
 
   if (t->flags & TR_ANALOGMASK)
     {
-      Trptr te = t->t_next;
+      Trptr te = GiveNextTrace(t);
       int ext = 0;
 
       while (te)
@@ -2432,7 +2517,7 @@ pr_draw_vptr_trace (pr_context * prc, Trptr t, vptr v, int which)
 	  if (te->flags & TR_ANALOG_BLANK_STRETCH)
 	    {
 	      ext++;
-	      te = te->t_next;
+	      te = GiveNextTrace(te);
 	    }
 	  else
 	    {
@@ -2639,7 +2724,7 @@ pr_rendertraces (pr_context * prc)
 			 ("Start time: " TTFormat ", Histent time: " TTFormat
 			  "\n", tims.start, (h->time + shift_timebase)));
 
-		  if (!t->n.nd->ext)
+		  if (!t->n.nd->extvals)
 		    {
 		      pr_draw_hptr_trace (prc, t, h, i, 1, 0);
 		    }
@@ -2666,11 +2751,12 @@ pr_rendertraces (pr_context * prc)
 
 	      if (kill_dodraw_grid)
 		{
-		  if (!(t->t_next))
+		  Trptr tn = GiveNextTrace(t);
+		  if (!tn)
 		    {
 		      kill_dodraw_grid = 0;
 		    }
-		  else if (!(t->t_next->flags & TR_ANALOG_BLANK_STRETCH))
+		  else if (!(tn->flags & TR_ANALOG_BLANK_STRETCH))
 		    {
 		      kill_dodraw_grid = 0;
 		    }
@@ -2893,8 +2979,29 @@ print_mif_image (FILE * wave, gdouble px, gdouble py)
 }
 
 /*
- * $Id: print.c,v 1.22 2009/06/26 19:56:18 gtkwave Exp $
+ * $Id: print.c,v 1.29 2010/03/14 07:09:49 gtkwave Exp $
  * $Log: print.c,v $
+ * Revision 1.29  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.28  2010/03/02 18:30:07  gtkwave
+ * fix for analog stretch traces when expanded then collapsed
+ *
+ * Revision 1.27  2010/02/22 17:15:11  gtkwave
+ * add y-coord clamping to avoid integer round off errors
+ *
+ * Revision 1.26  2010/02/21 05:15:16  gtkwave
+ * analog drawing fix for clipping + overdraw
+ *
+ * Revision 1.25  2010/02/07 20:16:34  gtkwave
+ * experiment with adding line clipping to analog rendering
+ *
+ * Revision 1.24  2010/01/22 02:10:49  gtkwave
+ * added second pattern search capability
+ *
+ * Revision 1.23  2010/01/19 17:50:40  gtkwave
+ * updated print rendering to match wavewindow marker lock adds
+ *
  * Revision 1.22  2009/06/26 19:56:18  gtkwave
  * add arrowheads to all impulse arrows
  *
