@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2009.
+ * Copyright (c) Tony Bybell 1999-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -70,6 +70,18 @@ if(strlen(str)) { GLOBALS->alt_hier_delimeter=str[0]; }
 return(0);
 }
 
+int f_analog_redraw_skip_count(char *str)
+{
+DEBUG(printf("f_analog_redraw_skip_count(\"%s\")\n",str));
+GLOBALS->analog_redraw_skip_count=atoi_64(str);
+if(GLOBALS->analog_redraw_skip_count < 0) 
+	{
+	GLOBALS->analog_redraw_skip_count = 0;
+	}
+
+return(0);
+}
+
 int f_append_vcd_hier(char *str)
 {
 DEBUG(printf("f_append_vcd_hier(\"%s\")\n",str));
@@ -278,7 +290,7 @@ return(0);
 int f_hier_max_level(char *str)
 {
 DEBUG(printf("f_hier_max_level(\"%s\")\n",str));
-GLOBALS->hier_max_level=atoi_64(str);
+GLOBALS->hier_max_level_shadow=GLOBALS->hier_max_level=atoi_64(str);
 return(0);
 }
 
@@ -628,6 +640,7 @@ return(0); \
 color_make(back)
 color_make(baseline)
 color_make(grid)
+color_make(grid2)
 color_make(high)
 color_make(low)
 color_make(1)
@@ -668,6 +681,7 @@ static struct rc_entry rcitems[]=
 {
 { "accel", f_accel },
 { "alt_hier_delimeter", f_alt_hier_delimeter },
+{ "analog_redraw_skip_count", f_analog_redraw_skip_count },
 { "append_vcd_hier", f_append_vcd_hier },
 { "atomic_vectors", f_atomic_vectors },
 { "autocoalesce", f_autocoalesce },
@@ -685,6 +699,7 @@ static struct rc_entry rcitems[]=
 { "color_dkgray", f_color_dkgray },
 { "color_gmstrd", f_color_gmstrd },
 { "color_grid", f_color_grid },
+{ "color_grid2", f_color_grid2 },
 { "color_high", f_color_high },
 { "color_low", f_color_low },
 { "color_ltblue", f_color_ltblue },
@@ -789,6 +804,7 @@ f_show_base_symbols	("off");
 f_color_back   		("000000"); /* black */
 f_color_baseline 	("ffffff"); /* white */
 f_color_grid		("202070"); /* dark dark blue */
+f_color_grid2		("6a5acd"); /* slate blue */
 f_color_high		("79f6f2"); /* light light blue */
 f_color_low		("5dbebb"); /* light blue */
 f_color_1		("00ff00"); /* green */
@@ -940,8 +956,20 @@ return;
 }
 
 /*
- * $Id: rc.c,v 1.19 2009/09/14 03:00:08 gtkwave Exp $
+ * $Id: rc.c,v 1.23 2010/03/10 18:14:13 gtkwave Exp $
  * $Log: rc.c,v $
+ * Revision 1.23  2010/03/10 18:14:13  gtkwave
+ * Toggle Trace Hier fix (cache old value for more usability)
+ *
+ * Revision 1.22  2010/02/21 05:15:16  gtkwave
+ * analog drawing fix for clipping + overdraw
+ *
+ * Revision 1.21  2010/01/22 07:28:28  gtkwave
+ * change grid2 color to slate blue
+ *
+ * Revision 1.20  2010/01/22 02:10:49  gtkwave
+ * added second pattern search capability
+ *
  * Revision 1.19  2009/09/14 03:00:08  gtkwave
  * bluespec code integration
  *
