@@ -827,7 +827,8 @@ if((match=(struct wave_rgb_color *)bsearch((void *)str, (void *)colors, C_ARRAY_
 	unsigned char *pnt=(unsigned char *)str;
 	int l=strlen(str);
 	unsigned char ch;
-	int i, rc;
+	int i;
+	unsigned int rc;
 
 	for(i=0;i<l;i++)
 		{
@@ -852,8 +853,11 @@ if((match=(struct wave_rgb_color *)bsearch((void *)str, (void *)colors, C_ARRAY_
 }
 
 /*
- * $Id: rgb.c,v 1.4 2009/12/17 17:11:06 gtkwave Exp $
+ * $Id: rgb.c,v 1.5 2010/03/18 17:12:37 gtkwave Exp $
  * $Log: rgb.c,v $
+ * Revision 1.5  2010/03/18 17:12:37  gtkwave
+ * pedantic warning cleanups
+ *
  * Revision 1.4  2009/12/17 17:11:06  gtkwave
  * collapsed separate arrays into an array of a single struct
  *
