@@ -144,7 +144,7 @@ if(GLOBALS->std_dnd_tgt_on_signalarea || GLOBALS->std_dnd_tgt_on_wavearea)
 	                }
 	        }
 
-	while(t->t_next && IsGroupEnd(t->t_next) && IsCollapsed(t->t_next)) {
+	while(t && t->t_next && IsGroupEnd(t->t_next) && IsCollapsed(t->t_next)) { /* added missing "t &&" because of possible while termination above */
 	  t = t->t_next;
 	}
         
@@ -1336,8 +1336,11 @@ gtk_signal_disconnect(GTK_OBJECT(GLOBALS->mainwindow), id);
 
 
 /*
- * $Id: signalwindow.c,v 1.48 2009/12/24 20:55:27 gtkwave Exp $
+ * $Id: signalwindow.c,v 1.49 2010/02/28 19:05:15 gtkwave Exp $
  * $Log: signalwindow.c,v $
+ * Revision 1.49  2010/02/28 19:05:15  gtkwave
+ * missing null pointer guard added
+ *
  * Revision 1.48  2009/12/24 20:55:27  gtkwave
  * warnings cleanups
  *
