@@ -36,28 +36,26 @@ typedef long off_t;
 
 struct fac
 {
+struct Node *working_node;
 int array_height;
 int msb, lsb, len;
-char *name;
-unsigned int lastchange;
 unsigned int flags;
-struct Node *resolve_lxt_alias_to;
-struct Node *working_node;
 };
 
 
 struct symbol
 {
-struct symbol *nextinaet;/* for aet node chaining */
-struct HistEnt *h;	 /* points to previous one */
+#ifndef _WAVE_HAVE_JUDY
+struct symbol *sym_next;  /* for hash chain, judy uses sym_judy in globals */
+#endif
 
 struct symbol *vec_root, *vec_chain;
-	
-struct symbol *next;	/* for hash chain */
 char *name;
 struct Node *n;
 
-char selected;		/* for the clist object */
+#ifndef _WAVE_HAVE_JUDY
+char s_selected;		/* for the clist object */
+#endif
 };
 
 
@@ -75,6 +73,11 @@ char *str;
 };
 
 
+/* hash create/destroy */
+void sym_hash_initialize(void *g);
+void sym_hash_destroy(void *g);
+
+
 struct symbol *symfind(char *, unsigned int *);
 struct symbol *symadd(char *, int);
 struct symbol *symadd_name_exists(char *name, int hv);
@@ -82,9 +85,7 @@ int hash(char *s);
 
 /* typically use zero for hashval as it doesn't matter if facs are sorted as symfind will bsearch... */
 #define symadd_name_exists_sym_exists(s, nam, hv) \
-(s)->name = (nam); \
-(s)->next=GLOBALS->sym[(hv)]; \
-GLOBALS->sym[(hv)]=(s);
+(s)->name = (nam); /* (s)->sym_next=GLOBALS->sym_hash[(hv)]; GLOBALS->sym_hash[(hv)]=(s); (obsolete) */
 
 void facsplit(char *, int *, int *);
 int sigcmp(char *, char *);
@@ -114,11 +115,43 @@ char *makename_chain(struct symbol *sym);
 void splash_create(void);
 void splash_sync(off_t current, off_t total);  
 
+/* accessor functions for sym->selected moved (potentially) to sparse array */
+char get_s_selected(struct symbol *s);
+char set_s_selected(struct symbol *s, char value);
+void destroy_s_selected(void);
+
 #endif
 
 /*
- * $Id: symbol.h,v 1.4 2009/09/14 03:00:08 gtkwave Exp $
+ * $Id: symbol.h,v 1.13 2010/03/16 21:01:10 gtkwave Exp $
  * $Log: symbol.h,v $
+ * Revision 1.13  2010/03/16 21:01:10  gtkwave
+ * remove selected member of struct symbol
+ *
+ * Revision 1.12  2010/03/15 15:57:28  gtkwave
+ * only allocate hash when necessary
+ *
+ * Revision 1.11  2010/03/15 03:14:53  gtkwave
+ * deallocated symbol hash table after no longer needed
+ *
+ * Revision 1.10  2010/03/14 20:12:28  gtkwave
+ * rename next hash pointer in struct symbol
+ *
+ * Revision 1.9  2010/03/13 19:48:53  gtkwave
+ * remove nextinaet field and replace with temp symchain
+ *
+ * Revision 1.8  2010/03/13 07:56:41  gtkwave
+ * removed unused h field in struct symbol
+ *
+ * Revision 1.7  2010/03/12 21:12:39  gtkwave
+ * removed lastchange field
+ *
+ * Revision 1.6  2010/03/12 20:37:15  gtkwave
+ * removed resolve_lxt_alias_to field from struct fac
+ *
+ * Revision 1.5  2010/03/11 23:31:52  gtkwave
+ * remove name field from struct fac
+ *
  * Revision 1.4  2009/09/14 03:00:08  gtkwave
  * bluespec code integration
  *
