@@ -67,7 +67,7 @@ return(TCL_ERROR);
 static int gtkwavetcl_nop(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 /* nothing, this is simply to call gtk's main loop */
-gtkwave_gtk_main_iteration();
+gtkwave_main_iteration();
 return(TCL_OK);
 }
 
@@ -207,7 +207,10 @@ return(gtkwavetcl_printTimeType(clientData, interp, objc, objv, value));
 static int gtkwavetcl_getTimeDimension(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 Tcl_Obj *aobj;
-char reportString[2] = { GLOBALS->time_dimension, 0 };
+char reportString[2];
+
+reportString[0] = GLOBALS->time_dimension;
+reportString[1] = 0;
 
 aobj = Tcl_NewStringObj(reportString, -1);
 Tcl_SetObjResult(interp, aobj);
@@ -581,7 +584,7 @@ if(objc == 3)
 		        MaxSignalLength();
 		        signalarea_configure_event(GLOBALS->signalarea, NULL);
 		        wavearea_configure_event(GLOBALS->wavearea, NULL);
-			gtkwave_gtk_main_iteration();
+			gtkwave_main_iteration();
 
 			if(t->asciivalue)
 				{
@@ -598,7 +601,7 @@ if(objc == 3)
 			        MaxSignalLength();
 			        signalarea_configure_event(GLOBALS->signalarea, NULL);
 			        wavearea_configure_event(GLOBALS->wavearea, NULL);
-				gtkwave_gtk_main_iteration();
+				gtkwave_main_iteration();
 
 				return(TCL_OK);
 				}
@@ -609,7 +612,7 @@ if(objc == 3)
 		        MaxSignalLength();
 		        signalarea_configure_event(GLOBALS->signalarea, NULL);
 		        wavearea_configure_event(GLOBALS->wavearea, NULL);
-			gtkwave_gtk_main_iteration();
+			gtkwave_main_iteration();
 			}
 		}
 	}
@@ -693,7 +696,7 @@ if(objc == 2)
         signalarea_configure_event(GLOBALS->signalarea, NULL);
         wavearea_configure_event(GLOBALS->wavearea, NULL);
 
-	gtkwave_gtk_main_iteration();
+	gtkwave_main_iteration();
 	}
         else  
         {
@@ -726,7 +729,7 @@ if(objc == 2)
         signalarea_configure_event(GLOBALS->signalarea, NULL);
         wavearea_configure_event(GLOBALS->wavearea, NULL);
 
-	gtkwave_gtk_main_iteration();
+	gtkwave_main_iteration();
 	}
         else  
         {
@@ -774,7 +777,7 @@ if(objc == 2)
 
         signalarea_configure_event(GLOBALS->signalarea, NULL);
         wavearea_configure_event(GLOBALS->wavearea, NULL);
-	gtkwave_gtk_main_iteration();
+	gtkwave_main_iteration();
 	}
         else  
         {
@@ -810,7 +813,7 @@ if(objc == 2)
         gtk_signal_emit_by_name (GTK_OBJECT (GTK_ADJUSTMENT(GLOBALS->wave_hslider)), "changed");
         gtk_signal_emit_by_name (GTK_OBJECT (GTK_ADJUSTMENT(GLOBALS->wave_hslider)), "value_changed");
 
-	gtkwave_gtk_main_iteration();
+	gtkwave_main_iteration();
 	}
         else  
         {
@@ -846,7 +849,7 @@ if(objc == 3)
         signalarea_configure_event(GLOBALS->signalarea, NULL);
         wavearea_configure_event(GLOBALS->wavearea, NULL);
 
-	gtkwave_gtk_main_iteration();
+	gtkwave_main_iteration();
 	}
         else  
         {
@@ -867,7 +870,7 @@ if(objc == 2)
         MaxSignalLength();
         signalarea_configure_event(GLOBALS->signalarea, NULL);
 
-	gtkwave_gtk_main_iteration();
+	gtkwave_main_iteration();
 	}
         else  
         {
@@ -919,7 +922,7 @@ if((objc == 3)||(objc == 4))
 			}
 
 	        wavearea_configure_event(GLOBALS->wavearea, NULL);
-		gtkwave_gtk_main_iteration();
+		gtkwave_main_iteration();
                 } 
 	}
         else  
@@ -953,7 +956,7 @@ if(objc == 2)
 
 /*         gtk_signal_emit_by_name (GTK_OBJECT (wadj), "changed"); /\* force bar update *\/ */
 /*         gtk_signal_emit_by_name (GTK_OBJECT (wadj), "value_changed"); /\* force text update *\/ */
-/*	gtkwave_gtk_main_iteration(); */
+/*	gtkwave_main_iteration(); */
 	}
         else  
         {
@@ -1000,7 +1003,7 @@ if(objc==2)
         		MaxSignalLength();
         		signalarea_configure_event(GLOBALS->signalarea, NULL);
         		wavearea_configure_event(GLOBALS->wavearea, NULL);
-			gtkwave_gtk_main_iteration();
+			gtkwave_main_iteration();
         		}
                 }
 	}
@@ -1091,7 +1094,7 @@ if(objc==2)
         		MaxSignalLength();
         		signalarea_configure_event(GLOBALS->signalarea, NULL);
         		wavearea_configure_event(GLOBALS->wavearea, NULL);
-			gtkwave_gtk_main_iteration();
+			gtkwave_main_iteration();
         		}
                 }
 	}
@@ -1178,7 +1181,7 @@ if(objc==2)
         		MaxSignalLength();
         		signalarea_configure_event(GLOBALS->signalarea, NULL);
         		wavearea_configure_event(GLOBALS->wavearea, NULL);
-			gtkwave_gtk_main_iteration();
+			gtkwave_main_iteration();
         		}
                 }
 	}
@@ -1244,7 +1247,7 @@ if(objc==2)
         		MaxSignalLength();
         		signalarea_configure_event(GLOBALS->signalarea, NULL);
         		wavearea_configure_event(GLOBALS->wavearea, NULL);
-			gtkwave_gtk_main_iteration();
+			gtkwave_main_iteration();
         		}
                 }
 	}
@@ -1310,7 +1313,7 @@ if(objc==2)
         		MaxSignalLength();
         		signalarea_configure_event(GLOBALS->signalarea, NULL);
         		wavearea_configure_event(GLOBALS->wavearea, NULL);
-			gtkwave_gtk_main_iteration();
+			gtkwave_main_iteration();
         		}
                 }
 	}
@@ -1354,7 +1357,7 @@ if(objc == 3)
 					t->flags &= (~TR_HIGHLIGHT);
 					}
 	        		signalarea_configure_event(GLOBALS->signalarea, NULL);
-				gtkwave_gtk_main_iteration();
+				gtkwave_main_iteration();
 				break;
 				}
 
@@ -1407,7 +1410,7 @@ if(objc == 3)
 		if(mat)
 			{
         		signalarea_configure_event(GLOBALS->signalarea, NULL);
-			gtkwave_gtk_main_iteration();
+			gtkwave_main_iteration();
 			}
 
 		return(gtkwavetcl_printInteger(clientData, interp, objc, objv, mat));
@@ -1528,7 +1531,7 @@ static int gtkwavetcl_signalChangeList(ClientData clientData, Tcl_Interp *interp
 static int gtkwavetcl_findNextEdge(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 edge_search(STRACE_FORWARD);
-gtkwave_gtk_main_iteration();
+gtkwave_main_iteration();
 return(gtkwavetcl_getMarker(clientData, interp, objc, objv));
 }
 
@@ -1536,7 +1539,7 @@ return(gtkwavetcl_getMarker(clientData, interp, objc, objv));
 static int gtkwavetcl_findPrevEdge(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 edge_search(STRACE_BACKWARD);
-gtkwave_gtk_main_iteration();
+gtkwave_main_iteration();
 return(gtkwavetcl_getMarker(clientData, interp, objc, objv));
 }
 
@@ -1566,7 +1569,7 @@ if(objc == 2)
 #endif
 	    }
 	}
-      gtkwave_gtk_main_iteration(); /* check if this is needed */
+      gtkwave_main_iteration(); /* check if this is needed */
     }
   else  
     {
@@ -1589,7 +1592,7 @@ if(objc == 2)
 		from_entry_callback(NULL, GLOBALS->from_entry);		
 		}
 
-	gtkwave_gtk_main_iteration();
+	gtkwave_main_iteration();
 	}
         else  
         {
@@ -1612,7 +1615,7 @@ if(objc == 2)
 		to_entry_callback(NULL, GLOBALS->to_entry);		
 		}
 
-	gtkwave_gtk_main_iteration();
+	gtkwave_main_iteration();
 	}
         else  
         {
@@ -1708,7 +1711,7 @@ static int gtkwavetcl_loadFile(ClientData clientData, Tcl_Interp *interp, int ob
       /*	read_save_helper(s); */
       process_url_file(s);
       /*	process_url_list(s); */
-      /*	gtkwave_gtk_main_iteration(); */
+      /*	gtkwave_main_iteration(); */
 
 
     }
@@ -1765,7 +1768,7 @@ static int gtkwavetcl_showSignal(ClientData clientData, Tcl_Interp *interp, int
       if (row < 0) { row = 0; };
 
       s1 = Tcl_GetString(objv[2]);
-      sscanf(s1, "%d", &location);
+      sscanf(s1, "%u", &location);
 
       SetTraceScrollbarRowValue(row, location);
     }
@@ -1829,7 +1832,7 @@ if(objc == 2)
         MaxSignalLength();
         signalarea_configure_event(GLOBALS->signalarea, NULL);
         
-        gtkwave_gtk_main_iteration();
+        gtkwave_main_iteration();
 	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, rc));
         }
         else
@@ -1927,8 +1930,14 @@ static void dummy_function(void)
 
 
 /*
- * $Id: tcl_commands.c,v 1.35 2009/12/24 20:55:27 gtkwave Exp $
+ * $Id: tcl_commands.c,v 1.37 2010/03/18 17:12:37 gtkwave Exp $
  * $Log: tcl_commands.c,v $
+ * Revision 1.37  2010/03/18 17:12:37  gtkwave
+ * pedantic warning cleanups
+ *
+ * Revision 1.36  2010/02/18 23:06:04  gtkwave
+ * change name of main iteration loop calls
+ *
  * Revision 1.35  2009/12/24 20:55:27  gtkwave
  * warnings cleanups
  *
