@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell and Concept Engineering GmbH 2008-2009.
+ * Copyright (c) Tony Bybell and Concept Engineering GmbH 2008-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -782,7 +782,10 @@ if(elem)
 	{
 	if((!strcmp("net", elem[0])) || (!strcmp("netBus", elem[0])))
 		{
-		char delim_str[2] = { GLOBALS->hier_delimeter, 0 };
+		char delim_str[2];
+
+		delim_str[0] = GLOBALS->hier_delimeter;
+		delim_str[1] = 0;
 
 		len = 0;
 		for(i=1;i<l;i++)
@@ -887,6 +890,8 @@ most_recent_lbrack_list = calloc_2(c, sizeof(char *));
 
 GLOBALS->default_flags=TR_RJUSTIFY;
 
+GLOBALS->strace_current_window = 0; /* in case there are shadow traces; in reality this should never happen */
+
 for(ii=0;ii<c;ii++)
 	{
 	s_new = make_net_name_from_tcl_list(list[ii], &unescaped_str);
@@ -1149,22 +1154,22 @@ for(ii=0;ii<c;ii++)
 		{
 		struct symbol *s = GLOBALS->facs[match_idx_list[ii]];
 
-		if((match_type_list[ii] >= 2)&&(s->n->ext))
+		if((match_type_list[ii] >= 2)&&(s->n->extvals))
 			{
 			nptr nexp;
 			int bit = atoi(most_recent_lbrack_list[ii]+1 + (match_type_list[ii] == 3)); /* == 3 for adjustment when lbrack is escaped */
 			int which, cnt;
 			
-			if(s->n->ext->lsi > s->n->ext->msi)
+			if(s->n->lsi > s->n->msi)
 				{
-				for(which=0,cnt=s->n->ext->lsi ; cnt>=s->n->ext->msi ; cnt--,which++)
+				for(which=0,cnt=s->n->lsi ; cnt>=s->n->msi ; cnt--,which++)
 					{
 					if(cnt==bit) break;
 					}
 				}
 				else
 				{
-				for(which=0,cnt=s->n->ext->msi ; cnt>=s->n->ext->lsi ; cnt--,which++)
+				for(which=0,cnt=s->n->msi ; cnt>=s->n->lsi ; cnt--,which++)
 					{
 					if(cnt==bit) break;
 					}
@@ -1449,7 +1454,7 @@ if(t)
 			hptr h_ptr = bsearch_node(t->n.nd, GLOBALS->tims.marker);
 			if(h_ptr)
 				{
-				if(!t->n.nd->ext)
+				if(!t->n.nd->extvals)
 					{
 					rc = (char *)calloc_2(2, 2*sizeof(char));
 					rc[0] = AN_STR[h_ptr->v.h_val];
@@ -1503,7 +1508,7 @@ for(i=0;i<GLOBALS->num_rows_search_c_2;i++)
         {
         struct symbol *s, *t;
         s=(struct symbol *)gtk_clist_get_row_data(GTK_CLIST(GLOBALS->clist_search_c_3), i);
-        if(s->selected)
+        if(get_s_selected(s))
                 {
                 if((!s->vec_root)||(!GLOBALS->autocoalesce))
                         {
@@ -1511,13 +1516,13 @@ for(i=0;i<GLOBALS->num_rows_search_c_2;i++)
                         else
                         {
                         t=s->vec_root;
-			t->selected = 1;
+			set_s_selected(t, 1);
 			t=t->vec_chain;
                         while(t)
                                 {
-                                if(t->selected)
+                                if(get_s_selected(t))
                                         {
-                                        t->selected=0;
+                                        set_s_selected(t, 0);
                                         }
                                 t=t->vec_chain;
                                 }
@@ -1530,7 +1535,7 @@ for(i=0;i<GLOBALS->num_rows_search_c_2;i++)
         int len;
         struct symbol *s, *t;
         s=(struct symbol *)gtk_clist_get_row_data(GTK_CLIST(GLOBALS->clist_search_c_3), i);
-        if(s->selected)
+        if(get_s_selected(s))
                 {
                 if((!s->vec_root)||(!GLOBALS->autocoalesce))
                         {
@@ -1546,9 +1551,9 @@ for(i=0;i<GLOBALS->num_rows_search_c_2;i++)
 				one_entry = make_single_tcl_list_name(t->n->nname, NULL, 1);
 				WAVE_OE_ME
 
-                                if(t->selected)
+                                if(get_s_selected(t))
                                         {
-                                        if(len) t->selected=0;
+                                        if(len) set_s_selected(t, 0);
                                         }
                                 len++;
 				break; /* t=t->vec_chain; ...no longer needed because of for() loop above and handler in process_tcl_list() */
@@ -1693,16 +1698,16 @@ while(t)
 					char *p = strrchr(str, '[');
 					if(p) { *p = 0; }					
               
-                        		if(n->ext->lsi > n->ext->msi)
+                        		if(n->lsi > n->msi)
                                 		{
-                                		for(which=0,cnt=n->ext->lsi ; cnt>=n->ext->msi ; cnt--,which++)
+                                		for(which=0,cnt=n->lsi ; cnt>=n->msi ; cnt--,which++)
                                         		{
                                         		if(cnt==bit) break;
                                         		}
                                 		}
                                 		else
                                 		{
-                                		for(which=0,cnt=n->ext->msi ; cnt>=n->ext->lsi ; cnt--,which++)
+                                		for(which=0,cnt=n->msi ; cnt>=n->lsi ; cnt--,which++)
                                         		{
                                         		if(cnt==bit) break;
                                         		}
@@ -1754,16 +1759,16 @@ while(t)
 				char *p = strrchr(str, '[');
 				if(p) { *p = 0; }					
               
-                       		if(n->ext->lsi > n->ext->msi)
+                       		if(n->lsi > n->msi)
                                		{
-                               		for(which=0,cnt=n->ext->lsi ; cnt>=n->ext->msi ; cnt--,which++)
+                               		for(which=0,cnt=n->lsi ; cnt>=n->msi ; cnt--,which++)
                                        		{
                                        		if(cnt==bit) break;
                                        		}
                                		}
                                		else
                                		{
-                               		for(which=0,cnt=n->ext->msi ; cnt>=n->ext->lsi ; cnt--,which++)
+                               		for(which=0,cnt=n->msi ; cnt>=n->lsi ; cnt--,which++)
                                        		{
                                        		if(cnt==bit) break;
                                        		}
@@ -2125,9 +2130,13 @@ if(mult_entry)
 	{
 	const char *hdr = "{gtkwave SAVELIST ";
 	int hdr_len = strlen(hdr);
-	const char *av[1] = { mult_entry };
-	char *zm = zMergeTclList(1, av);
-	int zm_len = strlen(zm);
+	const char *av[1];
+	char *zm;
+	int zm_len;
+
+	av[0] = mult_entry;
+	zm = zMergeTclList(1, av);
+	zm_len = strlen(zm);
 
 	free_2(mult_entry);
 
@@ -2191,10 +2200,11 @@ if(dot)
 		(!strcasecmp("dmp", dot+1)) ||
 		(!strcasecmp("lxt", dot+1)) ||
 		(!strcasecmp("lx2", dot+1)) ||
+		(!strcasecmp("lxt2", dot+1)) ||
 		(!strcasecmp("vzt", dot+1)) ||
 		(!strcasecmp("fst", dot+1)) ||
 		(!strcasecmp("ghw", dot+1)) ||
-		(!strcasecmp("aet", dot+1)) ||
+		(!strcasecmp("aet", dot+1)) ||	/* ignore .aet? filename types */
 		(!strcasecmp("ae2", dot+1))
 		)
 		{
@@ -2483,14 +2493,14 @@ if(objc > 1)
 		}
 
 	ife->callback();
-	gtkwave_gtk_main_iteration();
+	gtkwave_main_iteration();
 
 	GLOBALS->wave_script_args = NULL;
 	}
 	else
 	{
 	ife->callback();
-	gtkwave_gtk_main_iteration();
+	gtkwave_main_iteration();
 	}
 
 GLOBALS->enable_fast_exit = fexit;
@@ -2707,8 +2717,26 @@ void make_tcl_interpreter(char *argv[])
 
 
 /*
- * $Id: tcl_helper.c,v 1.67 2009/12/24 20:55:27 gtkwave Exp $
+ * $Id: tcl_helper.c,v 1.73 2010/03/18 17:12:37 gtkwave Exp $
  * $Log: tcl_helper.c,v $
+ * Revision 1.73  2010/03/18 17:12:37  gtkwave
+ * pedantic warning cleanups
+ *
+ * Revision 1.72  2010/03/16 21:01:11  gtkwave
+ * remove selected member of struct symbol
+ *
+ * Revision 1.71  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.70  2010/03/11 16:32:38  gtkwave
+ * fix to add .lxt2 suffix recognition
+ *
+ * Revision 1.69  2010/02/18 23:06:04  gtkwave
+ * change name of main iteration loop calls
+ *
+ * Revision 1.68  2010/01/22 02:10:49  gtkwave
+ * added second pattern search capability
+ *
  * Revision 1.67  2009/12/24 20:55:27  gtkwave
  * warnings cleanups
  *
