@@ -343,7 +343,7 @@ for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOB
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=GLOBALS->autocoalesce;
+		set_s_selected(s->vec_root, GLOBALS->autocoalesce);
 		}
         }
 
@@ -359,7 +359,7 @@ if(GLOBALS->is_lx2)
                 t=s->vec_root;
                 if((t)&&(GLOBALS->autocoalesce))
                         {
-                        if(t->selected)
+                        if(get_s_selected(t))
                                 {
                                 while(t)
                                         {
@@ -397,9 +397,9 @@ for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOB
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
 		{
-		if(t->selected)
+		if(get_s_selected(t))
 			{
-			t->selected=0;
+			set_s_selected(t, 0);
 			len=0;
 			while(t)
 				{
@@ -455,7 +455,7 @@ for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOB
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=GLOBALS->autocoalesce;
+		set_s_selected(s->vec_root, GLOBALS->autocoalesce);
 		}
         }
 
@@ -471,7 +471,7 @@ if(GLOBALS->is_lx2)
                 t=s->vec_root;
                 if((t)&&(GLOBALS->autocoalesce))
                         {
-                        if(t->selected)
+                        if(get_s_selected(t))
                                 {
                                 while(t)
                                         {
@@ -509,9 +509,9 @@ for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOB
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
 		{
-		if(t->selected)
+		if(get_s_selected(t))
 			{
-			t->selected=0;
+			set_s_selected(t, 0);
 			len=0;
 			while(t)
 				{
@@ -572,7 +572,7 @@ for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOB
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=GLOBALS->autocoalesce;
+		set_s_selected(s->vec_root, GLOBALS->autocoalesce);
 		}
         }
 
@@ -588,7 +588,7 @@ if(GLOBALS->is_lx2)
                 t=s->vec_root;
                 if((t)&&(GLOBALS->autocoalesce))
                         {
-                        if(t->selected)
+                        if(get_s_selected(t))
                                 {
                                 while(t)
                                         {
@@ -626,9 +626,9 @@ for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->which;i<=fetchhigh(GLOB
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
 		{
-		if(t->selected)
+		if(get_s_selected(t))
 			{
-			t->selected=0;
+			set_s_selected(t, 0);
 			len=0;
 			while(t)
 				{
@@ -813,8 +813,11 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
 }
 
 /*
- * $Id: treesearch_gtk1.c,v 1.12 2008/12/18 01:31:30 gtkwave Exp $
+ * $Id: treesearch_gtk1.c,v 1.13 2010/03/16 21:01:11 gtkwave Exp $
  * $Log: treesearch_gtk1.c,v $
+ * Revision 1.13  2010/03/16 21:01:11  gtkwave
+ * remove selected member of struct symbol
+ *
  * Revision 1.12  2008/12/18 01:31:30  gtkwave
  * integrated experimental autoscroll code on signal adds
  *
