@@ -276,7 +276,10 @@ GtkCTreeRow **gctr;
 int depth, i;
 int len = 1;
 char *tstring;
-char hier_suffix[2] = {GLOBALS->hier_delimeter,0};
+char hier_suffix[2];
+
+hier_suffix[0] = GLOBALS->hier_delimeter;
+hier_suffix[1] = 0;
 
 if(!node) return;
 
@@ -409,7 +412,10 @@ if(node)
 	int depth, i;
 	int len = 1;
 	char *tstring;
-	char hier_suffix[2] = {GLOBALS->hier_delimeter,0};
+	char hier_suffix[2];
+
+	hier_suffix[0] = GLOBALS->hier_delimeter;
+	hier_suffix[1] = 0;
                 
 	depth = GTK_CTREE_ROW(node)->level;
 	gctr = wave_alloca(depth * sizeof(GtkCTreeRow *));
@@ -793,9 +799,9 @@ sig_selection_foreach (GtkTreeModel *model,
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
 		{
-		if(t->selected)
+		if(get_s_selected(t))
 			{
-			t->selected=0;
+			set_s_selected(t,0);
 			len=0;
 			while(t)
 				{
@@ -887,7 +893,7 @@ sig_selection_foreach_preload_lx2
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
-		s->vec_root->selected=GLOBALS->autocoalesce;
+		set_s_selected(s->vec_root, GLOBALS->autocoalesce);
 		}
         }
 
@@ -901,7 +907,7 @@ sig_selection_foreach_preload_lx2
                 t=s->vec_root;
                 if((t)&&(GLOBALS->autocoalesce))
                         {
-                        if(t->selected)
+                        if(get_s_selected(t))
                                 {
                                 while(t)
                                         {
@@ -2048,8 +2054,14 @@ void dnd_setup(GtkWidget *src, GtkWidget *w, int enable_receive)
 }
 
 /*
- * $Id: treesearch_gtk2.c,v 1.41 2009/09/28 05:58:05 gtkwave Exp $
+ * $Id: treesearch_gtk2.c,v 1.43 2010/03/18 17:12:37 gtkwave Exp $
  * $Log: treesearch_gtk2.c,v $
+ * Revision 1.43  2010/03/18 17:12:37  gtkwave
+ * pedantic warning cleanups
+ *
+ * Revision 1.42  2010/03/16 21:01:12  gtkwave
+ * remove selected member of struct symbol
+ *
  * Revision 1.41  2009/09/28 05:58:05  gtkwave
  * changes to support signal_change_list
  *
