@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2009.
+ * Copyright (c) Tony Bybell 1999-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1641,6 +1641,13 @@ for(;;)
 						{
 						GLOBALS->start_time_vcd_c_1=tim;
 						}
+						else
+						{
+						if(tim < GLOBALS->current_time_vcd_c_1)	/* avoid backtracking time counts which can happen on malformed files */
+							{
+							tim = GLOBALS->current_time_vcd_c_1;
+							}
+						}
 
 					GLOBALS->current_time_vcd_c_1=tim;
 					if(GLOBALS->end_time_vcd_c_1<tim) GLOBALS->end_time_vcd_c_1=tim;	/* in case of malformed vcd files */
@@ -2036,6 +2043,9 @@ int duphier=0;
 char hashdirty;
 struct vcdsymbol *v, *vprime;
 char *str = NULL;
+#ifdef _WAVE_HAVE_JUDY
+int ss_len, longest = 0;
+#endif
 
 v=GLOBALS->vcdsymroot_vcd_c_1;
 while(v)
@@ -2091,7 +2101,9 @@ while(v)
 				if(symfind(str, NULL))
 					{
 					char *dupfix=(char *)malloc_2(max_slen+32);
+#ifndef _WAVE_HAVE_JUDY
 					hashdirty=1;
+#endif
 					DEBUG(fprintf(stderr,"Warning: %s is a duplicate net name.\n",str));
 
 					do sprintf(dupfix, "$DUP%d%s%s", duphier++, GLOBALS->vcd_hier_delimeter, str);
@@ -2104,7 +2116,9 @@ while(v)
 					/* fallthrough */
 					{
 					s=symadd(str,hashdirty?hash(str):GLOBALS->hashcache);
-	
+#ifdef _WAVE_HAVE_JUDY
+                                        ss_len = strlen(str); if(ss_len >= longest) { longest = ss_len + 1; }
+#endif
 					s->n=v->narray[j];
 					if(substnode)
 						{
@@ -2119,18 +2133,21 @@ while(v)
 						n->numhist=n2->numhist;
 						}
 	
+#ifndef _WAVE_HAVE_JUDY
 					s->n->nname=s->name;
-					s->h=s->n->curr;
+#endif
 					if(!GLOBALS->firstnode)
-						{
-						GLOBALS->firstnode=GLOBALS->curnode=s;
-						}
-						else
-						{
-						GLOBALS->curnode->nextinaet=s;
-						GLOBALS->curnode=s;
-						}
-	
+					        {
+					        GLOBALS->firstnode=
+					        GLOBALS->curnode=calloc_2(1, sizeof(struct symchain));
+					        }   
+					        else                                     
+					        {
+					        GLOBALS->curnode->next=calloc_2(1, sizeof(struct symchain));
+					        GLOBALS->curnode=GLOBALS->curnode->next;
+					        }
+					GLOBALS->curnode->symbol=s;
+                                                               	
 					GLOBALS->numfacs++;
 					DEBUG(fprintf(stderr,"Added: %s\n",str));
 					}
@@ -2172,7 +2189,9 @@ while(v)
 			if(symfind(str, NULL))
 				{
 				char *dupfix=(char *)malloc_2(max_slen+32);
+#ifndef _WAVE_HAVE_JUDY
 				hashdirty=1;
+#endif
 				DEBUG(fprintf(stderr,"Warning: %s is a duplicate net name.\n",str));
 
 				do sprintf(dupfix, "$DUP%d%s%s", duphier++, GLOBALS->vcd_hier_delimeter, str);
@@ -2187,7 +2206,9 @@ while(v)
 				struct symbol *s;
 
 				s=symadd(str,hashdirty?hash(str):GLOBALS->hashcache);	/* cut down on double lookups.. */
-
+#ifdef _WAVE_HAVE_JUDY
+                                ss_len = strlen(str); if(ss_len >= longest) { longest = ss_len + 1; }
+#endif
 				s->n=v->narray[0];
 				if(substnode)
 					{
@@ -2200,29 +2221,32 @@ while(v)
 					n->curr=n2->curr;
 					/* harray calculated later */
 					n->numhist=n2->numhist;
-					n->ext=n2->ext;
+					n->extvals=n2->extvals;
+					n->msi=n2->msi;
+					n->lsi=n2->lsi;
 					}
 					else
 					{
-					struct ExtNode *en;
-					en=(struct ExtNode *)malloc_2(sizeof(struct ExtNode));
-					en->msi=v->msi;
-					en->lsi=v->lsi;
+					s->n->msi=v->msi;
+					s->n->lsi=v->lsi;
 
-					s->n->ext=en;
+					s->n->extvals=1;
 					}
 
+#ifndef _WAVE_HAVE_JUDY
 				s->n->nname=s->name;
-				s->h=s->n->curr;
+#endif
 				if(!GLOBALS->firstnode)
-					{
-					GLOBALS->firstnode=GLOBALS->curnode=s;
-					}
-					else
-					{
-					GLOBALS->curnode->nextinaet=s;
-					GLOBALS->curnode=s;
-					}
+				        {
+				        GLOBALS->firstnode=
+				        GLOBALS->curnode=calloc_2(1, sizeof(struct symchain));
+				        }   
+				        else                                     
+				        {
+				        GLOBALS->curnode->next=calloc_2(1, sizeof(struct symchain));
+				        GLOBALS->curnode=GLOBALS->curnode->next;
+				        }
+				GLOBALS->curnode->symbol=s;
 
 				GLOBALS->numfacs++;
 				DEBUG(fprintf(stderr,"Added: %s\n",str));
@@ -2233,6 +2257,26 @@ while(v)
 	v=v->next;
 	}
 
+#ifdef _WAVE_HAVE_JUDY
+{
+Pvoid_t  PJArray = GLOBALS->sym_judy;   
+PPvoid_t PPValue;
+char *Index = calloc_2(1, longest);
+JError_t JError;
+                                
+for (PPValue  = JudySLFirst (PJArray, (uint8_t *)Index, &JError);
+         PPValue != (PPvoid_t) NULL;
+         PPValue  = JudySLNext  (PJArray, (uint8_t *)Index, &JError))
+    {
+        struct symbol *s = *(struct symbol **)PPValue;
+        s->name = strdup_2(Index);
+        s->n->nname = s->name;
+    }
+
+free_2(Index);
+}
+#endif
+
 if(sym_chain)
 	{
 	sym_curr=sym_chain;	
@@ -2257,38 +2301,39 @@ if(sym_chain)
 void vcd_sortfacs(void)
 {
 int i;
-JRB ptr, lst;
 
-GLOBALS->pfx_hier_array = calloc_2(GLOBALS->hier_pfx_cnt ? GLOBALS->hier_pfx_cnt : 1, sizeof(char *));
-lst = GLOBALS->hier_pfx;
-if(lst)
-	{
-	jrb_traverse(ptr, lst)
-		{
-		GLOBALS->pfx_hier_array[ptr->val.ui] = ptr->key.s;
-		}
-	}
+create_hier_array();
 
 GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
 GLOBALS->curnode=GLOBALS->firstnode;
 for(i=0;i<GLOBALS->numfacs;i++)
         {
-        char *subst, ch;
+        char *subst;
+#ifdef WAVE_HIERFIX
+        char ch;
+#endif
         int len;
+	struct symchain *sc;
                  
-        GLOBALS->facs[i]=GLOBALS->curnode;
-        if((len=strlen(subst=GLOBALS->curnode->name))>GLOBALS->longestname) GLOBALS->longestname=len;
-        GLOBALS->curnode=GLOBALS->curnode->nextinaet;
+        GLOBALS->facs[i]=GLOBALS->curnode->symbol;
+        if((len=strlen(subst=GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
+	sc = GLOBALS->curnode;
+        GLOBALS->curnode=GLOBALS->curnode->next;
+	free_2(sc);
+#ifdef WAVE_HIERFIX
         while((ch=(*subst)))
                 {
                 if(ch==GLOBALS->hier_delimeter) { *subst=VCDNAM_HIERSORT; } /* forces sort at hier boundaries */
                 subst++;
                 }
+#endif
         }
+GLOBALS->firstnode=GLOBALS->curnode=NULL;
 
 /* quicksort(facs,0,numfacs-1); */	/* quicksort deprecated because it degenerates on sorted traces..badly.  very badly. */
 wave_heapsort(GLOBALS->facs,GLOBALS->numfacs);
 
+#ifdef WAVE_HIERFIX
 for(i=0;i<GLOBALS->numfacs;i++)
         {
         char *subst, ch;
@@ -2304,6 +2349,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
         printf("%-4d %s\n",i,facs[i]->name);
 #endif
         }
+#endif
 
 GLOBALS->facs_are_sorted=1;
 
@@ -2478,6 +2524,7 @@ if(!GLOBALS->vcd_handle_vcd_c_1)
 
 /* SPLASH */				splash_create(); 
 
+sym_hash_initialize(GLOBALS);
 getch_alloc();		/* alloc membuff for vcd getch buffer */
 
 build_slisthier();
@@ -2549,8 +2596,38 @@ return(GLOBALS->max_time);
 /*******************************************************************************/
 
 /*
- * $Id: vcd.c,v 1.22 2009/08/28 19:58:42 gtkwave Exp $
+ * $Id: vcd.c,v 1.32 2010/03/18 17:12:37 gtkwave Exp $
  * $Log: vcd.c,v $
+ * Revision 1.32  2010/03/18 17:12:37  gtkwave
+ * pedantic warning cleanups
+ *
+ * Revision 1.31  2010/03/17 17:32:45  gtkwave
+ * use calloc'd memory for SL iterator initialization
+ *
+ * Revision 1.30  2010/03/16 21:01:12  gtkwave
+ * remove selected member of struct symbol
+ *
+ * Revision 1.29  2010/03/15 15:57:28  gtkwave
+ * only allocate hash when necessary
+ *
+ * Revision 1.28  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.27  2010/03/13 19:48:53  gtkwave
+ * remove nextinaet field and replace with temp symchain
+ *
+ * Revision 1.26  2010/03/13 07:56:41  gtkwave
+ * removed unused h field in struct symbol
+ *
+ * Revision 1.25  2010/03/01 05:16:26  gtkwave
+ * move compressed hier tree traversal to hierpack
+ *
+ * Revision 1.24  2010/02/08 17:31:19  gtkwave
+ * backtracking time fix
+ *
+ * Revision 1.23  2010/01/23 03:21:11  gtkwave
+ * hierarchy fixes when characters < "." are in the signal names
+ *
  * Revision 1.22  2009/08/28 19:58:42  gtkwave
  * added malform_eof_fix
  *
