@@ -145,7 +145,7 @@ static char *tokens[]={ "var", "end", "scope", "upscope",
 
 #ifdef DEBUG_PRINTF
 static char *vartypes[]={ "event", "parameter",
-                "integer", "real", "real_parameter", "reg", "supply0",
+                "integer", "real", "real_parameter", "realtime", "reg", "supply0",
                 "supply1", "time", "tri", "triand", "trior",
                 "trireg", "tri0", "tri1", "wand", "wire", "wor", "port", "in", "out", "inout",
                 "$end", "", "", "", ""};  
@@ -1918,6 +1918,9 @@ int duphier=0;
 char hashdirty;
 struct vcdsymbol *v, *vprime;
 char *str = NULL;
+#ifdef _WAVE_HAVE_JUDY
+int ss_len, longest = 0;
+#endif
 
 v=GLOBALS->vcdsymroot_vcd_partial_c_2;
 while(v)
@@ -1973,7 +1976,9 @@ while(v)
 				if(symfind(str, NULL))
 					{
 					char *dupfix=(char *)malloc_2(max_slen+32);
+#ifndef _WAVE_HAVE_JUDY
 					hashdirty=1;
+#endif
 					DEBUG(fprintf(stderr,"Warning: %s is a duplicate net name.\n",str));
 
 					do sprintf(dupfix, "$DUP%d%s%s", duphier++, GLOBALS->vcd_hier_delimeter, str);
@@ -1986,7 +1991,9 @@ while(v)
 					/* fallthrough */
 					{
 					s=symadd(str,hashdirty?hash(str):GLOBALS->hashcache);
-	
+#ifdef _WAVE_HAVE_JUDY
+                                        ss_len = strlen(str); if(ss_len >= longest) { longest = ss_len + 1; }
+#endif
 					s->n=v->narray[j];
 					if(substnode)
 						{
@@ -2001,17 +2008,20 @@ while(v)
 						n->numhist=n2->numhist;
 						}
 	
+#ifndef _WAVE_HAVE_JUDY
 					s->n->nname=s->name;
-					s->h=s->n->curr;
+#endif
 					if(!GLOBALS->firstnode)
-						{
-						GLOBALS->firstnode=GLOBALS->curnode=s;
-						}
-						else
-						{
-						GLOBALS->curnode->nextinaet=s;
-						GLOBALS->curnode=s;
-						}
+					        {
+					        GLOBALS->firstnode=
+					        GLOBALS->curnode=calloc_2(1, sizeof(struct symchain));
+					        }   
+					        else                                     
+					        {
+					        GLOBALS->curnode->next=calloc_2(1, sizeof(struct symchain));
+					        GLOBALS->curnode=GLOBALS->curnode->next;
+					        }
+					GLOBALS->curnode->symbol=s;
 	
 					GLOBALS->numfacs++;
 					DEBUG(fprintf(stderr,"Added: %s\n",str));
@@ -2054,7 +2064,9 @@ while(v)
 			if(symfind(str, NULL))
 				{
 				char *dupfix=(char *)malloc_2(max_slen+32);
+#ifndef _WAVE_HAVE_JUDY
 				hashdirty=1;
+#endif
 				DEBUG(fprintf(stderr,"Warning: %s is a duplicate net name.\n",str));
 
 				do sprintf(dupfix, "$DUP%d%s%s", duphier++, GLOBALS->vcd_hier_delimeter, str);
@@ -2069,7 +2081,9 @@ while(v)
 				struct symbol *s;
 
 				s=symadd(str,hashdirty?hash(str):GLOBALS->hashcache);	/* cut down on double lookups.. */
-
+#ifdef _WAVE_HAVE_JUDY
+                                ss_len = strlen(str); if(ss_len >= longest) { longest = ss_len + 1; }
+#endif
 				s->n=v->narray[0];
 				if(substnode)
 					{
@@ -2082,29 +2096,32 @@ while(v)
 					n->curr=n2->curr;
 					/* harray calculated later */
 					n->numhist=n2->numhist;
-					n->ext=n2->ext;
+					n->extvals=n2->extvals;
+					n->msi=n2->msi;
+					n->lsi=n2->lsi;
 					}
 					else
 					{
-					struct ExtNode *en;
-					en=(struct ExtNode *)malloc_2(sizeof(struct ExtNode));
-					en->msi=v->msi;
-					en->lsi=v->lsi;
+					s->n->msi=v->msi;
+					s->n->lsi=v->lsi;
 
-					s->n->ext=en;
+					s->n->extvals=1;
 					}
 
+#ifndef _WAVE_HAVE_JUDY
 				s->n->nname=s->name;
-				s->h=s->n->curr;
+#endif
 				if(!GLOBALS->firstnode)
-					{
-					GLOBALS->firstnode=GLOBALS->curnode=s;
-					}
-					else
-					{
-					GLOBALS->curnode->nextinaet=s;
-					GLOBALS->curnode=s;
-					}
+				        {
+				        GLOBALS->firstnode=
+				        GLOBALS->curnode=calloc_2(1, sizeof(struct symchain));
+				        }   
+				        else                                     
+				        {
+				        GLOBALS->curnode->next=calloc_2(1, sizeof(struct symchain));
+				        GLOBALS->curnode=GLOBALS->curnode->next;
+				        }
+				GLOBALS->curnode->symbol=s;
 
 				GLOBALS->numfacs++;
 				DEBUG(fprintf(stderr,"Added: %s\n",str));
@@ -2115,6 +2132,26 @@ while(v)
 	v=v->next;
 	}
 
+#ifdef _WAVE_HAVE_JUDY
+{
+Pvoid_t  PJArray = GLOBALS->sym_judy;
+PPvoid_t PPValue;
+char *Index = calloc_2(1, longest);
+JError_t JError;
+                                        
+for (PPValue  = JudySLFirst (PJArray, (uint8_t *)Index, &JError);
+         PPValue != (PPvoid_t) NULL;
+         PPValue  = JudySLNext  (PJArray, (uint8_t *)Index, &JError))
+    {                   
+        struct symbol *s = *(struct symbol **)PPValue;  
+        s->name = strdup_2(Index);
+        s->n->nname = s->name;  
+    }
+
+free_2(Index);
+}
+#endif
+
 if(sym_chain)
 	{
 	sym_curr=sym_chain;	
@@ -2157,6 +2194,7 @@ GLOBALS->slistroot=GLOBALS->slistcurr=NULL; GLOBALS->slisthier_len=0;
 
 TimeType vcd_partial_main(char *fname)
 {
+unsigned int shmidu = ~(0L);
 int shmid;
 
 GLOBALS->pv_vcd_partial_c_2=GLOBALS->rootv_vcd_partial_c_2=NULL;
@@ -2174,12 +2212,13 @@ if(!GLOBALS->hier_was_explicitly_set) /* set default hierarchy split char */
 
 if(!strcmp(fname, "-vcd"))
 	{
-	if(!fscanf(stdin, "%x", &shmid)) shmid = -1; /* allow use of -v flag to pass straight from stdin */
+	if(!fscanf(stdin, "%x", &shmidu)) shmidu = ~(0L); /* allow use of -v flag to pass straight from stdin */
 	}
 	else
 	{
-	sscanf(fname, "%x", &shmid);	/* passed as a filename */
+	sscanf(fname, "%x", &shmidu);	/* passed as a filename */
 	}
+shmid = (int)shmidu;
 
 #if !defined _MSC_VER
 #ifdef __MINGW32__
@@ -2216,6 +2255,7 @@ fprintf(stderr, "Interactive VCD mode does not work with Windows, exiting.\n");
 exit(255);
 #endif
 
+sym_hash_initialize(GLOBALS);
 getch_alloc();		/* alloc membuff for vcd getch buffer */
 build_slisthier();
 
@@ -2396,7 +2436,8 @@ if(GLOBALS->partial_vcd)
 	while(*GLOBALS->consume_ptr_vcd_partial_c_1)
 		{
 		Trptr t;
-	
+		int old_maxtime_marker_conflict = (GLOBALS->tims.marker > GLOBALS->max_time);
+
 		vcd_parse();
 	
 		GLOBALS->min_time=GLOBALS->start_time_vcd_partial_c_2*GLOBALS->time_scale;
@@ -2413,6 +2454,11 @@ if(GLOBALS->partial_vcd)
 	
 		update_endcap_times_for_partial_vcd();
 		update_maxmarker_labels();
+
+		if(old_maxtime_marker_conflict)
+			{
+			old_maxtime_marker_conflict = (GLOBALS->tims.marker<=GLOBALS->max_time); /* data is now past what was invisible marker */
+			}
 	
 		t = GLOBALS->traces.first; while(t) { regen_trace_mark(t); t = t->t_next; }
 		t = GLOBALS->traces.buffer; while(t) { regen_trace_mark(t); t = t->t_next; }
@@ -2438,6 +2484,13 @@ if(GLOBALS->partial_vcd)
 		        MaxSignalLength();
 		        signalarea_configure_event(GLOBALS->signalarea, NULL);
 			}
+		else if ((old_maxtime_marker_conflict) && (!GLOBALS->helpbox_is_active))
+			{
+			GLOBALS->signalwindow_width_dirty=1;
+			MaxSignalLength();
+			signalarea_configure_event(GLOBALS->signalarea, NULL);
+		        wavearea_configure_event(GLOBALS->wavearea, NULL);
+			}
 			else
 			{
 		        signalarea_configure_event(GLOBALS->signalarea, NULL);
@@ -2446,18 +2499,48 @@ if(GLOBALS->partial_vcd)
 
 		update_maxmarker_labels();
 
-		gtkwave_gtk_main_iteration();
+		gtkwave_main_iteration();
 		}
 	}
 
 #endif
 
-gtkwave_gtk_main_iteration();
+gtkwave_main_iteration();
 }
 
 /*
- * $Id: vcd_partial.c,v 1.22 2009/12/22 20:00:41 gtkwave Exp $
+ * $Id: vcd_partial.c,v 1.32 2010/03/18 17:12:37 gtkwave Exp $
  * $Log: vcd_partial.c,v $
+ * Revision 1.32  2010/03/18 17:12:37  gtkwave
+ * pedantic warning cleanups
+ *
+ * Revision 1.31  2010/03/17 17:32:45  gtkwave
+ * use calloc'd memory for SL iterator initialization
+ *
+ * Revision 1.30  2010/03/16 21:01:12  gtkwave
+ * remove selected member of struct symbol
+ *
+ * Revision 1.29  2010/03/15 16:40:56  gtkwave
+ * fixed kick_partial_vcd to handle maxtime scrolling over markertime
+ *
+ * Revision 1.28  2010/03/15 15:57:29  gtkwave
+ * only allocate hash when necessary
+ *
+ * Revision 1.27  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.26  2010/03/13 19:48:53  gtkwave
+ * remove nextinaet field and replace with temp symchain
+ *
+ * Revision 1.25  2010/03/13 07:56:41  gtkwave
+ * removed unused h field in struct symbol
+ *
+ * Revision 1.24  2010/02/22 21:13:36  gtkwave
+ * added "realtime" VCD variable
+ *
+ * Revision 1.23  2010/02/18 23:06:04  gtkwave
+ * change name of main iteration loop calls
+ *
  * Revision 1.22  2009/12/22 20:00:41  gtkwave
  * warnings fixes
  *
