@@ -1932,6 +1932,11 @@ for(;;)
 						}
 						else
 						{
+						if(tim < GLOBALS->current_time_vcd_recoder_c_3) /* avoid backtracking time counts which can happen on malformed files */
+							{
+							tim = GLOBALS->current_time_vcd_recoder_c_3;
+							}
+
 						if(GLOBALS->time_vlist_vcd_recoder_write)
 							{					
 							vlist_packer_emit_utt((struct vlist_packer_t **)(void *)&GLOBALS->time_vlist_vcd_recoder_write, tim - GLOBALS->current_time_vcd_recoder_c_3);
@@ -2266,6 +2271,9 @@ int duphier=0;
 char hashdirty;
 struct vcdsymbol *v, *vprime;
 char *str = NULL;
+#ifdef _WAVE_HAVE_JUDY
+int ss_len, longest = 0;
+#endif
 
 v=GLOBALS->vcdsymroot_vcd_recoder_c_3;
 while(v)
@@ -2321,7 +2329,9 @@ while(v)
 				if(symfind(str, NULL))
 					{
 					char *dupfix=(char *)malloc_2(max_slen+32);
+#ifndef _WAVE_HAVE_JUDY
 					hashdirty=1;
+#endif
 					DEBUG(fprintf(stderr,"Warning: %s is a duplicate net name.\n",str));
 
 					do sprintf(dupfix, "$DUP%d%s%s", duphier++, GLOBALS->vcd_hier_delimeter, str);
@@ -2334,7 +2344,9 @@ while(v)
 					/* fallthrough */
 					{
 					s=symadd(str,hashdirty?hash(str):GLOBALS->hashcache);
-	
+#ifdef _WAVE_HAVE_JUDY
+					ss_len = strlen(str); if(ss_len >= longest) { longest = ss_len + 1; }
+#endif	
 					s->n=v->narray[j];
 					if(substnode)
 						{
@@ -2350,17 +2362,20 @@ while(v)
 						n->numhist=n2->numhist;
 						}
 	
+#ifndef _WAVE_HAVE_JUDY
 					s->n->nname=s->name;
-					s->h=s->n->curr;
+#endif
 					if(!GLOBALS->firstnode)
-						{
-						GLOBALS->firstnode=GLOBALS->curnode=s;
-						}
-						else
-						{
-						GLOBALS->curnode->nextinaet=s;
-						GLOBALS->curnode=s;
-						}
+					        {
+					        GLOBALS->firstnode=
+					        GLOBALS->curnode=calloc_2(1, sizeof(struct symchain));
+					        }   
+					        else                                     
+					        {
+					        GLOBALS->curnode->next=calloc_2(1, sizeof(struct symchain));
+					        GLOBALS->curnode=GLOBALS->curnode->next;
+					        }
+					GLOBALS->curnode->symbol=s;
 	
 					GLOBALS->numfacs++;
 					DEBUG(fprintf(stderr,"Added: %s\n",str));
@@ -2403,7 +2418,9 @@ while(v)
 			if(symfind(str, NULL))
 				{
 				char *dupfix=(char *)malloc_2(max_slen+32);
+#ifndef _WAVE_HAVE_JUDY
 				hashdirty=1;
+#endif
 				DEBUG(fprintf(stderr,"Warning: %s is a duplicate net name.\n",str));
 
 				do sprintf(dupfix, "$DUP%d%s%s", duphier++, GLOBALS->vcd_hier_delimeter, str);
@@ -2418,7 +2435,9 @@ while(v)
 				struct symbol *s;
 
 				s=symadd(str,hashdirty?hash(str):GLOBALS->hashcache);	/* cut down on double lookups.. */
-
+#ifdef _WAVE_HAVE_JUDY
+                                ss_len = strlen(str); if(ss_len >= longest) { longest = ss_len + 1; }
+#endif        
 				s->n=v->narray[0];
 				if(substnode)
 					{
@@ -2432,29 +2451,32 @@ while(v)
 					n->curr=(hptr)n2;
 					/* harray calculated later */
 					n->numhist=n2->numhist;
-					n->ext=n2->ext;
+					n->extvals=n2->extvals;
+					n->msi=n2->msi;
+					n->lsi=n2->lsi;
 					}
 					else
 					{
-					struct ExtNode *en;
-					en=(struct ExtNode *)malloc_2(sizeof(struct ExtNode));
-					en->msi=v->msi;
-					en->lsi=v->lsi;
+					s->n->msi=v->msi;
+					s->n->lsi=v->lsi;
 
-					s->n->ext=en;
+					s->n->extvals=1;
 					}
 
+#ifndef _WAVE_HAVE_JUDY
 				s->n->nname=s->name;
-				s->h=s->n->curr;
+#endif
 				if(!GLOBALS->firstnode)
-					{
-					GLOBALS->firstnode=GLOBALS->curnode=s;
-					}
-					else
-					{
-					GLOBALS->curnode->nextinaet=s;
-					GLOBALS->curnode=s;
-					}
+				        {
+				        GLOBALS->firstnode=
+				        GLOBALS->curnode=calloc_2(1, sizeof(struct symchain));
+				        }   
+				        else                                     
+				        {
+				        GLOBALS->curnode->next=calloc_2(1, sizeof(struct symchain));
+				        GLOBALS->curnode=GLOBALS->curnode->next;
+				        }
+				GLOBALS->curnode->symbol=s;
 
 				GLOBALS->numfacs++;
 				DEBUG(fprintf(stderr,"Added: %s\n",str));
@@ -2465,6 +2487,26 @@ while(v)
 	v=v->next;
 	}
 
+#ifdef _WAVE_HAVE_JUDY
+{
+Pvoid_t  PJArray = GLOBALS->sym_judy;
+PPvoid_t PPValue;
+char *Index = calloc_2(1, longest);
+JError_t JError;  
+
+for (PPValue  = JudySLFirst (PJArray, (uint8_t *)Index, &JError);
+         PPValue != (PPvoid_t) NULL;
+         PPValue  = JudySLNext  (PJArray, (uint8_t *)Index, &JError))
+    {        
+	struct symbol *s = *(struct symbol **)PPValue;
+	s->name = strdup_2(Index);
+	s->n->nname = s->name;	
+    }   
+
+free_2(Index);
+}
+#endif
+
 if(sym_chain)
 	{
 	sym_curr=sym_chain;	
@@ -2656,6 +2698,7 @@ if(!GLOBALS->vcd_handle_vcd_recoder_c_2)
 
 /* SPLASH */				splash_create(); 
 
+sym_hash_initialize(GLOBALS);
 getch_alloc();		/* alloc membuff for vcd getch buffer */
 
 build_slisthier();
@@ -3169,8 +3212,32 @@ np->mv.mvlfac_vlist = NULL;
 }
 
 /*
- * $Id: vcd_recoder.c,v 1.33 2009/12/25 18:12:16 gtkwave Exp $
+ * $Id: vcd_recoder.c,v 1.41 2010/03/18 17:12:37 gtkwave Exp $
  * $Log: vcd_recoder.c,v $
+ * Revision 1.41  2010/03/18 17:12:37  gtkwave
+ * pedantic warning cleanups
+ *
+ * Revision 1.40  2010/03/17 17:32:45  gtkwave
+ * use calloc'd memory for SL iterator initialization
+ *
+ * Revision 1.39  2010/03/16 21:01:12  gtkwave
+ * remove selected member of struct symbol
+ *
+ * Revision 1.38  2010/03/15 15:57:29  gtkwave
+ * only allocate hash when necessary
+ *
+ * Revision 1.37  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.36  2010/03/13 19:48:53  gtkwave
+ * remove nextinaet field and replace with temp symchain
+ *
+ * Revision 1.35  2010/03/13 07:56:41  gtkwave
+ * removed unused h field in struct symbol
+ *
+ * Revision 1.34  2010/02/08 17:31:19  gtkwave
+ * backtracking time fix
+ *
  * Revision 1.33  2009/12/25 18:12:16  gtkwave
  * more warnings fixes
  *
