@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 2005-2009.
+ * Copyright (c) Tony Bybell 2005-2010.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -374,8 +374,6 @@ while(t)
 			{
 			n = t->n.nd;
 			if(n->expansion) n = n->expansion->parent;
-			/* e = n->ext; */
-			/* if(e) { msi = e->msi; lsi = e->lsi; } else { msi = lsi = -1; } */
 			vt = vcdsav_splay(n, vt);
 			if(!vt || vt->item != n)
 				{
@@ -406,8 +404,6 @@ while(t)
 						n = bt->nodes[i];
 	
 						if(n->expansion) n = n->expansion->parent;
-						/* e = n->ext; */
-						/* if(e) { msi = e->msi; lsi = e->lsi; } else { msi = lsi = -1; } */
 						vt = vcdsav_splay(n, vt);
 						if(!vt || vt->item != n)
 							{
@@ -430,26 +426,38 @@ while(t)
 	if(!strace_append)
 		{
 		t=t->t_next;
-		if(!t) 
-			{
-	                if(GLOBALS->shadow_straces)
-	                        {
-	                        swap_strace_contexts();
-				st = GLOBALS->straces;
-
-				strace_append = 1;
-				t = st ? st->trace : NULL;
-				}
-			}
+		if(t) continue;
 		}
 		else
 		{
 		st = st->next;
 		t = st ? st->trace : NULL;
+		if(t) 
+			{
+			continue;
+			}
+			else
+			{
+			swap_strace_contexts();
+			}
 		}
+
+strace_concat:
+	GLOBALS->strace_ctx = &GLOBALS->strace_windows[GLOBALS->strace_current_window = strace_append];	
+	strace_append++;
+	if(strace_append == WAVE_NUM_STRACE_WINDOWS) break;
+
+	if(!GLOBALS->strace_ctx->shadow_straces)
+		{
+		goto strace_concat;		
+		}
+
+	swap_strace_contexts();
+	st = GLOBALS->strace_ctx->straces;
+	t = st ? st->trace : NULL;
+	if(!t) {swap_strace_contexts(); goto strace_concat; }
 	}
 
-if(strace_append) swap_strace_contexts();
 if(!nodecnt) return(VCDSAV_EMPTY);
 
 
@@ -511,10 +519,10 @@ for(i=0;i<nodecnt;i++)
 		{
 		int msi = -1, lsi = -1;
 
-		if(GLOBALS->hp_vcd_saver_c_1[i]->item->ext)
+		if(GLOBALS->hp_vcd_saver_c_1[i]->item->extvals)
 			{
-			msi = GLOBALS->hp_vcd_saver_c_1[i]->item->ext->msi;
-			lsi = GLOBALS->hp_vcd_saver_c_1[i]->item->ext->lsi;
+			msi = GLOBALS->hp_vcd_saver_c_1[i]->item->msi;
+			lsi = GLOBALS->hp_vcd_saver_c_1[i]->item->lsi;
 			}
 		
 		if(msi==lsi)
@@ -1373,7 +1381,7 @@ if(!(t->flags&(TR_EXCLUDE|TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
         GLOBALS->shift_timebase=t->shift;
         if(!t->vector)
         	{
-                if(!t->n.nd->ext)
+                if(!t->n.nd->extvals)
                 	{
 			write_hptr_trace(t, whichptr, tmin, tmax); /* single-bit */
                         }
@@ -1457,8 +1465,14 @@ return(errno ? VCDSAV_FILE_ERROR : VCDSAV_OK);
 }
 
 /*
- * $Id: vcd_saver.c,v 1.11 2009/07/07 20:12:53 gtkwave Exp $
+ * $Id: vcd_saver.c,v 1.13 2010/03/14 07:09:49 gtkwave Exp $
  * $Log: vcd_saver.c,v $
+ * Revision 1.13  2010/03/14 07:09:49  gtkwave
+ * removed ExtNode and merged with Node
+ *
+ * Revision 1.12  2010/01/22 02:10:49  gtkwave
+ * added second pattern search capability
+ *
  * Revision 1.11  2009/07/07 20:12:53  gtkwave
  * convert hex capitalization to match verilog
  *
